import { EventEmitter, Output, Component, forwardRef, Input, ChangeDetectionStrategy } from '@angular/core';
import { delegateCombine } from "igniteui-angular-core";
import { IgxSeriesComponent } from "./igx-series-component";
import { CalloutCollisionMode_$type } from "./CalloutCollisionMode";
import { IgxCalloutStyleUpdatingEventArgs } from "./igx-callout-style-updating-event-args";
import { IgxCalloutContentUpdatingEventArgs } from "./igx-callout-content-updating-event-args";
import { IgxCalloutLabelUpdatingEventArgs } from "./igx-callout-label-updating-event-args";
import { IgxCalloutSeriesSelectingEventArgs } from "./igx-callout-series-selecting-event-args";
import { IgxAnnotationLayerComponent } from "./igx-annotation-layer-component";
import { CalloutLayer } from "./CalloutLayer";
import { ensureBool, brushToString, stringToBrush, ensureEnum } from "igniteui-angular-core";
import * as i0 from "@angular/core";
/**
 * Represents an annotation layer that displays crosshair lines that cross through the closest value of the target series under the cursor.
*/
export let IgxCalloutLayerComponent = /*@__PURE__*/ (() => {
    class IgxCalloutLayerComponent extends IgxAnnotationLayerComponent {
        constructor() {
            super();
            this._calloutStyleUpdating = null;
            this._calloutContentUpdating = null;
            this._calloutLabelUpdating = null;
            this._calloutSeriesSelecting = null;
        }
        createImplementation() {
            return new CalloutLayer();
        }
        /**
                                     * @hidden
                                     */
        get i() {
            return this._implementation;
        }
        /**
         * Gets whether the series is an callout annotation layer.
        */
        get isAnnotationCalloutLayer() {
            return this.i.c2;
        }
        /**
         * Gets or sets the label mapping property for the callouts.
        */
        get labelMemberPath() {
            return this.i.sv;
        }
        set labelMemberPath(v) {
            this.i.sv = v;
        }
        /**
         * Gets or sets the label mapping property for the callouts.
        */
        get xMemberPath() {
            return this.i.s4;
        }
        set xMemberPath(v) {
            this.i.s4 = v;
        }
        /**
         * Gets or sets the label mapping property for the callouts.
        */
        get yMemberPath() {
            return this.i.s7;
        }
        set yMemberPath(v) {
            this.i.s7 = v;
        }
        /**
         * Gets or sets the key mapping property for the callouts.
        */
        get keyMemberPath() {
            return this.i.ss;
        }
        set keyMemberPath(v) {
            this.i.ss = v;
        }
        /**
         * Gets or sets whether to allow the callouts to be variable distances from the target points, for suppporting collision modes.
        */
        get isCalloutOffsettingEnabled() {
            return this.i.rh;
        }
        set isCalloutOffsettingEnabled(v) {
            this.i.rh = ensureBool(v);
        }
        /**
         * Gets or sets the content mapping property for the callouts.
        */
        get contentMemberPath() {
            return this.i.sm;
        }
        set contentMemberPath(v) {
            this.i.sm = v;
        }
        /**
         * Gets or sets the name of the series series to target this annotation to. If null, this annotation targets all series simultaneously.
        */
        get targetSeriesName() {
            return this.i.sx;
        }
        set targetSeriesName(v) {
            this.i.sx = v;
        }
        /**
         * Gets or sets the series to target this annotation to. If null, this annotation targets all series simultaneously.
        */
        get targetSeries() {
            if (this.i.qs == null) {
                return null;
            }
            if (!this.i.qs.externalObject) {
                let e = IgxSeriesComponent._createFromInternal(this.i.qs);
                if (e) {
                    e._implementation = this.i.qs;
                }
                this.i.qs.externalObject = e;
            }
            return this.i.qs.externalObject;
        }
        set targetSeries(v) {
            if (v != null && this._stylingContainer && v._styling)
                v._styling(this._stylingContainer, this, this);
            v == null ? this.i.qs = null : this.i.qs = v.i;
        }
        /**
         * Gets or sets a channel name to identify other callout layers within the chart to share collision information with.
        */
        get collisionChannel() {
            return this.i.sj;
        }
        set collisionChannel(v) {
            this.i.sj = v;
        }
        /**
         * Gets or sets how to select the final value to annotate.
        */
        get isAutoCalloutBehaviorEnabled() {
            return this.i.rg;
        }
        set isAutoCalloutBehaviorEnabled(v) {
            this.i.rg = ensureBool(v);
        }
        /**
         * Gets or sets whether to use values, rather than labels for auto callout labels.
        */
        get useValueForAutoCalloutLabels() {
            return this.i.rj;
        }
        set useValueForAutoCalloutLabels(v) {
            this.i.rj = ensureBool(v);
        }
        /**
         * Gets or sets whether to allow for custom callout styles.
        */
        get isCustomCalloutStyleEnabled() {
            return this.i.ri;
        }
        set isCustomCalloutStyleEnabled(v) {
            this.i.ri = ensureBool(v);
        }
        /**
         * Gets or sets the precision to use when values are used for the auto callout labels.
        */
        get autoCalloutLabelPrecision() {
            return this.i.r1;
        }
        set autoCalloutLabelPrecision(v) {
            this.i.r1 = +v;
        }
        /**
         * Gets or sets the color to use for the callout text. Leave unset for an automatic value.
        */
        get calloutTextColor() {
            return brushToString(this.i.ug);
        }
        set calloutTextColor(v) {
            this.i.ug = stringToBrush(v);
        }
        /**
         * Gets or sets the brush that specifies how the backgrounds for the callouts of the layer are painted. Leave unset for an automatic value.
        */
        get calloutBackground() {
            return brushToString(this.i.ud);
        }
        set calloutBackground(v) {
            this.i.ud = stringToBrush(v);
        }
        /**
         * Gets or sets the precision to use displaying values for interpolated crosshair positions.
        */
        get calloutInterpolatedValuePrecision() {
            return this.i.r2;
        }
        set calloutInterpolatedValuePrecision(v) {
            this.i.r2 = +v;
        }
        /**
         * Gets or sets the brush that specifies how the outlines for the callouts of the layer are painted.
        */
        get calloutOutline() {
            return brushToString(this.i.uf);
        }
        set calloutOutline(v) {
            this.i.uf = stringToBrush(v);
        }
        /**
         * Gets or sets the brush that specifies how the leader lines for the callouts of the layer are painted.
        */
        get calloutLeaderBrush() {
            return brushToString(this.i.ue);
        }
        set calloutLeaderBrush(v) {
            this.i.ue = stringToBrush(v);
        }
        /**
         * Gets or sets the left padding to use withing the callout. Leaving this NaN will use an automatic value related to the axis label margins.
        */
        get calloutPaddingLeft() {
            return this.i.ru;
        }
        set calloutPaddingLeft(v) {
            this.i.ru = +v;
        }
        /**
         * Gets or sets the top padding to use within the callout. Leaving this NaN will use an automatic value related to the axis label margins.
        */
        get calloutPaddingTop() {
            return this.i.rw;
        }
        set calloutPaddingTop(v) {
            this.i.rw = +v;
        }
        /**
         * Gets or sets the right padding to use within the callout. Leaving this NaN will use an automatic value related to the axis label margins.
        */
        get calloutPaddingRight() {
            return this.i.rv;
        }
        set calloutPaddingRight(v) {
            this.i.rv = +v;
        }
        /**
         * Gets or sets the bottom padding to use within the callout. Leaving this NaN will use an automatic value related to the axis label margins.
        */
        get calloutPaddingBottom() {
            return this.i.rt;
        }
        set calloutPaddingBottom(v) {
            this.i.rt = +v;
        }
        /**
         * Gets or sets the strategy to use for avoiding collisions between the callouts in this layer. Leave unset for an automatic value.
        */
        get calloutCollisionMode() {
            return this.i.qm;
        }
        set calloutCollisionMode(v) {
            this.i.qm = ensureEnum(CalloutCollisionMode_$type, v);
        }
        /**
         * Gets or sets the padding to add to the callout positioning. Leave unset for an automatic value.
        */
        get calloutPositionPadding() {
            return this.i.rx;
        }
        set calloutPositionPadding(v) {
            this.i.rx = +v;
        }
        /**
         * Gets or sets the stroke thickness for the callout backing. Leave unset for an automatic value.
        */
        get calloutStrokeThickness() {
            return this.i.ry;
        }
        set calloutStrokeThickness(v) {
            this.i.ry = +v;
        }
        /**
         * Gets or sets the stroke thickness for the axis annotation backing. Leave unset for an automatic value.
        */
        get textStyle() {
            return this.i.s0;
        }
        set textStyle(v) {
            this.i.s0 = v;
        }
        findByName(name) {
            var baseResult = super.findByName(name);
            if (baseResult) {
                return baseResult;
            }
            if (this.targetSeries && this.targetSeries.name && this.targetSeries.name == name) {
                return this.targetSeries;
            }
            return null;
        }
        _styling(container, component, parent) {
            super._styling(container, component, parent);
            this._inStyling = true;
            if (this.targetSeries && this.targetSeries._styling) {
                this.targetSeries._styling(container, component, this);
            }
            this._inStyling = false;
        }
        getItemValue(item, memberPathName) {
            let iv = this.i.hk(item, memberPathName);
            return (iv);
        }
        /**
         * Invalidates content of callout layer
        
        */
        invalidateCalloutContent() {
            this.i.tg();
        }
        /**
         * Event raised when updating style of callout layer
        */
        get calloutStyleUpdating() {
            if (this._calloutStyleUpdating == null) {
                this._calloutStyleUpdating = new EventEmitter();
                this.i.calloutStyleUpdating = delegateCombine(this.i.calloutStyleUpdating, (o, e) => {
                    this._runInZone(() => {
                        let outerArgs = new IgxCalloutStyleUpdatingEventArgs();
                        outerArgs._provideImplementation(e);
                        if (this.beforeCalloutStyleUpdating) {
                            this.beforeCalloutStyleUpdating(this, outerArgs);
                        }
                        this._calloutStyleUpdating.emit({
                            sender: this,
                            args: outerArgs
                        });
                    });
                });
            }
            return this._calloutStyleUpdating;
        }
        /**
         * Raised to allow you to decide on the content for an automatically created callout.
        */
        get calloutContentUpdating() {
            if (this._calloutContentUpdating == null) {
                this._calloutContentUpdating = new EventEmitter();
                this.i.calloutContentUpdating = delegateCombine(this.i.calloutContentUpdating, (o, e) => {
                    this._runInZone(() => {
                        let outerArgs = new IgxCalloutContentUpdatingEventArgs();
                        outerArgs._provideImplementation(e);
                        if (this.beforeCalloutContentUpdating) {
                            this.beforeCalloutContentUpdating(this, outerArgs);
                        }
                        this._calloutContentUpdating.emit({
                            sender: this,
                            args: outerArgs
                        });
                    });
                });
            }
            return this._calloutContentUpdating;
        }
        /**
         * Raised to allow you to decide on the label for an automatically created callout.
        */
        get calloutLabelUpdating() {
            if (this._calloutLabelUpdating == null) {
                this._calloutLabelUpdating = new EventEmitter();
                this.i.calloutLabelUpdating = delegateCombine(this.i.calloutLabelUpdating, (o, e) => {
                    this._runInZone(() => {
                        let outerArgs = new IgxCalloutLabelUpdatingEventArgs();
                        outerArgs._provideImplementation(e);
                        if (this.beforeCalloutLabelUpdating) {
                            this.beforeCalloutLabelUpdating(this, outerArgs);
                        }
                        this._calloutLabelUpdating.emit({
                            sender: this,
                            args: outerArgs
                        });
                    });
                });
            }
            return this._calloutLabelUpdating;
        }
        /**
         * Raised to allow you to select a target series for a data bound callout.
        */
        get calloutSeriesSelecting() {
            if (this._calloutSeriesSelecting == null) {
                this._calloutSeriesSelecting = new EventEmitter();
                this.i.calloutSeriesSelecting = delegateCombine(this.i.calloutSeriesSelecting, (o, e) => {
                    this._runInZone(() => {
                        let outerArgs = new IgxCalloutSeriesSelectingEventArgs();
                        outerArgs._provideImplementation(e);
                        if (this.beforeCalloutSeriesSelecting) {
                            this.beforeCalloutSeriesSelecting(this, outerArgs);
                        }
                        this._calloutSeriesSelecting.emit({
                            sender: this,
                            args: outerArgs
                        });
                    });
                });
            }
            return this._calloutSeriesSelecting;
        }
    }
    IgxCalloutLayerComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.13", ngImport: i0, type: IgxCalloutLayerComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
    IgxCalloutLayerComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "12.2.13", type: IgxCalloutLayerComponent, selector: "igx-callout-layer", inputs: { labelMemberPath: "labelMemberPath", xMemberPath: "xMemberPath", yMemberPath: "yMemberPath", keyMemberPath: "keyMemberPath", isCalloutOffsettingEnabled: "isCalloutOffsettingEnabled", contentMemberPath: "contentMemberPath", targetSeriesName: "targetSeriesName", targetSeries: "targetSeries", collisionChannel: "collisionChannel", isAutoCalloutBehaviorEnabled: "isAutoCalloutBehaviorEnabled", useValueForAutoCalloutLabels: "useValueForAutoCalloutLabels", isCustomCalloutStyleEnabled: "isCustomCalloutStyleEnabled", autoCalloutLabelPrecision: "autoCalloutLabelPrecision", calloutTextColor: "calloutTextColor", calloutBackground: "calloutBackground", calloutInterpolatedValuePrecision: "calloutInterpolatedValuePrecision", calloutOutline: "calloutOutline", calloutLeaderBrush: "calloutLeaderBrush", calloutPaddingLeft: "calloutPaddingLeft", calloutPaddingTop: "calloutPaddingTop", calloutPaddingRight: "calloutPaddingRight", calloutPaddingBottom: "calloutPaddingBottom", calloutCollisionMode: "calloutCollisionMode", calloutPositionPadding: "calloutPositionPadding", calloutStrokeThickness: "calloutStrokeThickness", textStyle: "textStyle" }, outputs: { calloutStyleUpdating: "calloutStyleUpdating", calloutContentUpdating: "calloutContentUpdating", calloutLabelUpdating: "calloutLabelUpdating", calloutSeriesSelecting: "calloutSeriesSelecting" }, providers: [{ provide: IgxAnnotationLayerComponent, useExisting: forwardRef(() => IgxCalloutLayerComponent) }, { provide: IgxSeriesComponent, useExisting: forwardRef(() => IgxCalloutLayerComponent) }], usesInheritance: true, ngImport: i0, template: ``, isInline: true, changeDetection: i0.ChangeDetectionStrategy.OnPush });
    return IgxCalloutLayerComponent;
})();
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.13", ngImport: i0, type: IgxCalloutLayerComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'igx-callout-layer',
                    template: ``,
                    providers: [{ provide: IgxAnnotationLayerComponent, useExisting: forwardRef(() => IgxCalloutLayerComponent) }, { provide: IgxSeriesComponent, useExisting: forwardRef(() => IgxCalloutLayerComponent) }],
                    changeDetection: ChangeDetectionStrategy.OnPush
                }]
        }], ctorParameters: function () { return []; }, propDecorators: { labelMemberPath: [{
                type: Input
            }], xMemberPath: [{
                type: Input
            }], yMemberPath: [{
                type: Input
            }], keyMemberPath: [{
                type: Input
            }], isCalloutOffsettingEnabled: [{
                type: Input
            }], contentMemberPath: [{
                type: Input
            }], targetSeriesName: [{
                type: Input
            }], targetSeries: [{
                type: Input
            }], collisionChannel: [{
                type: Input
            }], isAutoCalloutBehaviorEnabled: [{
                type: Input
            }], useValueForAutoCalloutLabels: [{
                type: Input
            }], isCustomCalloutStyleEnabled: [{
                type: Input
            }], autoCalloutLabelPrecision: [{
                type: Input
            }], calloutTextColor: [{
                type: Input
            }], calloutBackground: [{
                type: Input
            }], calloutInterpolatedValuePrecision: [{
                type: Input
            }], calloutOutline: [{
                type: Input
            }], calloutLeaderBrush: [{
                type: Input
            }], calloutPaddingLeft: [{
                type: Input
            }], calloutPaddingTop: [{
                type: Input
            }], calloutPaddingRight: [{
                type: Input
            }], calloutPaddingBottom: [{
                type: Input
            }], calloutCollisionMode: [{
                type: Input
            }], calloutPositionPadding: [{
                type: Input
            }], calloutStrokeThickness: [{
                type: Input
            }], textStyle: [{
                type: Input
            }], calloutStyleUpdating: [{
                type: Output
            }], calloutContentUpdating: [{
                type: Output
            }], calloutLabelUpdating: [{
                type: Output
            }], calloutSeriesSelecting: [{
                type: Output
            }] } });
//# sourceMappingURL=igx-callout-layer-component.js.map
