import { Component, EventEmitter, Output, Input } from '@angular/core';
import { HorizontalAlignment_$type } from "igniteui-angular-core";
import { UnknownValuePlotting_$type } from "igniteui-angular-core";
import { TrendLineType_$type } from "igniteui-angular-core";
import { IgxChartSeriesEventArgs } from './igx-chart-series-event-args';
import { brushToString, stringToBrush, toBrushCollection, fromBrushCollection, fromRect, toRect, ensureBool, ensureEnum, toSpinal, initializePropertiesFromCss, NamePatcher } from "igniteui-angular-core";
import { MarkerType_$type } from "./MarkerType";
import { delegateCombine } from "igniteui-angular-core";
import { IgxDomainChartSeriesPointerEventArgs } from './igx-domain-chart-series-pointer-event-args';
import { MarkerTypeCollection as MarkerTypeCollection_internal } from './MarkerTypeCollection';
import { IgxMarkerTypeCollection } from './igx-marker-type-collection';
import { SyncableObservableCollection$1 } from "igniteui-angular-core";
import { ToolTipType_$type } from "./ToolTipType";
import { CrosshairsDisplayMode_$type } from "./CrosshairsDisplayMode";
import { IgxCalloutStyleUpdatingEventArgs } from "./igx-callout-style-updating-event-args";
import { ComputedPlotAreaMarginMode_$type } from './ComputedPlotAreaMarginMode';
import { SeriesHighlightingMode_$type } from './SeriesHighlightingMode';
import { SeriesHighlightingBehavior_$type } from './SeriesHighlightingBehavior';
import { LegendHighlightingMode_$type } from './LegendHighlightingMode';
import { SeriesOutlineMode_$type } from './SeriesOutlineMode';
import { MarkerOutlineMode_$type } from './MarkerOutlineMode';
import { MarkerFillMode_$type } from './MarkerFillMode';
import { MarkerAutomaticBehavior_$type } from './MarkerAutomaticBehavior';
import { LegendItemBadgeMode_$type } from './LegendItemBadgeMode';
import { LegendItemBadgeShape_$type } from './LegendItemBadgeShape';
import * as i0 from "@angular/core";
/**
 * Represents a base class for all domain charts that can plot scatter data and shapefiles
*
* ```html
* <igx-category-chart
*       yAxisMinimumValue="0"
*       [dataSource]="data"
*       bottomMargin= 20>
*     </igx-category-chart>
* ```
*/
export let IgxDomainChartComponent = /*@__PURE__*/ (() => {
    class IgxDomainChartComponent {
        constructor() {
            this._calloutsDataSource = null;
            this._markerTypes = null;
            this.__p = null;
            this._hasUserValues = new Set();
            this._stylingContainer = null;
            this._stylingParent = null;
            this._inStyling = false;
            this._seriesAdded = null;
            this._seriesRemoved = null;
            this._seriesPointerEnter = null;
            this._seriesPointerLeave = null;
            this._seriesPointerMove = null;
            this._seriesPointerDown = null;
            this._seriesPointerUp = null;
            this._calloutStyleUpdating = null;
            this._zoneRunner = null;
            if (this._styling) {
                NamePatcher.ensureStylablePatched(Object.getPrototypeOf(this));
            }
            this._implementation = this.createImplementation();
            this._implementation.externalObject = this;
            this.onImplementationCreated();
        }
        createImplementation() {
            return null;
        }
        ngOnInit() {
        }
        get i() {
            return this._implementation;
        }
        onImplementationCreated() {
        }
        /**
        * Sets or gets the template reference to use for tooltips for all the series.
        *
        *
        */
        get tooltipTemplate() {
            return this.i.tooltipTemplate;
        }
        set tooltipTemplate(v) {
            this.i.tooltipTemplate = v;
        }
        /**
        * Sets or gets the template references to use for tooltips for all the series, in order.
        *
        *
        */
        get tooltipTemplates() {
            let ret = [];
            if (this.i.tooltipTemplates) {
                for (let ii = 0; ii < this.i.tooltipTemplates.count; ii++) {
                    ret.push(this.i.tooltipTemplates.item(ii));
                }
            }
            return ret;
        }
        set tooltipTemplates(v) {
            this.i.tooltipTemplates.clear();
            if (v) {
                for (let ii = 0; ii < v.length; ii++) {
                    this.i.tooltipTemplates.add(v[ii]);
                }
            }
        }
        get legend() {
            if (this.i.legend != null)
                return this.i.legend.externalObject;
        }
        set legend(v) {
            if (v != undefined && v != null)
                this.i.legend = v.i;
        }
        set calloutsDataSource(value) {
            this._calloutsDataSource = value;
            this.bindCalloutsData();
        }
        get calloutsDataSource() {
            return this._calloutsDataSource;
        }
        bindCalloutsData() {
            if (this.i != null && this.i !== undefined) {
                this.i.calloutsItemsSource = this._calloutsDataSource;
            }
        }
        /**
     * Gets or sets the scaling value used to affect the pixel density of the control.
     * A higher scaling ratio will produce crisper visuals at the expense of memory.  Lower values will cause the control
     * to appear blurry.
    */
        get pixelScalingRatio() {
            return this.i.ee;
        }
        set pixelScalingRatio(v) {
            this.i.ee = +v;
        }
        /**
         * Gets or sets the left margin of chart title
        *
        *  Use `titleLeftMargin` property for the left margin of chart title.
        *
        * ```html
        * <igx-category-chart
        *     yAxisMinimumValue="0"
        *     [dataSource]="data"
        * 	titleLeftMargin= 10>
        * </igx-category-chart>
        * ```
        *
        * ```ts
        * this.chart.titleLeftMargin = 10;
        * ```
        */
        get titleLeftMargin() {
            return this.i.er;
        }
        set titleLeftMargin(v) {
            this.i.er = +v;
        }
        /**
         * Gets or sets the right margin of chart title
        *
        *  Use `titleLeftMargin` property for the right margin of chart title.
        *
        * ```html
        * <igx-category-chart
        * 		yAxisMinimumValue="0"
        * 		[dataSource]="data"
        * 		titleRightMargin= 10>
        * </igx-category-chart>
        * ```
        *
        * ```ts
        * this.chart.titleRightMargin = 10;
        * ```
        */
        get titleRightMargin() {
            return this.i.es;
        }
        set titleRightMargin(v) {
            this.i.es = +v;
        }
        /**
         * Gets or sets the top margin of chart title
        *
        *  Use `titleTopMargin` property for the top margin of chart title.
        *
        * ```html
        * <igx-category-chart
        *      yAxisMinimumValue="0"
        *      [dataSource]="data"
        *      title="Countries"
        *      titleTopMargin=10 >
        * </igx-category-chart>
        * ```
        *
        * ```ts
        * this.chart.titleTopMargin = 10;
        * ```
        */
        get titleTopMargin() {
            return this.i.et;
        }
        set titleTopMargin(v) {
            this.i.et = +v;
        }
        /**
         * Gets or sets the bottom margin of chart title
        *
        *  Use `titleBottomMargin` property for the bottom margin of chart title.
        *
        * ```html
        * <igx-category-chart
        *    yAxisMinimumValue="0"
        *    [dataSource]="data"
        *    titleBottomMargin= 10 >
        * </igx-category-chart>
        * ```
        *
        * ```ts
        *  this.chart.titleBottomMargin = 5;
        * ```
        */
        get titleBottomMargin() {
            return this.i.eq;
        }
        set titleBottomMargin(v) {
            this.i.eq = +v;
        }
        /**
         * Gets or sets the left margin of chart subtitle
        *
        * Use `subtitleLeftMargin` property for the left margin of chart subtitle.
        *
        * ```html
        * <igx-category-chart
        *     yAxisMinimumValue="0"
        *     [dataSource]="data"
        *     subtitleLeftMargin= 20>
        * </igx-category-chart>
        * ```
        *
        * ```ts
        * this.chart.subtitleLeftMargin = 20 ;
        * ```
        */
        get subtitleLeftMargin() {
            return this.i.em;
        }
        set subtitleLeftMargin(v) {
            this.i.em = +v;
        }
        /**
         * Gets or sets the top margin of chart subtitle
        *
        * Use `subtitleTopMargin` property for the top margin of chart subtitle.
        *
        * ```html
        *    <igx-category-chart
        *       yAxisMinimumValue="0"
        *       [dataSource]="data"
        *       subtitle= "This is a subtitle"
        *       subtitleTopMargin=10>
        *     </igx-category-chart>
        * ```
        *
        * ```ts
        * this.chart.subtitleTopMargin = 10;
        * ```
        */
        get subtitleTopMargin() {
            return this.i.eo;
        }
        set subtitleTopMargin(v) {
            this.i.eo = +v;
        }
        /**
         * Gets or sets the right margin of chart subtitle
        *
        * Use `subtitleRightMargin` property for the right margin of chart subtitle.
        *
        * ```html
        * <igx-category-chart
        *     yAxisMinimumValue="0"
        *     [dataSource]="data"
        *     subtitleRightMargin= 10>
        * </igx-category-chart>
        * ```
        *
        * ```ts
        *  this.chart.subtitleRightMargin = 20 ;
        * ```
        */
        get subtitleRightMargin() {
            return this.i.en;
        }
        set subtitleRightMargin(v) {
            this.i.en = +v;
        }
        /**
         * Gets or sets the bottom margin of chart subtitle
        *
        * Use `subtitleBottomMargin` property for the bottom margin of chart subtitle.
        *
        * ```html
        * <igx-category-chart
        *     yAxisMinimumValue="0"
        *     [dataSource]="data"
        * 	subtitleBottomMargin=10>
        * </igx-category-chart>
        * ```
        *
        * ```ts
        * this.chart.subtitleBottomMargin = 10 ;
        * ```
        */
        get subtitleBottomMargin() {
            return this.i.el;
        }
        set subtitleBottomMargin(v) {
            this.i.el = +v;
        }
        /**
         * Gets or sets color of chart subtitle
        *
        * Use `subtitleTextColor` property to color the subtitle.
        *
        * ```html
        *  <igx-category-chart
        *       yAxisMinimumValue="0"
        *       [dataSource]="data"
        *       subtitle= "This is a subtitle"
        *       subtitleTextColor= 'blue'>
        *     </igx-category-chart>
        * ```
        *
        * ```ts
        * this.chart.subtitleTextColor = "#ff0000" ;
        * ```
        */
        get subtitleTextColor() {
            return brushToString(this.i.lo);
        }
        set subtitleTextColor(v) {
            this.i.lo = stringToBrush(v);
        }
        /**
         * Gets or sets color of chart title
        *
        *  Use `titleTextColor` property to color the chart title
        *
        * ```html
        * <igx-category-chart
        *       yAxisMinimumValue="0"
        *       [dataSource]="data"
        *       titleTextColor= "red">
        * </igx-category-chart>
        * ```
        *
        * ```ts
        *  this.chart.titleTextColor="red" ;
        * ```
        */
        get titleTextColor() {
            return brushToString(this.i.lp);
        }
        set titleTextColor(v) {
            this.i.lp = stringToBrush(v);
        }
        /**
         * Gets or sets the left margin of the chart content.
        *
        * Use the 'leftMargin' property for the left margin of the chart content.
        *
        * ```html
        * <igx-category-chart
        *       yAxisMinimumValue="0"
        *       [dataSource]="data"
        *       leftMargin=20>
        * </igx-category-chart>
        * ```
        *
        * ```ts
        *  this.chart.leftMargin = 20;
        * ```
        */
        get leftMargin() {
            return this.i.eb;
        }
        set leftMargin(v) {
            this.i.eb = +v;
        }
        /**
         * Gets or sets the top margin of the chart content.
        *
        * Use `topMargin` property for the margin of the chart content.
        *
        * ```html
        * <igx-category-chart
        *     yAxisMinimumValue="0"
        *     [dataSource]="data"
        *     topMargin= 20>
        * </igx-category-chart>
        * ```
        *
        * ```ts
        * this.chart.topMargin=20;
        * ```
        */
        get topMargin() {
            return this.i.eu;
        }
        set topMargin(v) {
            this.i.eu = +v;
        }
        /**
         * Gets or sets the right margin of the chart content.
        *
        * Use `rightMargin` property for the right margin of the chart content.
        *
        * ```html
        * <igx-category-chart
        *     yAxisMinimumValue="0"
        *     [dataSource]="data"
        *     rightMargin=20>
        * </igx-category-chart>
        * ```
        *
        * ```ts
        *   this.chart.rightMargin = 20 ;
        * ```
        */
        get rightMargin() {
            return this.i.ek;
        }
        set rightMargin(v) {
            this.i.ek = +v;
        }
        /**
         * Gets or sets the bottom margin around the chart content.
        *
        * Use the `bottomMargin` property for the bottom margin around the chart content.
        *
        * ```html
        * <igx-category-chart
        *       yAxisMinimumValue="0"
        *       [dataSource]="data"
        *       bottomMargin= 20>
        *     </igx-category-chart>
        * ```
        *
        * ```ts
        * this.chart.bottomMargin=20;
        * ```
        */
        get bottomMargin() {
            return this.i.d9;
        }
        set bottomMargin(v) {
            this.i.d9 = +v;
        }
        /**
         * Gets or sets the duration used for animating series plots when the data is changing
        *
        * Use the `transitionDuration` property to animating between data values.
        *
        * ```html
        * <igx-category-chart
        *     yAxisMinimumValue="0"
        *     [dataSource]="data"
        *     transitionDuration="500">
        * </igx-category-chart>
        * ```
        *
        * ```ts
        * this.chart.transitionDuratio= 500;
        * ```
        */
        get transitionDuration() {
            return this.i.e9;
        }
        set transitionDuration(v) {
            this.i.e9 = +v;
        }
        /**
         * Gets or sets the easing function used for animating series plots when the data is changing.
         * This can be set to one of the known values "linear" or "cubic," or it can be set to an easing function which takes a single numeric parameter and returns a number.
        *
        * The 'transitionInEasingFunction' property used for easing function for animating series plots when the chart is loading into view.
        *
        * ```html
        * <igx-category-chart
        *     yAxisMinimumValue="0"
        *     [dataSource]="data"
        *     transitionInEasingFunction= "cubic">
        * </igx-category-chart>
        * ```
        *
        * ```ts
        * this.chart.transitionInEasingFunction=  this.cubicFunc;
        *
        * cubicFunc(time: number) : number
        *   {
        *     return time;
        *   }
        * ```
        */
        get transitionEasingFunction() {
            return this.i.bs;
        }
        set transitionEasingFunction(v) {
            this.i.bs = v;
        }
        /**
         * Gets or sets CSS font property for the chart subtitle
        *
        * Use `subtitleTextStyle` property for the CSS font of the chart subtitle.
        *
        * ```html
        *  <igx-category-chart
        *       yAxisMinimumValue="0"
        *       [dataSource]="data"
        *       subtitle= "This is a subtitle"
        *       subtitleTextStyle ="16pt Verdona">
        *     </igx-category-chart>
        * ```
        *
        * ```ts
        * this.chart.subtitleTextStyle= "16pt Verdona";
        * ```
        */
        get subtitleTextStyle() {
            return this.i.h5;
        }
        set subtitleTextStyle(v) {
            this.i.h5 = v;
        }
        /**
         * Gets or sets CSS font property for the chart title
        *
        * Use `titleTextStyle` property for the CSS font property of the chart title
        *
        * ```html
        *  <igx-category-chart
        *       yAxisMinimumValue="0"
        *       [dataSource]="data"
        *       titleTextStyle= "24pt Verdona">
        *     </igx-category-chart>
        * ```
        *
        * ```ts
        * this.chart.xAxisTitleTextStyle = "24pt Verdona";
        * ```
        */
        get titleTextStyle() {
            return this.i.ih;
        }
        set titleTextStyle(v) {
            this.i.ih = v;
        }
        /**
         * Gets the domain type of this chart
        */
        get domainType() {
            return this.i.ai;
        }
        /**
         * Gets or sets a set of property paths that should be included for consideration by the category chart, leaving the remainder excluded. If null, all properties will be considered.
        *
        * The `includedProperties` property used to include the properties for the consideration of the category chart.
        *
        * ```html
        * <igx-category-chart
        *     yAxisMinimumValue="0"
        *     [dataSource]="data"
        *     includedProperties="ProductName,Cost" >
        * </igx-category-chart>
        * ```
        *
        * ```ts
        * this.chart.includedProperties = ["ProductName", "Cost"];
        * ```
        */
        get includedProperties() {
            return this.i.d;
        }
        set includedProperties(v) {
            if (v && !Array.isArray(v) && typeof (v) == "string") {
                const re = /\s*(?:,|\s|$)\s*/gm;
                v = v.split(re);
            }
            this.i.d = v;
        }
        /**
         * Gets or sets a set of property paths that should be excluded from consideration by the category chart.
        *
        * The `excludedProperties` property used for the property paths that should be excluded from consideration by the category chart.
        *
        * ```html
        * <igx-category-chart
        *     yAxisMinimumValue="0"
        *     [dataSource]="data"
        *     excludedProperties="ID">
        * </igx-category-chart>
        * ```
        *
        * ```ts
        * this.chart.excludedProperties = ["ID", "Discount"];
        * ```
        */
        get excludedProperties() {
            return this.i.c;
        }
        set excludedProperties(v) {
            if (v && !Array.isArray(v) && typeof (v) == "string") {
                const re = /\s*(?:,|\s|$)\s*/gm;
                v = v.split(re);
            }
            this.i.c = v;
        }
        /**
         * Gets or sets the palette of brushes to use for coloring the chart series.
         * The value provided should be an array of CSS color strings or JavaScript objects defining gradients. Optionally the first element can be a string reading "RGB" or "HSV" to specify the interpolation mode of the collection
        *
        * Use the `brushes` property to  set the brushes.
        *
        * ```html
        *  <igx-category-chart
        *       yAxisMinimumValue="0"
        *       [dataSource]="data"
        *       Brushes="#ff0000, #cc0000, #aa0000">
        *     </igx-category-chart>
        * ```
        *
        * ```ts
        * this.chart.brushes = ["#ff0000","#00ff00"];
        * ```
        */
        get brushes() {
            return fromBrushCollection(this.i.n);
        }
        set brushes(v) {
            this.i.n = toBrushCollection(v);
        }
        /**
         * Gets or sets the palette of brushes to use for outlines on the chart series.
         * The value provided should be an array of CSS color strings or JavaScript objects defining gradients. Optionally the first element can be a string reading "RGB" or "HSV" to specify the interpolation mode of the collection
        *
        *  Use the `outlines` property to sets the palette of brushes to use for outlines on the chart series
        *
        * ```html
        * <igx-category-chart
        *     yAxisMinimumValue="0"
        *     [dataSource]="data"
        *     outlines="#ff0000, #cc0000, #aa0000">
        * </igx-category-chart>
        * ```
        */
        get outlines() {
            return fromBrushCollection(this.i.r);
        }
        set outlines(v) {
            this.i.r = toBrushCollection(v);
        }
        /**
         * Gets the actual palette of brushes to use for coloring the chart series.
        */
        get actualBrushes() {
            return fromBrushCollection(this.i.l);
        }
        set actualBrushes(v) {
            this.i.l = toBrushCollection(v);
        }
        /**
         * Gets the actual palette of brushes to use for outlines on the chart series.
        */
        get actualOutlines() {
            return fromBrushCollection(this.i.m);
        }
        set actualOutlines(v) {
            this.i.m = toBrushCollection(v);
        }
        /**
         * Gets or sets whether the chart can be horizontally zoomed through user interactions.
        *
        * Use the `isHorizontalZoomEnabled` property to allow chart horizontally zoomed .
        *
        * ```html
        *  <igx-category-chart
        *       yAxisMinimumValue="0"
        *       [dataSource]="data"
        *       isHorizontalZoomEnabled=true>
        *   </igx-category-chart>
        * ```
        *
        * ```ts
        * this.chart.isHorizontalZoomEnabled = true;
        * ```
        */
        get isHorizontalZoomEnabled() {
            return this.i.cn;
        }
        set isHorizontalZoomEnabled(v) {
            this.i.cn = ensureBool(v);
        }
        /**
         * Gets or sets whether the chart can be vertically zoomed through user interactions.
        *
        * Use the `isVerticalZoomEnabled` property to allow chart zoom vertically.
        *
        * ```html
        *  <igx-category-chart
        *       yAxisMinimumValue="0"
        *       [dataSource]="data"
        *       isVerticalZoomEnabled=true>
        *     </igx-category-chart>
        * ```
        *
        * ```ts
        *  this.chart.isVerticalZoomEnabled = true;
        * ```
        */
        get isVerticalZoomEnabled() {
            return this.i.ct;
        }
        set isVerticalZoomEnabled(v) {
            this.i.ct = ensureBool(v);
        }
        /**
         * Gets or sets whether the chart should display mock data when the data source has not been provided, if supported for this type of chart.
        */
        get shouldDisplayMockData() {
            return this.i.cw;
        }
        set shouldDisplayMockData(v) {
            this.i.cw = ensureBool(v);
        }
        /**
         * Gets or sets whether the chart should use a faded skeleton style for mock data.
        */
        get shouldUseSkeletonStyleForMockData() {
            return this.i.cx;
        }
        set shouldUseSkeletonStyleForMockData(v) {
            this.i.cx = ensureBool(v);
        }
        /**
         * Gets or sets whether the chart can highlight series through user interactions.
         * This property applies to Category Chart and Financial Chart controls.
        */
        get isSeriesHighlightingEnabled() {
            return this.i.cp;
        }
        set isSeriesHighlightingEnabled(v) {
            this.i.cp = ensureBool(v);
        }
        /**
         * Gets or sets the rectangle representing the current scroll and zoom state of the chart.
         * WindowRect is expressed as a Rectangle with coordinates and sizes between 0 and 1.
        *
        * Use `windowRect` property representing the current scroll and zoom state of the chart.
        *
        * ```html
        * <igx-category-chart
        *       yAxisMinimumValue="0"
        *       [dataSource]="data"
        *       WindowRect=[0,0,1,1]>
        * </igx-category-chart>
        * ```
        *
        * ```ts
        * this.chart.windowRect =[0,0,1,1];
        * ```
        */
        get windowRect() {
            return fromRect(this.i.lt);
        }
        set windowRect(v) {
            this.i.lt = toRect(v);
        }
        /**
         * Gets a rectangle representing the bounds of the plot area.
        *
        * `viewport` property representing the bounds of the plot area.
        *
        * ```ts
        * let viewport:Rect =  this.chart.viewport;
        * ```
        */
        get viewport() {
            return fromRect(this.i.ls);
        }
        /**
         * Gets or sets text to display above the plot area.
        *
        * Use the `chartTitle` property to display the text above the plot area.
        *
        * ```html
        * <igx-category-chart
        *     yAxisMinimumValue="0"
        *     [dataSource]="data"
        *     title="This is a Title">
        * </igx-category-chart>
        * ```
        *
        * ```ts
        *  this.chart.title= "This is a Title";
        * ```
        */
        get chartTitle() {
            return this.i.h9;
        }
        set chartTitle(v) {
            this.i.h9 = v;
        }
        /**
         * Gets or sets text to display below the Title, above the plot area.
        *
        * Use the `subtitle` property to display the text below  and above the plot area.
        *
        * ```html
        * <igx-category-chart
        *     yAxisMinimumValue="0"
        *     [dataSource]="data"
        *     subtitle= "This is a subtitle">
        * </igx-category-chart>
        * ```
        *
        * ```ts
        *  this.chart.subtitle ="CategoryChart Subtitle" ;
        * ```
        */
        get subtitle() {
            return this.i.hy;
        }
        set subtitle(v) {
            this.i.hy = v;
        }
        /**
         * Gets or sets horizontal alignment which determines the title position, relative to the left and right edges of the control.
        *
        * Use the `titleAlignment` property for the horizontal alignment of the title.
        *
        * ```html
        * <igx-category-chart
        *     yAxisMinimumValue="0"
        *     [dataSource]="data"
        *     titleAlignment= "center">
        * </igx-category-chart>
        * ```
        *
        * ```ts
        * this.chart.titleAlignment = HorizontalAlignment.Center;
        * ```
        */
        get titleAlignment() {
            return this.i.k0;
        }
        set titleAlignment(v) {
            this.i.k0 = ensureEnum(HorizontalAlignment_$type, v);
        }
        /**
         * Gets or sets horizontal alignment which determines the subtitle position, relative to the left and right edges of the control.
        *
        * Use the `subtitleAlignment` property to Gets or sets horizontal alignment.
        *
        * ```html
        * <igx-category-chart
        *     yAxisMinimumValue="0"
        *     [dataSource]="data"
        *     subtitleAlignment= "center">
        * </igx-category-chart>
        * ```
        *
        * ```ts
        * this.chart.subtitleAlignment = HorizontalAlignment.Right;
        * ```
        */
        get subtitleAlignment() {
            return this.i.kz;
        }
        set subtitleAlignment(v) {
            this.i.kz = ensureEnum(HorizontalAlignment_$type, v);
        }
        /**
         * Gets or sets the behavior that determines how unknown values will be plotted on the chart.
         * Null and Double.NaN are two examples of unknown values.
        *
        * Use the `unknownValuePlotting` property to determines the behavior that how unknown values will be plotted on the chart.
        *
        * ```html
        * <igx-category-chart
        *       yAxisMinimumValue="0"
        *       [dataSource]="data"
        *       unknownValuePlotting= "dontPlot">
        * </igx-category-chart>
        * ```
        *
        * ```ts
        * this.chart.unknownValuePlotting =UnknownValuePlotting.DontPlot;
        * ```
        */
        get unknownValuePlotting() {
            return this.i.bo;
        }
        set unknownValuePlotting(v) {
            this.i.bo = ensureEnum(UnknownValuePlotting_$type, v);
        }
        /**
         * Gets or sets the rendering resolution for all series in this chart.
         * Where n = Resolution, for every n horizontal pixels, combine all items into a single data point.  When Resolution = 0, all data points will be rendered as graphical objects.  Charts with a higher resolution will have faster performance.
        *
        * Use the `resolution` property if the callouts should be display.
        *
        * ```html
        * <igx-category-chart
        *     yAxisMinimumValue="0"
        *     [dataSource]="data"
        *     resolution= 2>
        * </igx-category-chart>
        * ```
        *
        * ```ts
        *   this.chart.resolution = 2 ;
        * ```
        */
        get resolution() {
            return this.i.ej;
        }
        set resolution(v) {
            this.i.ej = +v;
        }
        /**
         * Gets or sets the thickness for all series in this chart. Depending on the ChartType, this can be the main brush used, or just the outline.
        *
        * Use the `thickness` property for the thickness of all the series in this chart.
        *
        * ```html
        * <igx-category-chart
        *     yAxisMinimumValue="0"
        *     [dataSource]="data"
        *     thickness=5>
        * </igx-category-chart>
        * ```
        */
        get thickness() {
            return this.i.ep;
        }
        set thickness(v) {
            this.i.ep = +v;
        }
        /**
         * Gets or sets the OutlineMode for all series in this chart.
        */
        get outlineMode() {
            return this.i.bi;
        }
        set outlineMode(v) {
            this.i.bi = ensureEnum(SeriesOutlineMode_$type, v);
        }
        /**
         * Gets or sets the MarkerOutlineMode for all series that support markers in this chart.
        */
        get markerOutlineMode() {
            return this.i.a0;
        }
        set markerOutlineMode(v) {
            this.i.a0 = ensureEnum(MarkerOutlineMode_$type, v);
        }
        /**
         * Gets or sets the MarkerFillMode for all series that support markers in this chart.
        */
        get markerFillMode() {
            return this.i.ay;
        }
        set markerFillMode(v) {
            this.i.ay = ensureEnum(MarkerFillMode_$type, v);
        }
        /**
         * Gets or sets the Marker Fill Opacity for all series that support markers in this chart.
        */
        get markerFillOpacity() {
            return this.i.ec;
        }
        set markerFillOpacity(v) {
            this.i.ec = +v;
        }
        /**
         * Gets or sets the Marker Thickness for all series that support markers in this chart.
        */
        get markerThickness() {
            return this.i.ed;
        }
        set markerThickness(v) {
            this.i.ed = +v;
        }
        /**
         * Gets or sets the marker shapes used for indicating location of data points in this chart.
         * This property applies only to these chart types: point, line, spline, bubble, and polygon
        */
        get markerTypes() {
            if (this._markerTypes === null) {
                let coll = new IgxMarkerTypeCollection();
                let innerColl = this.i.a5;
                if (!innerColl) {
                    innerColl = new MarkerTypeCollection_internal();
                }
                this._markerTypes = coll._fromInner(innerColl);
                this.i.a5 = innerColl;
            }
            return this._markerTypes;
        }
        set markerTypes(v) {
            if (this._markerTypes !== null) {
                this._markerTypes._setSyncTarget(null);
                this._markerTypes = null;
            }
            let coll = new IgxMarkerTypeCollection();
            this._markerTypes = coll._fromOuter(v);
            let syncColl = new SyncableObservableCollection$1(MarkerType_$type);
            let innerColl = this.i.a5;
            if (!innerColl) {
                innerColl = new MarkerTypeCollection_internal();
            }
            syncColl._inner = innerColl;
            syncColl.clear();
            this._markerTypes._setSyncTarget(syncColl);
            this.i.a5 = innerColl;
        }
        /**
         * Gets or sets the default marker type for all series plotted in this chart.
         * This property is ignored when the MarkerTypes property is set
        */
        get markerAutomaticBehavior() {
            return this.i.aw;
        }
        set markerAutomaticBehavior(v) {
            this.i.aw = ensureEnum(MarkerAutomaticBehavior_$type, v);
        }
        /**
         * Gets or sets the palette of brushes used for rendering fill area of data point markers.
         * This property applies only to these chart types: point, line, spline, bubble, and polygon
        *
        * `markerBrushes` property used for rendering fill area of data point markers.
        *
        * ```html
        * <igx-category-chart
        *     yAxisMinimumValue="0"
        *     [dataSource]="data"
        *     markerBrushes="#ff0000, #cc0000, #aa0000">
        * </igx-category-chart>
        * ```
        *
        * ```ts
        *  this.chart.markerBrushes=[ "#ff0000", "#ffff00", "#00ffff" ];
        * ```
        */
        get markerBrushes() {
            return fromBrushCollection(this.i.p);
        }
        set markerBrushes(v) {
            this.i.p = toBrushCollection(v);
        }
        /**
         * Gets or sets the palette of brushes used for rendering outlines of data point markers.
         * This property applies only to these chart types: point, line, spline, bubble, and polygon
        *
        * `markerOutlines` property used for rendering outlines of data point markers.
        *
        * ```html
        * <igx-category-chart
        *     yAxisMinimumValue="0"
        *     [dataSource]="data"
        *     markerOutlines="#ff0000, #cc0000, #aa0000">
        * </igx-category-chart>
        * ```
        *
        * ```ts
        * this.chart.markerOutlines= ["#ff0000", "#ffff00", "#00ffff"] ;
        * ```
        */
        get markerOutlines() {
            return fromBrushCollection(this.i.q);
        }
        set markerOutlines(v) {
            this.i.q = toBrushCollection(v);
        }
        /**
         * Gets or sets the maximum number of markers displayed in the plot area of the chart.
        *
        * `markerMaxCount` property used to display maximum number of markers in the plot area of the chart.
        *
        * ```html
        * <igx-category-chart
        *     yAxisMinimumValue="0"
        *     [dataSource]="data"
        *     markerMaxCount=100 >
        * </igx-category-chart>
        * ```
        *
        * ```ts
        *  this.chart.markerMaxCount = 100 ;
        * ```
        */
        get markerMaxCount() {
            return this.i.e8;
        }
        set markerMaxCount(v) {
            this.i.e8 = +v;
        }
        /**
         * Gets or sets the fill opacity for all series that have area visuals in this chart.
         * For example, Area, SplineArea, Column chart types
        */
        get areaFillOpacity() {
            return this.i.d6;
        }
        set areaFillOpacity(v) {
            this.i.d6 = +v;
        }
        /**
         * Gets or sets whether the series animations should be allowed when a range change has been detected on an axis.
        */
        get animateSeriesWhenAxisRangeChanges() {
            return this.i.ca;
        }
        set animateSeriesWhenAxisRangeChanges(v) {
            this.i.ca = ensureBool(v);
        }
        /**
         * Gets or sets the palette of brushes to used for coloring trend lines in this chart.
         * The value provided should be an array of CSS color strings or JavaScript objects defining gradients. Optionally the first element can be a string reading "RGB" or "HSV" to specify the interpolation mode of the collection
        *
        * Use the `trendLineBrushes` property for coloring trend lines in the chart.
        *
        * ```html
        * <igx-category-chart
        *     yAxisMinimumValue="0"
        *     [dataSource]="data"
        *     trendLineBrushes="#ff0000,#aa0000">
        * </igx-category-chart>
        * ```
        *
        * ```ts
        * this.chart.trendLineBrushes=["#ff0000", "#ffff00", "#00ffff"]	;
        * ```
        */
        get trendLineBrushes() {
            return fromBrushCollection(this.i.t);
        }
        set trendLineBrushes(v) {
            this.i.t = toBrushCollection(v);
        }
        /**
         * Gets or sets the formula used for calculating trend lines in this chart.
         * This property applies only to these chart types: point, line, spline, and bubble
        *
        * Use the `trendLineType` property for calculating trend lines.
        *
        * ```html
        * <igx-category-chart
        *       yAxisMinimumValue="0"
        *       [dataSource]="data"
        *       trendLineType= "cubicFit">
        * </igx-category-chart>
        * ```
        *
        * ```ts
        * this.chart.trendLineType = TrendLineType.CubicFit;
        * ```
        */
        get trendLineType() {
            return this.i.bm;
        }
        set trendLineType(v) {
            this.i.bm = ensureEnum(TrendLineType_$type, v);
        }
        /**
         * Gets or sets the thickness of the trend lines in this chart.
         * This property applies only to these chart types: point, line, spline, and bubble
        *
        * Use the `trendLineThickness` property for the thickness of the trend lines in the chart.
        *
        * ```html
        * <igx-category-chart
        *     yAxisMinimumValue="0"
        *     [dataSource]="data"
        *     trendLineThickness= 2>
        * </igx-category-chart>
        * ```
        *
        * ```ts
        * this.chart.trendLineThickness=2;
        * ```
        */
        get trendLineThickness() {
            return this.i.ev;
        }
        set trendLineThickness(v) {
            this.i.ev = +v;
        }
        /**
         * Gets or sets a value indicating whether grid and tick lines are aligned to device pixels.
        *
        * Use `alignsGridLinesToPixels` propert to indicat whether grid and tick lines are aligned to device pixels.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     AlignsGridLinesToPixels="true">
        * </igx-category-chart>
        * ```
        *
        * ```ts
        *  this.chart.alignsGridLinesToPixels= true;
        * ```
        */
        get alignsGridLinesToPixels() {
            return this.i.b9;
        }
        set alignsGridLinesToPixels(v) {
            this.i.b9 = ensureBool(v);
        }
        /**
         * Margin applied to the Left of the plot area.
        */
        get plotAreaMarginLeft() {
            return this.i.eg;
        }
        set plotAreaMarginLeft(v) {
            this.i.eg = +v;
        }
        /**
         * Margin applied to the Top of the plot area.
        */
        get plotAreaMarginTop() {
            return this.i.ei;
        }
        set plotAreaMarginTop(v) {
            this.i.ei = +v;
        }
        /**
         * Margin applied to the right of the plot area.
        */
        get plotAreaMarginRight() {
            return this.i.eh;
        }
        set plotAreaMarginRight(v) {
            this.i.eh = +v;
        }
        /**
         * Margin applied below the plot area.
        */
        get plotAreaMarginBottom() {
            return this.i.ef;
        }
        set plotAreaMarginBottom(v) {
            this.i.ef = +v;
        }
        /**
         * Gets or sets the highlighting mode to use for the series in the component, when supported. This takes precedence over the series level IsHightlightingEnabled.
        */
        get computedPlotAreaMarginMode() {
            return this.i.y;
        }
        set computedPlotAreaMarginMode(v) {
            this.i.y = ensureEnum(ComputedPlotAreaMarginMode_$type, v);
        }
        /**
         * Gets or sets the highlighting mode to use for the series in the component, when supported. This takes precedence over the series level IsHightlightingEnabled.
        */
        get highlightingMode() {
            return this.i.bg;
        }
        set highlightingMode(v) {
            this.i.bg = ensureEnum(SeriesHighlightingMode_$type, v);
        }
        /**
         * Gets or sets the highlighting Behavior to use for the series in the component, when supported. This takes precedence over the series level IsHightlightingEnabled.
        */
        get highlightingBehavior() {
            return this.i.be;
        }
        set highlightingBehavior(v) {
            this.i.be = ensureEnum(SeriesHighlightingBehavior_$type, v);
        }
        /**
         * Gets or sets the highlighting mode to use for the legend linked to the component, when supported.
        */
        get legendHighlightingMode() {
            return this.i.aq;
        }
        set legendHighlightingMode(v) {
            this.i.aq = ensureEnum(LegendHighlightingMode_$type, v);
        }
        /**
         * Gets or sets the type of legend badges representing all series displayed in a legend linked to this component
         * This property will be ignored when the LegendItemTemplate or LegendItemBadgeTemplate property is set on a series
        */
        get legendItemBadgeShape() {
            return this.i.au;
        }
        set legendItemBadgeShape(v) {
            this.i.au = ensureEnum(LegendItemBadgeShape_$type, v);
        }
        /**
         * Gets or sets the mode of legend badges representing all series displayed in a legend linked to this component.
         * This property will be ignored when the LegendItemTemplate or LegendItemBadgeTemplate property is set on a series
        */
        get legendItemBadgeMode() {
            return this.i.as;
        }
        set legendItemBadgeMode(v) {
            this.i.as = ensureEnum(LegendItemBadgeMode_$type, v);
        }
        /**
         * Gets or sets a whether the series viewer should auto expand margins to accommodate the initial horizontal axis labels.
        */
        get shouldAutoExpandMarginForInitialLabels() {
            return this.i.cv;
        }
        set shouldAutoExpandMarginForInitialLabels(v) {
            this.i.cv = ensureBool(v);
        }
        /**
         * Gets or sets the extra amount the series viewer should auto expand margins to accommodate the initial horizontal axis labels.
        */
        get autoExpandMarginExtraPadding() {
            return this.i.d7;
        }
        set autoExpandMarginExtraPadding(v) {
            this.i.d7 = +v;
        }
        /**
         * Gets or sets the maximum amount the series viewer should auto expand margins to accommodate the initial horizontal axis labels.
        */
        get autoExpandMarginMaximumValue() {
            return this.i.d8;
        }
        set autoExpandMarginMaximumValue(v) {
            this.i.d8 = +v;
        }
        get trendLinePeriod() {
            return this.i.fa;
        }
        set trendLinePeriod(v) {
            this.i.fa = +v;
        }
        /**
         * Gets or sets the style of tooltip to be displayed.
        */
        get toolTipType() {
            return this.i.bk;
        }
        set toolTipType(v) {
            this.i.bk = ensureEnum(ToolTipType_$type, v);
        }
        /**
         * Gets or sets the crosshairs to be displayed.
        */
        get crosshairsDisplayMode() {
            return this.i.aa;
        }
        set crosshairsDisplayMode(v) {
            this.i.aa = ensureEnum(CrosshairsDisplayMode_$type, v);
        }
        /**
         * Gets or sets whether crosshairs will snap to the nearest data point.
        */
        get crosshairsSnapToData() {
            return this.i.cf;
        }
        set crosshairsSnapToData(v) {
            this.i.cf = ensureBool(v);
        }
        /**
         * Gets or sets the color to apply to vertical crosshairs line.
        */
        get crosshairsLineVerticalStroke() {
            return brushToString(this.i.lg);
        }
        set crosshairsLineVerticalStroke(v) {
            this.i.lg = stringToBrush(v);
        }
        /**
         * Gets or sets thickness of crosshairs lines.
        */
        get crosshairsLineThickness() {
            return this.i.ea;
        }
        set crosshairsLineThickness(v) {
            this.i.ea = +v;
        }
        /**
         * Gets or sets the color to apply to horizontal crosshairs line.
        */
        get crosshairsLineHorizontalStroke() {
            return brushToString(this.i.lf);
        }
        set crosshairsLineHorizontalStroke(v) {
            this.i.lf = stringToBrush(v);
        }
        /**
         * Gets or sets whether annotations are shown along the axis for crosshair values
        */
        get crosshairsAnnotationEnabled() {
            return this.i.ce;
        }
        set crosshairsAnnotationEnabled(v) {
            this.i.ce = ensureBool(v);
        }
        /**
         * Gets or sets the background of crosshair annotation on x-axis.
        */
        get crosshairsAnnotationXAxisBackground() {
            return brushToString(this.i.lb);
        }
        set crosshairsAnnotationXAxisBackground(v) {
            this.i.lb = stringToBrush(v);
        }
        /**
         * Gets or sets the background of crosshair annotation on y-axis.
        */
        get crosshairsAnnotationYAxisBackground() {
            return brushToString(this.i.ld);
        }
        set crosshairsAnnotationYAxisBackground(v) {
            this.i.ld = stringToBrush(v);
        }
        /**
         * Gets or sets the text color of crosshair annotation on x-axis.
        */
        get crosshairsAnnotationXAxisTextColor() {
            return brushToString(this.i.lc);
        }
        set crosshairsAnnotationXAxisTextColor(v) {
            this.i.lc = stringToBrush(v);
        }
        /**
         * Gets or sets the text color of crosshair annotation on y-axis.
        */
        get crosshairsAnnotationYAxisTextColor() {
            return brushToString(this.i.le);
        }
        set crosshairsAnnotationYAxisTextColor(v) {
            this.i.le = stringToBrush(v);
        }
        /**
         * Gets or sets precision on interpolated values of crosshairs on x-axis.
        */
        get crosshairsAnnotationXAxisPrecision() {
            return this.i.e5;
        }
        set crosshairsAnnotationXAxisPrecision(v) {
            this.i.e5 = +v;
        }
        /**
         * Gets or sets precision on interpolated values of crosshairs on y-axis.
        */
        get crosshairsAnnotationYAxisPrecision() {
            return this.i.e6;
        }
        set crosshairsAnnotationYAxisPrecision(v) {
            this.i.e6 = +v;
        }
        /**
         * Gets or sets whether annotations for the final value of each series is displayed on the axis.
        */
        get finalValueAnnotationsVisible() {
            return this.i.cg;
        }
        set finalValueAnnotationsVisible(v) {
            this.i.cg = ensureBool(v);
        }
        /**
         * Gets or sets the background of final value annotation.
        */
        get finalValueAnnotationsBackground() {
            return brushToString(this.i.lh);
        }
        set finalValueAnnotationsBackground(v) {
            this.i.lh = stringToBrush(v);
        }
        /**
         * Gets or sets the text color of final value annotation.
        */
        get finalValueAnnotationsTextColor() {
            return brushToString(this.i.li);
        }
        set finalValueAnnotationsTextColor(v) {
            this.i.li = stringToBrush(v);
        }
        /**
         * Gets or sets precision on final value annotation.
        */
        get finalValueAnnotationsPrecision() {
            return this.i.e7;
        }
        set finalValueAnnotationsPrecision(v) {
            this.i.e7 = +v;
        }
        /**
         * Gets or sets if callouts should be displayed.
        */
        get calloutsVisible() {
            return this.i.cd;
        }
        set calloutsVisible(v) {
            this.i.cd = ensureBool(v);
        }
        /**
         * Gets or sets if event annotations should be displayed.
        */
        get calloutStyleUpdatingEventEnabled() {
            return this.i.cc;
        }
        set calloutStyleUpdatingEventEnabled(v) {
            this.i.cc = ensureBool(v);
        }
        /**
         * Gets or sets the member path of the X data for the callouts.
        */
        get calloutsXMemberPath() {
            return this.i.gb;
        }
        set calloutsXMemberPath(v) {
            this.i.gb = v;
        }
        /**
         * Gets or sets the member path of the Y data for the callouts.
        */
        get calloutsYMemberPath() {
            return this.i.gd;
        }
        set calloutsYMemberPath(v) {
            this.i.gd = v;
        }
        /**
         * Gets or sets the member path of the label data for the callouts.
        */
        get calloutsLabelMemberPath() {
            return this.i.f7;
        }
        set calloutsLabelMemberPath(v) {
            this.i.f7 = v;
        }
        /**
         * Gets or sets the member path of the content data for the callouts.
        */
        get calloutsContentMemberPath() {
            return this.i.f4;
        }
        set calloutsContentMemberPath(v) {
            this.i.f4 = v;
        }
        findByName(name) {
            if (this.legend && this.legend.name && this.legend.name == name) {
                return this.legend;
            }
            if (this.markerTypes != null && this.markerTypes.findByName && this.markerTypes.findByName(name)) {
                return this.markerTypes.findByName(name);
            }
            return null;
        }
        get hasUserValues() {
            return this._hasUserValues;
        }
        __m(propertyName) {
            if (!this._inStyling) {
                this._hasUserValues.add(propertyName);
            }
        }
        _styling(container, component, parent) {
            if (this._inStyling) {
                return;
            }
            this._inStyling = true;
            this._stylingContainer = container;
            this._stylingParent = component;
            let genericPrefix = "";
            let typeName = this.i.$type.name;
            if (typeName.indexOf("Xam") === 0) {
                typeName = typeName.substring(3);
            }
            genericPrefix = toSpinal("DomainChartComponent");
            let additionalPrefixes = [];
            let prefix = toSpinal(typeName);
            additionalPrefixes.push(prefix + "-");
            let b = this.i.$type.baseType;
            while (b && b.name != "Object" &&
                b.name != "Base" &&
                b.name != "Control" &&
                b.Name != "DependencyObject" &&
                b.Name != "FrameworkElement") {
                typeName = b.name;
                if (typeName.indexOf("Xam") === 0) {
                    typeName = typeName.substring(3);
                }
                let basePrefix = toSpinal(typeName);
                additionalPrefixes.push(basePrefix + "-");
                b = b.baseType;
            }
            if (parent) {
                let parentTypeName = parent.i.$type.name;
                if (parentTypeName.indexOf("Xam") === 0) {
                    parentTypeName = parentTypeName.substring(3);
                }
                let parentPrefix = toSpinal(parentTypeName);
                additionalPrefixes.push(parentPrefix + "-" + genericPrefix + "-");
                additionalPrefixes.push(parentPrefix + "-" + prefix + "-");
            }
            initializePropertiesFromCss(container, this, genericPrefix + "-", this.hasUserValues, false, additionalPrefixes);
            if (this._otherStyling) {
                this._otherStyling(container, component, parent);
            }
            this._inStyling = false;
        }
        /**
     * Provides a container for this control
    
    *
    * `provideContainer` method provide container for the control.
    *
    * ```ts
    *     this.chart.provideContainer("Container");
    * ```
    */
        provideContainer(container) {
            this.i.provideContainer(container);
        }
        /**
         * Destroy this control
        
        *
        * Use the `destroy` property to destroy the chart.
        *
        * ```ts
        * this.chart.destroy();
        * ```
        */
        destroy() {
            this.i.destroy();
        }
        /**
         * Called when the control has been resized.
        
        *
        * `notifyResized` method Called when the control has been resized.
        *
        * ```ts
        * this.chart.notifyResized();
        * ```
        */
        notifyResized() {
            this.i.notifyResized();
        }
        notifyVisualPropertiesChanged() {
            this.i.jx();
        }
        /**
         * Forces any pending refresh to the chart to be finished.
        
        *
        * Method `flush` used to Forces any pending deferred work to render on the chart before continuing.
        *
        * ```ts
        * this.chart.flush();
        * ```
        */
        flush() {
            this.i.i5();
        }
        /**
         * Hides the active main tooltip, if displayed.
        
        *
        * Use the `hideToolTip` method to hide the active tooltip.
        *
        * ```ts
        * this.chart.hideToolTip();
        * ```
        */
        hideToolTip() {
            this.i.jc();
        }
        /**
         * Replays transition-in animation on all series in the chart.
        
        */
        replayTransitionIn() {
            this.i.km();
        }
        notifySetItem(source_, index, oldItem, newItem) {
            this.i.jw(source_, index, oldItem, newItem);
        }
        /**
         * Used to manually notify the chart that the data source has reset or cleared its items.
        
        *
        * Use `notifyClearItems` method to notifies the chart that the items have been cleared from an associated data source.
        *
        * ```ts
        * this.chart.notifyClearItems(this.data);
        * ```
        */
        notifyClearItems(source_) {
            this.i.js(source_);
        }
        notifyInsertItem(source_, index, newItem) {
            this.i.jt(source_, index, newItem);
        }
        notifyRemoveItem(source_, index, oldItem) {
            this.i.ju(source_, index, oldItem);
        }
        /**
         * Event raised when a series is initialized and added to this chart.
        *
        * `SeriesAdded` event raised when a series is initialized and added to this chart.
        *
        * ```html
        *  <igx-category-chart
        *       yAxisMinimumValue="0"
        *       [dataSource]="data"
        *       (seriesAdded)="CategoryChart_SeriesAdded()"
        *      >
        * </igx-category-chart>
        * ```
        */
        get seriesAdded() {
            if (this._seriesAdded == null) {
                this._seriesAdded = new EventEmitter();
                this.i.seriesAdded = delegateCombine(this.i.seriesAdded, (o, e) => {
                    this._runInZone(() => {
                        let outerArgs = new IgxChartSeriesEventArgs();
                        outerArgs._provideImplementation(e);
                        if (this.beforeSeriesAdded) {
                            this.beforeSeriesAdded(this, outerArgs);
                        }
                        this._seriesAdded.emit({
                            sender: this,
                            args: outerArgs
                        });
                    });
                });
            }
            return this._seriesAdded;
        }
        /**
         * Event raised when a series is removed from this chart.
        *
        * `SeriesRemoved` event raised when a series is removed from this chart.
        *
        * ```html
        * <igx-category-chart
        *       yAxisMinimumValue="0"
        *       [dataSource]="data"
        *       (seriesRemoved)="CategoryChart_seriesRemoved()">
        * </igx-category-chart>
        * ```
        *
        * ```ts
        *  CategoryChart_seriesRemoved(sender: any , aregs: ChartSeriesEventArgs)
        *   {
        *
        *   }
        * ```
        */
        get seriesRemoved() {
            if (this._seriesRemoved == null) {
                this._seriesRemoved = new EventEmitter();
                this.i.seriesRemoved = delegateCombine(this.i.seriesRemoved, (o, e) => {
                    this._runInZone(() => {
                        let outerArgs = new IgxChartSeriesEventArgs();
                        outerArgs._provideImplementation(e);
                        if (this.beforeSeriesRemoved) {
                            this.beforeSeriesRemoved(this, outerArgs);
                        }
                        this._seriesRemoved.emit({
                            sender: this,
                            args: outerArgs
                        });
                    });
                });
            }
            return this._seriesRemoved;
        }
        /**
         * Occurs when the pointer enters a Series.
        *
        * `SeriesPointerEnter` event raised when the pointer enters a Series.
        *
        * ```html
        * <igx-category-chart
        *       yAxisMinimumValue="0"
        *       [dataSource]="data"
        *       (seriesPointerEnter)="CategoryChart_seriesPointerEnter()" >
        * </igx-category-chart>
        * ```
        *
        * ```ts
        * CategoryChart_seriesPointerEnter(sender: any , aregs: ChartSeriesEventArgs)
        *   {
        *
        *   }
        * ```
        */
        get seriesPointerEnter() {
            if (this._seriesPointerEnter == null) {
                this._seriesPointerEnter = new EventEmitter();
                this.i.seriesPointerEnter = delegateCombine(this.i.seriesPointerEnter, (o, e) => {
                    this._runInZone(() => {
                        let outerArgs = new IgxDomainChartSeriesPointerEventArgs();
                        outerArgs._provideImplementation(e);
                        if (this.beforeSeriesPointerEnter) {
                            this.beforeSeriesPointerEnter(this, outerArgs);
                        }
                        this._seriesPointerEnter.emit({
                            sender: this,
                            args: outerArgs
                        });
                    });
                });
            }
            return this._seriesPointerEnter;
        }
        /**
         * Occurs when the pointer leaves a Series.
        *
        * `SeriesPointerLeave` event raised when the pointer leaves a Series.
        *
        * ```html
        * <igx-category-chart
        *       yAxisMinimumValue="0"
        *       [dataSource]="data"
        *       (seriesPointerLeave)= "CategoryChart_seriesPointerLeave()" >
        * </igx-category-chart>
        * ```
        *
        * ```ts
        * CategoryChart_seriesPointerLeave(sender: any , aregs: ChartSeriesEventArgs)
        *   {
        *
        *   }
        * ```
        */
        get seriesPointerLeave() {
            if (this._seriesPointerLeave == null) {
                this._seriesPointerLeave = new EventEmitter();
                this.i.seriesPointerLeave = delegateCombine(this.i.seriesPointerLeave, (o, e) => {
                    this._runInZone(() => {
                        let outerArgs = new IgxDomainChartSeriesPointerEventArgs();
                        outerArgs._provideImplementation(e);
                        if (this.beforeSeriesPointerLeave) {
                            this.beforeSeriesPointerLeave(this, outerArgs);
                        }
                        this._seriesPointerLeave.emit({
                            sender: this,
                            args: outerArgs
                        });
                    });
                });
            }
            return this._seriesPointerLeave;
        }
        /**
         * Occurs when the pointer moves over a Series.
        *
        * `SeriesPointerMove` event raised when the pointer moves over a Series.
        *
        * ```html
        * <igx-category-chart
        *       yAxisMinimumValue="0"
        *       [dataSource]="data"
        *        (seriesPointerMove)="CategoryChart_seriesPointerMove()">
        * </igx-category-chart>
        * ```
        *
        * ```ts
        *  CategoryChart_seriesPointerMove(sender: any , aregs: ChartSeriesEventArgs)
        *   {
        *
        *   }
        * ```
        */
        get seriesPointerMove() {
            if (this._seriesPointerMove == null) {
                this._seriesPointerMove = new EventEmitter();
                this.i.seriesPointerMove = delegateCombine(this.i.seriesPointerMove, (o, e) => {
                    let outerArgs = new IgxDomainChartSeriesPointerEventArgs();
                    outerArgs._provideImplementation(e);
                    if (this.beforeSeriesPointerMove) {
                        this.beforeSeriesPointerMove(this, outerArgs);
                    }
                    this._seriesPointerMove.emit({
                        sender: this,
                        args: outerArgs
                    });
                });
            }
            return this._seriesPointerMove;
        }
        /**
         * Occurs when the pointer is pressed down over a Series.
        *
        * `SeriesPointerDown` event raised when the pointer is pressed down over a Series
        *
        * ```html
        * <igx-category-chart
        *       yAxisMinimumValue="0"
        *       [dataSource]="data"
        *       (seriesPointerDown)="CategoryChart_seriesPointerDown()" >
        * </igx-category-chart>
        * ```
        */
        get seriesPointerDown() {
            if (this._seriesPointerDown == null) {
                this._seriesPointerDown = new EventEmitter();
                this.i.seriesPointerDown = delegateCombine(this.i.seriesPointerDown, (o, e) => {
                    this._runInZone(() => {
                        let outerArgs = new IgxDomainChartSeriesPointerEventArgs();
                        outerArgs._provideImplementation(e);
                        if (this.beforeSeriesPointerDown) {
                            this.beforeSeriesPointerDown(this, outerArgs);
                        }
                        this._seriesPointerDown.emit({
                            sender: this,
                            args: outerArgs
                        });
                    });
                });
            }
            return this._seriesPointerDown;
        }
        /**
         * Occurs when the pointer is released over a Series.
        *
        * `SeriesPointerUp` event raised when the pointer is released over a Series.
        *
        * ```ts
        *  CategoryChart_seriesPointerUp(sender: any , aregs: ChartSeriesEventArgs)
        *   {
        *
        *   }
        * ```
        *
        * ```html
        * <igx-category-chart
        *       yAxisMinimumValue="0"
        *       [dataSource]="data"
        *       (seriesPointerUp)="CategoryChart_seriesPointerUp()" >
        * </igx-category-chart>
        * ```
        */
        get seriesPointerUp() {
            if (this._seriesPointerUp == null) {
                this._seriesPointerUp = new EventEmitter();
                this.i.seriesPointerUp = delegateCombine(this.i.seriesPointerUp, (o, e) => {
                    this._runInZone(() => {
                        let outerArgs = new IgxDomainChartSeriesPointerEventArgs();
                        outerArgs._provideImplementation(e);
                        if (this.beforeSeriesPointerUp) {
                            this.beforeSeriesPointerUp(this, outerArgs);
                        }
                        this._seriesPointerUp.emit({
                            sender: this,
                            args: outerArgs
                        });
                    });
                });
            }
            return this._seriesPointerUp;
        }
        /**
         * Occurs when the style of a callout is updated.
        */
        get calloutStyleUpdating() {
            if (this._calloutStyleUpdating == null) {
                this._calloutStyleUpdating = new EventEmitter();
                this.i.calloutStyleUpdating = delegateCombine(this.i.calloutStyleUpdating, (o, e) => {
                    let outerArgs = new IgxCalloutStyleUpdatingEventArgs();
                    outerArgs._provideImplementation(e);
                    if (this.beforeCalloutStyleUpdating) {
                        this.beforeCalloutStyleUpdating(this, outerArgs);
                    }
                    this._calloutStyleUpdating.emit({
                        sender: this,
                        args: outerArgs
                    });
                });
            }
            return this._calloutStyleUpdating;
        }
        _runInZone(act) {
            if (this._zoneRunner != null) {
                this._zoneRunner(act);
            }
            else {
                act();
            }
        }
    }
    IgxDomainChartComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.13", ngImport: i0, type: IgxDomainChartComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
    IgxDomainChartComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "12.2.13", type: IgxDomainChartComponent, selector: "ng-component", inputs: { tooltipTemplate: "tooltipTemplate", tooltipTemplates: "tooltipTemplates", legend: "legend", calloutsDataSource: "calloutsDataSource", pixelScalingRatio: "pixelScalingRatio", titleLeftMargin: "titleLeftMargin", titleRightMargin: "titleRightMargin", titleTopMargin: "titleTopMargin", titleBottomMargin: "titleBottomMargin", subtitleLeftMargin: "subtitleLeftMargin", subtitleTopMargin: "subtitleTopMargin", subtitleRightMargin: "subtitleRightMargin", subtitleBottomMargin: "subtitleBottomMargin", subtitleTextColor: "subtitleTextColor", titleTextColor: "titleTextColor", leftMargin: "leftMargin", topMargin: "topMargin", rightMargin: "rightMargin", bottomMargin: "bottomMargin", transitionDuration: "transitionDuration", transitionEasingFunction: "transitionEasingFunction", subtitleTextStyle: "subtitleTextStyle", titleTextStyle: "titleTextStyle", includedProperties: "includedProperties", excludedProperties: "excludedProperties", brushes: "brushes", outlines: "outlines", actualBrushes: "actualBrushes", actualOutlines: "actualOutlines", isHorizontalZoomEnabled: "isHorizontalZoomEnabled", isVerticalZoomEnabled: "isVerticalZoomEnabled", shouldDisplayMockData: "shouldDisplayMockData", shouldUseSkeletonStyleForMockData: "shouldUseSkeletonStyleForMockData", isSeriesHighlightingEnabled: "isSeriesHighlightingEnabled", windowRect: "windowRect", chartTitle: "chartTitle", subtitle: "subtitle", titleAlignment: "titleAlignment", subtitleAlignment: "subtitleAlignment", unknownValuePlotting: "unknownValuePlotting", resolution: "resolution", thickness: "thickness", outlineMode: "outlineMode", markerOutlineMode: "markerOutlineMode", markerFillMode: "markerFillMode", markerFillOpacity: "markerFillOpacity", markerThickness: "markerThickness", markerTypes: "markerTypes", markerAutomaticBehavior: "markerAutomaticBehavior", markerBrushes: "markerBrushes", markerOutlines: "markerOutlines", markerMaxCount: "markerMaxCount", areaFillOpacity: "areaFillOpacity", animateSeriesWhenAxisRangeChanges: "animateSeriesWhenAxisRangeChanges", trendLineBrushes: "trendLineBrushes", trendLineType: "trendLineType", trendLineThickness: "trendLineThickness", alignsGridLinesToPixels: "alignsGridLinesToPixels", plotAreaMarginLeft: "plotAreaMarginLeft", plotAreaMarginTop: "plotAreaMarginTop", plotAreaMarginRight: "plotAreaMarginRight", plotAreaMarginBottom: "plotAreaMarginBottom", computedPlotAreaMarginMode: "computedPlotAreaMarginMode", highlightingMode: "highlightingMode", highlightingBehavior: "highlightingBehavior", legendHighlightingMode: "legendHighlightingMode", legendItemBadgeShape: "legendItemBadgeShape", legendItemBadgeMode: "legendItemBadgeMode", shouldAutoExpandMarginForInitialLabels: "shouldAutoExpandMarginForInitialLabels", autoExpandMarginExtraPadding: "autoExpandMarginExtraPadding", autoExpandMarginMaximumValue: "autoExpandMarginMaximumValue", trendLinePeriod: "trendLinePeriod", toolTipType: "toolTipType", crosshairsDisplayMode: "crosshairsDisplayMode", crosshairsSnapToData: "crosshairsSnapToData", crosshairsLineVerticalStroke: "crosshairsLineVerticalStroke", crosshairsLineThickness: "crosshairsLineThickness", crosshairsLineHorizontalStroke: "crosshairsLineHorizontalStroke", crosshairsAnnotationEnabled: "crosshairsAnnotationEnabled", crosshairsAnnotationXAxisBackground: "crosshairsAnnotationXAxisBackground", crosshairsAnnotationYAxisBackground: "crosshairsAnnotationYAxisBackground", crosshairsAnnotationXAxisTextColor: "crosshairsAnnotationXAxisTextColor", crosshairsAnnotationYAxisTextColor: "crosshairsAnnotationYAxisTextColor", crosshairsAnnotationXAxisPrecision: "crosshairsAnnotationXAxisPrecision", crosshairsAnnotationYAxisPrecision: "crosshairsAnnotationYAxisPrecision", finalValueAnnotationsVisible: "finalValueAnnotationsVisible", finalValueAnnotationsBackground: "finalValueAnnotationsBackground", finalValueAnnotationsTextColor: "finalValueAnnotationsTextColor", finalValueAnnotationsPrecision: "finalValueAnnotationsPrecision", calloutsVisible: "calloutsVisible", calloutStyleUpdatingEventEnabled: "calloutStyleUpdatingEventEnabled", calloutsXMemberPath: "calloutsXMemberPath", calloutsYMemberPath: "calloutsYMemberPath", calloutsLabelMemberPath: "calloutsLabelMemberPath", calloutsContentMemberPath: "calloutsContentMemberPath" }, outputs: { seriesAdded: "seriesAdded", seriesRemoved: "seriesRemoved", seriesPointerEnter: "seriesPointerEnter", seriesPointerLeave: "seriesPointerLeave", seriesPointerMove: "seriesPointerMove", seriesPointerDown: "seriesPointerDown", seriesPointerUp: "seriesPointerUp", calloutStyleUpdating: "calloutStyleUpdating" }, ngImport: i0, template: ``, isInline: true });
    return IgxDomainChartComponent;
})();
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.13", ngImport: i0, type: IgxDomainChartComponent, decorators: [{
            type: Component,
            args: [{
                    template: ``,
                }]
        }], ctorParameters: function () { return []; }, propDecorators: { tooltipTemplate: [{
                type: Input
            }], tooltipTemplates: [{
                type: Input
            }], legend: [{
                type: Input
            }], calloutsDataSource: [{
                type: Input
            }], pixelScalingRatio: [{
                type: Input
            }], titleLeftMargin: [{
                type: Input
            }], titleRightMargin: [{
                type: Input
            }], titleTopMargin: [{
                type: Input
            }], titleBottomMargin: [{
                type: Input
            }], subtitleLeftMargin: [{
                type: Input
            }], subtitleTopMargin: [{
                type: Input
            }], subtitleRightMargin: [{
                type: Input
            }], subtitleBottomMargin: [{
                type: Input
            }], subtitleTextColor: [{
                type: Input
            }], titleTextColor: [{
                type: Input
            }], leftMargin: [{
                type: Input
            }], topMargin: [{
                type: Input
            }], rightMargin: [{
                type: Input
            }], bottomMargin: [{
                type: Input
            }], transitionDuration: [{
                type: Input
            }], transitionEasingFunction: [{
                type: Input
            }], subtitleTextStyle: [{
                type: Input
            }], titleTextStyle: [{
                type: Input
            }], includedProperties: [{
                type: Input
            }], excludedProperties: [{
                type: Input
            }], brushes: [{
                type: Input
            }], outlines: [{
                type: Input
            }], actualBrushes: [{
                type: Input
            }], actualOutlines: [{
                type: Input
            }], isHorizontalZoomEnabled: [{
                type: Input
            }], isVerticalZoomEnabled: [{
                type: Input
            }], shouldDisplayMockData: [{
                type: Input
            }], shouldUseSkeletonStyleForMockData: [{
                type: Input
            }], isSeriesHighlightingEnabled: [{
                type: Input
            }], windowRect: [{
                type: Input
            }], chartTitle: [{
                type: Input
            }], subtitle: [{
                type: Input
            }], titleAlignment: [{
                type: Input
            }], subtitleAlignment: [{
                type: Input
            }], unknownValuePlotting: [{
                type: Input
            }], resolution: [{
                type: Input
            }], thickness: [{
                type: Input
            }], outlineMode: [{
                type: Input
            }], markerOutlineMode: [{
                type: Input
            }], markerFillMode: [{
                type: Input
            }], markerFillOpacity: [{
                type: Input
            }], markerThickness: [{
                type: Input
            }], markerTypes: [{
                type: Input
            }], markerAutomaticBehavior: [{
                type: Input
            }], markerBrushes: [{
                type: Input
            }], markerOutlines: [{
                type: Input
            }], markerMaxCount: [{
                type: Input
            }], areaFillOpacity: [{
                type: Input
            }], animateSeriesWhenAxisRangeChanges: [{
                type: Input
            }], trendLineBrushes: [{
                type: Input
            }], trendLineType: [{
                type: Input
            }], trendLineThickness: [{
                type: Input
            }], alignsGridLinesToPixels: [{
                type: Input
            }], plotAreaMarginLeft: [{
                type: Input
            }], plotAreaMarginTop: [{
                type: Input
            }], plotAreaMarginRight: [{
                type: Input
            }], plotAreaMarginBottom: [{
                type: Input
            }], computedPlotAreaMarginMode: [{
                type: Input
            }], highlightingMode: [{
                type: Input
            }], highlightingBehavior: [{
                type: Input
            }], legendHighlightingMode: [{
                type: Input
            }], legendItemBadgeShape: [{
                type: Input
            }], legendItemBadgeMode: [{
                type: Input
            }], shouldAutoExpandMarginForInitialLabels: [{
                type: Input
            }], autoExpandMarginExtraPadding: [{
                type: Input
            }], autoExpandMarginMaximumValue: [{
                type: Input
            }], trendLinePeriod: [{
                type: Input
            }], toolTipType: [{
                type: Input
            }], crosshairsDisplayMode: [{
                type: Input
            }], crosshairsSnapToData: [{
                type: Input
            }], crosshairsLineVerticalStroke: [{
                type: Input
            }], crosshairsLineThickness: [{
                type: Input
            }], crosshairsLineHorizontalStroke: [{
                type: Input
            }], crosshairsAnnotationEnabled: [{
                type: Input
            }], crosshairsAnnotationXAxisBackground: [{
                type: Input
            }], crosshairsAnnotationYAxisBackground: [{
                type: Input
            }], crosshairsAnnotationXAxisTextColor: [{
                type: Input
            }], crosshairsAnnotationYAxisTextColor: [{
                type: Input
            }], crosshairsAnnotationXAxisPrecision: [{
                type: Input
            }], crosshairsAnnotationYAxisPrecision: [{
                type: Input
            }], finalValueAnnotationsVisible: [{
                type: Input
            }], finalValueAnnotationsBackground: [{
                type: Input
            }], finalValueAnnotationsTextColor: [{
                type: Input
            }], finalValueAnnotationsPrecision: [{
                type: Input
            }], calloutsVisible: [{
                type: Input
            }], calloutStyleUpdatingEventEnabled: [{
                type: Input
            }], calloutsXMemberPath: [{
                type: Input
            }], calloutsYMemberPath: [{
                type: Input
            }], calloutsLabelMemberPath: [{
                type: Input
            }], calloutsContentMemberPath: [{
                type: Input
            }], seriesAdded: [{
                type: Output
            }], seriesRemoved: [{
                type: Output
            }], seriesPointerEnter: [{
                type: Output
            }], seriesPointerLeave: [{
                type: Output
            }], seriesPointerMove: [{
                type: Output
            }], seriesPointerDown: [{
                type: Output
            }], seriesPointerUp: [{
                type: Output
            }], calloutStyleUpdating: [{
                type: Output
            }] } });
//# sourceMappingURL=igx-domain-chart-component.js.map
