import { EventEmitter, Output, Component, Input } from '@angular/core';
import { delegateCombine } from "igniteui-angular-core";
import { IgxNumericAngleAxisComponent } from "./igx-numeric-angle-axis-component";
import { IgxNumericRadiusAxisComponent } from "./igx-numeric-radius-axis-component";
import { TrendLineType_$type } from "igniteui-angular-core";
import { ScatterItemSearchMode_$type } from "./ScatterItemSearchMode";
import { IgxAssigningPolarStyleEventArgs } from "./igx-assigning-polar-style-event-args";
import { IgxAssigningPolarMarkerStyleEventArgs } from "./igx-assigning-polar-marker-style-event-args";
import { IgxMarkerSeriesComponent } from "./igx-marker-series-component";
import { ensureBool, ensureEnum, brushToString, stringToBrush, toPoint, fromPoint } from "igniteui-angular-core";
import * as i0 from "@angular/core";
/**
 * Represents the base class from which all IgxDataChartComponent polar series are derived.
*/
export let IgxPolarBaseComponent = /*@__PURE__*/ (() => {
    class IgxPolarBaseComponent extends IgxMarkerSeriesComponent {
        constructor() {
            super();
            this._assigningPolarStyle = null;
            this._assigningPolarMarkerStyle = null;
        }
        /**
                                     * @hidden
                                     */
        get i() {
            return this._implementation;
        }
        /**
         * Checks if this series is a polar series
        */
        get isPolar() {
            return this.i.d0;
        }
        /**
         * Gets or sets the path to use to find the angle values for the series.
        */
        get angleMemberPath() {
            return this.i.so;
        }
        set angleMemberPath(v) {
            this.i.so = v;
        }
        /**
         * Gets or sets the path to use to get the radius values for the series.
        */
        get radiusMemberPath() {
            return this.i.sy;
        }
        set radiusMemberPath(v) {
            this.i.sy = v;
        }
        /**
         * Gets the effective angle axis for the current series object.
        */
        get angleAxis() {
            if (this.i.q8 == null) {
                return null;
            }
            if (!this.i.q8.externalObject) {
                let e = IgxNumericAngleAxisComponent._createFromInternal(this.i.q8);
                if (e) {
                    e._implementation = this.i.q8;
                }
                this.i.q8.externalObject = e;
            }
            return this.i.q8.externalObject;
        }
        set angleAxis(v) {
            if (v != null && this._stylingContainer && v._styling)
                v._styling(this._stylingContainer, this, this);
            v == null ? this.i.q8 = null : this.i.q8 = v.i;
        }
        /**
         * Gets the effective radius axis for the current series object.
        */
        get radiusAxis() {
            if (this.i.q9 == null) {
                return null;
            }
            if (!this.i.q9.externalObject) {
                let e = IgxNumericRadiusAxisComponent._createFromInternal(this.i.q9);
                if (e) {
                    e._implementation = this.i.q9;
                }
                this.i.q9.externalObject = e;
            }
            return this.i.q9.externalObject;
        }
        set radiusAxis(v) {
            if (v != null && this._stylingContainer && v._styling)
                v._styling(this._stylingContainer, this, this);
            v == null ? this.i.q9 = null : this.i.q9 = v.i;
        }
        /**
         * Gets or sets whether Cartesian Interpolation should be used rather than Archimedian
         * spiral based interpolation.
        */
        get useCartesianInterpolation() {
            return this.i.r8;
        }
        set useCartesianInterpolation(v) {
            this.i.r8 = ensureBool(v);
        }
        /**
         * Gets or sets the maximum number of markers displayed by the current series.
         * If more than the specified number of markers are visible, the polar series will automatically
         * choose a representative set.
        */
        get maximumMarkers() {
            return this.i.si;
        }
        set maximumMarkers(v) {
            this.i.si = +v;
        }
        /**
         * Gets or sets the trend type for the current series object.
        */
        get trendLineType() {
            return this.i.rq;
        }
        set trendLineType(v) {
            this.i.rq = ensureEnum(TrendLineType_$type, v);
        }
        /**
         * Gets or sets the brush that specifies how the current series
         * object's trend line is drawn.
        */
        get trendLineBrush() {
            return brushToString(this.i.tx);
        }
        set trendLineBrush(v) {
            this.i.tx = stringToBrush(v);
        }
        /**
         * Gets the effective TrendLineBrush for this series.
        */
        get actualTrendLineBrush() {
            return brushToString(this.i.tw);
        }
        set actualTrendLineBrush(v) {
            this.i.tw = stringToBrush(v);
        }
        /**
         * Gets or sets the thickness of the current series object's trend line.
        */
        get trendLineThickness() {
            return this.i.sg;
        }
        set trendLineThickness(v) {
            this.i.sg = +v;
        }
        /**
         * Gets or sets the moving average period for the current series object.
        */
        get trendLinePeriod() {
            return this.i.sj;
        }
        set trendLinePeriod(v) {
            this.i.sj = +v;
        }
        /**
         * Sets or Gets the Trendline Z index.
        */
        get trendLineZIndex() {
            return this.i.sk;
        }
        set trendLineZIndex(v) {
            this.i.sk = +v;
        }
        /**
         * Gets or sets whether to clip the series to the bounds.
         * Setting this to true can effect performance.
        */
        get clipSeriesToBounds() {
            return this.i.rz;
        }
        set clipSeriesToBounds(v) {
            this.i.rz = ensureBool(v);
        }
        get actualItemSearchMode() {
            return this.i.rm;
        }
        set actualItemSearchMode(v) {
            this.i.rm = ensureEnum(ScatterItemSearchMode_$type, v);
        }
        /**
         * Gets or sets the mode the series will use to find the closest point to the cursor.
        */
        get itemSearchMode() {
            return this.i.ro;
        }
        set itemSearchMode(v) {
            this.i.ro = ensureEnum(ScatterItemSearchMode_$type, v);
        }
        /**
         * Gets or sets the threshold to use when searching for items using ItemSearchMode.
        */
        get itemSearchThreshold() {
            return this.i.sh;
        }
        set itemSearchThreshold(v) {
            this.i.sh = +v;
        }
        /**
         * Gets or sets whether this Polar series should allow custom style overrides of its individual visuals.
        */
        get isCustomPolarStyleAllowed() {
            return this.i.r2;
        }
        set isCustomPolarStyleAllowed(v) {
            this.i.r2 = ensureBool(v);
        }
        /**
         * Gets or sets whether this Polar series should allow custom style overrides of its individual marker visuals.
        */
        get isCustomPolarMarkerStyleAllowed() {
            return this.i.r1;
        }
        set isCustomPolarMarkerStyleAllowed(v) {
            this.i.r1 = ensureBool(v);
        }
        findByName(name) {
            var baseResult = super.findByName(name);
            if (baseResult) {
                return baseResult;
            }
            if (this.angleAxis && this.angleAxis.name && this.angleAxis.name == name) {
                return this.angleAxis;
            }
            if (this.radiusAxis && this.radiusAxis.name && this.radiusAxis.name == name) {
                return this.radiusAxis;
            }
            return null;
        }
        _styling(container, component, parent) {
            super._styling(container, component, parent);
            this._inStyling = true;
            if (this.angleAxis && this.angleAxis._styling) {
                this.angleAxis._styling(container, component, this);
            }
            if (this.radiusAxis && this.radiusAxis._styling) {
                this.radiusAxis._styling(container, component, this);
            }
            this._inStyling = false;
        }
        /**
         * Scrolls the requested item into view, if possible.
        
        * @param item  * The item to scroll into view.
        */
        scrollIntoView(item) {
            let iv = this.i.eh(item);
            return (iv);
        }
        /**
         * Gets the item that is the best match for the specified world coordinates.
        
        * @param world  * The world coordinates to use.
        */
        getItem(world) {
            let iv = this.i.hh(toPoint(world));
            return (iv);
        }
        /**
         * Gets the index of the item that resides at the provided world coordinates.
        
        * @param world  * The world coordinates of the requested item.
        */
        getItemIndex(world) {
            let iv = this.i.g0(toPoint(world));
            return (iv);
        }
        getExactItemIndex(world) {
            let iv = this.i.fw(toPoint(world));
            return (iv);
        }
        getSeriesValuePosition(world, useInterpolation, skipUnknowns) {
            let iv = this.i.o2(toPoint(world), useInterpolation, skipUnknowns);
            return fromPoint(iv);
        }
        getItemValue(item, memberPathName) {
            let iv = this.i.hk(item, memberPathName);
            return (iv);
        }
        /**
         * Determine if object can be used as RadiusAxis
        
        * @param axis  * The object to check
        */
        canUseAsRadiusAxis(axis) {
            let iv = this.i.ry(axis);
            return (iv);
        }
        /**
         * Determine if object can be used as AngleAxis
        
        * @param axis  * The object to check
        */
        canUseAsAngleAxis(axis) {
            let iv = this.i.rx(axis);
            return (iv);
        }
        /**
         * Event raised when Assigning Category Style
        */
        get assigningPolarStyle() {
            if (this._assigningPolarStyle == null) {
                this._assigningPolarStyle = new EventEmitter();
                this.i.assigningPolarStyle = delegateCombine(this.i.assigningPolarStyle, (o, e) => {
                    let outerArgs = new IgxAssigningPolarStyleEventArgs();
                    outerArgs._provideImplementation(e);
                    if (this.beforeAssigningPolarStyle) {
                        this.beforeAssigningPolarStyle(this, outerArgs);
                    }
                    this._assigningPolarStyle.emit({
                        sender: this,
                        args: outerArgs
                    });
                });
            }
            return this._assigningPolarStyle;
        }
        /**
         * Event raised when Assigning Polar Marker Style
        */
        get assigningPolarMarkerStyle() {
            if (this._assigningPolarMarkerStyle == null) {
                this._assigningPolarMarkerStyle = new EventEmitter();
                this.i.assigningPolarMarkerStyle = delegateCombine(this.i.assigningPolarMarkerStyle, (o, e) => {
                    let outerArgs = new IgxAssigningPolarMarkerStyleEventArgs();
                    outerArgs._provideImplementation(e);
                    if (this.beforeAssigningPolarMarkerStyle) {
                        this.beforeAssigningPolarMarkerStyle(this, outerArgs);
                    }
                    this._assigningPolarMarkerStyle.emit({
                        sender: this,
                        args: outerArgs
                    });
                });
            }
            return this._assigningPolarMarkerStyle;
        }
    }
    IgxPolarBaseComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.13", ngImport: i0, type: IgxPolarBaseComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
    IgxPolarBaseComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "12.2.13", type: IgxPolarBaseComponent, selector: "ng-component", inputs: { angleMemberPath: "angleMemberPath", radiusMemberPath: "radiusMemberPath", angleAxis: "angleAxis", radiusAxis: "radiusAxis", useCartesianInterpolation: "useCartesianInterpolation", maximumMarkers: "maximumMarkers", trendLineType: "trendLineType", trendLineBrush: "trendLineBrush", actualTrendLineBrush: "actualTrendLineBrush", trendLineThickness: "trendLineThickness", trendLinePeriod: "trendLinePeriod", trendLineZIndex: "trendLineZIndex", clipSeriesToBounds: "clipSeriesToBounds", actualItemSearchMode: "actualItemSearchMode", itemSearchMode: "itemSearchMode", itemSearchThreshold: "itemSearchThreshold", isCustomPolarStyleAllowed: "isCustomPolarStyleAllowed", isCustomPolarMarkerStyleAllowed: "isCustomPolarMarkerStyleAllowed" }, outputs: { assigningPolarStyle: "assigningPolarStyle", assigningPolarMarkerStyle: "assigningPolarMarkerStyle" }, usesInheritance: true, ngImport: i0, template: ``, isInline: true });
    return IgxPolarBaseComponent;
})();
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.13", ngImport: i0, type: IgxPolarBaseComponent, decorators: [{
            type: Component,
            args: [{
                    template: ``,
                }]
        }], ctorParameters: function () { return []; }, propDecorators: { angleMemberPath: [{
                type: Input
            }], radiusMemberPath: [{
                type: Input
            }], angleAxis: [{
                type: Input
            }], radiusAxis: [{
                type: Input
            }], useCartesianInterpolation: [{
                type: Input
            }], maximumMarkers: [{
                type: Input
            }], trendLineType: [{
                type: Input
            }], trendLineBrush: [{
                type: Input
            }], actualTrendLineBrush: [{
                type: Input
            }], trendLineThickness: [{
                type: Input
            }], trendLinePeriod: [{
                type: Input
            }], trendLineZIndex: [{
                type: Input
            }], clipSeriesToBounds: [{
                type: Input
            }], actualItemSearchMode: [{
                type: Input
            }], itemSearchMode: [{
                type: Input
            }], itemSearchThreshold: [{
                type: Input
            }], isCustomPolarStyleAllowed: [{
                type: Input
            }], isCustomPolarMarkerStyleAllowed: [{
                type: Input
            }], assigningPolarStyle: [{
                type: Output
            }], assigningPolarMarkerStyle: [{
                type: Output
            }] } });
//# sourceMappingURL=igx-polar-base-component.js.map
