import { EventEmitter, Output, Component, Input } from '@angular/core';
import { delegateCombine } from "igniteui-angular-core";
import { IgxNumericXAxisComponent } from "./igx-numeric-x-axis-component";
import { IgxNumericYAxisComponent } from "./igx-numeric-y-axis-component";
import { IgxTriangulationStatusEventArgs } from "igniteui-angular-core";
import { IgxSeriesComponent } from "./igx-series-component";
import * as i0 from "@angular/core";
/**
 * Base class for series which triangulate XY data prior to rendering.
*/
export let IgxScatterTriangulationSeriesComponent = /*@__PURE__*/ (() => {
    class IgxScatterTriangulationSeriesComponent extends IgxSeriesComponent {
        constructor() {
            super();
            this._triangulationStatusChanged = null;
        }
        /**
                                     * @hidden
                                     */
        get i() {
            return this._implementation;
        }
        /**
         * The name of the property from which to extract the X-coordinate for each item in the ItemsSource.
        */
        get xMemberPath() {
            return this.i.qg;
        }
        set xMemberPath(v) {
            this.i.qg = v;
        }
        /**
         * The name of the property from which to extract the Y-coordinate for each item in the ItemsSource.
        */
        get yMemberPath() {
            return this.i.qk;
        }
        set yMemberPath(v) {
            this.i.qk = v;
        }
        /**
         * The X-Axis for this series.
        */
        get xAxis() {
            if (this.i.pi == null) {
                return null;
            }
            if (!this.i.pi.externalObject) {
                let e = IgxNumericXAxisComponent._createFromInternal(this.i.pi);
                if (e) {
                    e._implementation = this.i.pi;
                }
                this.i.pi.externalObject = e;
            }
            return this.i.pi.externalObject;
        }
        set xAxis(v) {
            if (v != null && this._stylingContainer && v._styling)
                v._styling(this._stylingContainer, this, this);
            v == null ? this.i.pi = null : this.i.pi = v.i;
        }
        /**
         * The Y-Axis for this series.
        */
        get yAxis() {
            if (this.i.pj == null) {
                return null;
            }
            if (!this.i.pj.externalObject) {
                let e = IgxNumericYAxisComponent._createFromInternal(this.i.pj);
                if (e) {
                    e._implementation = this.i.pj;
                }
                this.i.pj.externalObject = e;
            }
            return this.i.pj.externalObject;
        }
        set yAxis(v) {
            if (v != null && this._stylingContainer && v._styling)
                v._styling(this._stylingContainer, this, this);
            v == null ? this.i.pj = null : this.i.pj = v.i;
        }
        /**
         * The source of triangulation data.
         * This property is optional.  If it is left as null, the triangulation will be created based on the items in the ItemsSource.  Triangulation is a demanding operation, so the runtime performance will be better when specifying a TriangulationSource, especially when a large number of data items are present.
        */
        get trianglesSource() {
            return this.i.trianglesSource;
        }
        set trianglesSource(v) {
            this.i.trianglesSource = v;
        }
        /**
         * The name of the property of the TrianglesSource items which, for each triangle, contains the index of the first vertex point in the ItemsSource.
        */
        get triangleVertexMemberPath1() {
            return this.i.p8;
        }
        set triangleVertexMemberPath1(v) {
            this.i.p8 = v;
        }
        /**
         * The name of the property of the TrianglesSource items which, for each triangle, contains the index of the second vertex point in the ItemsSource.
        */
        get triangleVertexMemberPath2() {
            return this.i.qa;
        }
        set triangleVertexMemberPath2(v) {
            this.i.qa = v;
        }
        /**
         * The name of the property of the TrianglesSource items which, for each triangle, contains the index of the third vertex point in the ItemsSource.
        */
        get triangleVertexMemberPath3() {
            return this.i.qc;
        }
        set triangleVertexMemberPath3(v) {
            this.i.qc = v;
        }
        /**
         * Gets whether or not this series is a shape series
        */
        get isShape() {
            return this.i.d7;
        }
        /**
         * Overridden by derived series classes to indicate when marker-less display is preferred or not.
        */
        get isMarkerlessDisplayPreferred() {
            return this.i.dw;
        }
        findByName(name) {
            var baseResult = super.findByName(name);
            if (baseResult) {
                return baseResult;
            }
            if (this.xAxis && this.xAxis.name && this.xAxis.name == name) {
                return this.xAxis;
            }
            if (this.yAxis && this.yAxis.name && this.yAxis.name == name) {
                return this.yAxis;
            }
            return null;
        }
        _styling(container, component, parent) {
            super._styling(container, component, parent);
            this._inStyling = true;
            if (this.xAxis && this.xAxis._styling) {
                this.xAxis._styling(container, component, this);
            }
            if (this.yAxis && this.yAxis._styling) {
                this.yAxis._styling(container, component, this);
            }
            this._inStyling = false;
        }
        getItemValue(item, memberPathName) {
            let iv = this.i.hk(item, memberPathName);
            return (iv);
        }
        /**
         * Determine if object can be used as YAxis
        
        * @param axis  * The object to check
        */
        canUseAsYAxis(axis) {
            let iv = this.i.p0(axis);
            return (iv);
        }
        /**
         * Determine if object can be used as XAxis
        
        * @param axis  * The object to check
        */
        canUseAsXAxis(axis) {
            let iv = this.i.pz(axis);
            return (iv);
        }
        /**
         * Raised when the status of an ongoing Triangulation has changed.
        */
        get triangulationStatusChanged() {
            if (this._triangulationStatusChanged == null) {
                this._triangulationStatusChanged = new EventEmitter();
                this.i.triangulationStatusChanged = delegateCombine(this.i.triangulationStatusChanged, (o, e) => {
                    this._runInZone(() => {
                        let outerArgs = new IgxTriangulationStatusEventArgs();
                        outerArgs._provideImplementation(e);
                        if (this.beforeTriangulationStatusChanged) {
                            this.beforeTriangulationStatusChanged(this, outerArgs);
                        }
                        this._triangulationStatusChanged.emit({
                            sender: this,
                            args: outerArgs
                        });
                    });
                });
            }
            return this._triangulationStatusChanged;
        }
    }
    IgxScatterTriangulationSeriesComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.13", ngImport: i0, type: IgxScatterTriangulationSeriesComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
    IgxScatterTriangulationSeriesComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "12.2.13", type: IgxScatterTriangulationSeriesComponent, selector: "ng-component", inputs: { xMemberPath: "xMemberPath", yMemberPath: "yMemberPath", xAxis: "xAxis", yAxis: "yAxis", trianglesSource: "trianglesSource", triangleVertexMemberPath1: "triangleVertexMemberPath1", triangleVertexMemberPath2: "triangleVertexMemberPath2", triangleVertexMemberPath3: "triangleVertexMemberPath3" }, outputs: { triangulationStatusChanged: "triangulationStatusChanged" }, usesInheritance: true, ngImport: i0, template: ``, isInline: true });
    return IgxScatterTriangulationSeriesComponent;
})();
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.13", ngImport: i0, type: IgxScatterTriangulationSeriesComponent, decorators: [{
            type: Component,
            args: [{
                    template: ``,
                }]
        }], ctorParameters: function () { return []; }, propDecorators: { xMemberPath: [{
                type: Input
            }], yMemberPath: [{
                type: Input
            }], xAxis: [{
                type: Input
            }], yAxis: [{
                type: Input
            }], trianglesSource: [{
                type: Input
            }], triangleVertexMemberPath1: [{
                type: Input
            }], triangleVertexMemberPath2: [{
                type: Input
            }], triangleVertexMemberPath3: [{
                type: Input
            }], triangulationStatusChanged: [{
                type: Output
            }] } });
//# sourceMappingURL=igx-scatter-triangulation-series-component.js.map
