import { EventEmitter, Output, Component, Input, ChangeDetectionStrategy } from '@angular/core';
import { delegateCombine } from "igniteui-angular-core";
import { Visibility_$type } from "igniteui-angular-core";
import { LegendItemBadgeShape_$type } from "./LegendItemBadgeShape";
import { LegendItemBadgeMode_$type } from "./LegendItemBadgeMode";
import { MarkerType_$type } from "./MarkerType";
import { SeriesOutlineMode_$type } from "./SeriesOutlineMode";
import { IgxPropertyUpdatedEventArgs } from "igniteui-angular-core";
import { StackedFragmentSeries } from "./StackedFragmentSeries";
import { TypeRegistrar } from "igniteui-angular-core";
import { NamePatcher, brushToString, stringToBrush, ensureBool, colorToString, stringToColor, ensureEnum, toSpinal, initializePropertiesFromCss, toPoint, fromPoint, fromRect } from "igniteui-angular-core";
import * as i0 from "@angular/core";
/**
 * Represents a non-visual child of StackedSeriesBase.
*/
export let IgxStackedFragmentSeriesComponent = /*@__PURE__*/ (() => {
    class IgxStackedFragmentSeriesComponent {
        constructor() {
            this.__p = null;
            this._hasUserValues = new Set();
            this._stylingContainer = null;
            this._stylingParent = null;
            this._inStyling = false;
            this._propertyUpdated = null;
            this._zoneRunner = null;
            if (this._styling) {
                NamePatcher.ensureStylablePatched(Object.getPrototypeOf(this));
            }
            this._implementation = this.createImplementation();
            this._implementation.externalObject = this;
            this.onImplementationCreated();
        }
        createImplementation() {
            return new StackedFragmentSeries();
        }
        ngOnInit() {
        }
        /**
         * @hidden
         */
        get i() {
            return this._implementation;
        } /**
                                     * @hidden
                                     */
        static _createFromInternal(internal) {
            if (!internal) {
                return null;
            }
            if (!internal.$type) {
                return null;
            }
            let name = internal.$type.name;
            let externalName = "Igx" + name + "Component";
            if (!TypeRegistrar.isRegistered(externalName)) {
                return null;
            }
            return TypeRegistrar.create(externalName);
        }
        onImplementationCreated() {
        }
        /**
         * Gets or sets the ItemsSource property for the current series object. Normally you will want to provide data to the parent series instead.
         * But if you have data as individual columns, it can be assigned here. The data must be aligned and have the same number of items for each fragment.
        */
        get dataSource() {
            return this.i.itemsSource;
        }
        set dataSource(v) {
            this.i.itemsSource = v;
        }
        /**
         * Gets or sets the brush of the stacked fragment.
        */
        get brush() {
            return brushToString(this.i.hx);
        }
        set brush(v) {
            this.i.hx = stringToBrush(v);
        }
        /**
         * Gets the actual brush used by the series.
        */
        get actualBrush() {
            return brushToString(this.i.hs);
        }
        set actualBrush(v) {
            this.i.hs = stringToBrush(v);
        }
        /**
         * Gets or sets whether drop shadow should be enabled for this series.
        */
        get isDropShadowEnabled() {
            return this.i.ag;
        }
        set isDropShadowEnabled(v) {
            this.i.ag = ensureBool(v);
        }
        /**
         * Gets whether drop shadow is actually enabled for this series.
        */
        get actualIsDropShadowEnabled() {
            return this.i.aa;
        }
        set actualIsDropShadowEnabled(v) {
            this.i.aa = ensureBool(v);
        }
        /**
         * Gets or sets the shadow blur.
         * This property is ignored when StackedFragmentSeries.UseSingleShadow is set to true.
        */
        get shadowBlur() {
            return this.i.bi;
        }
        set shadowBlur(v) {
            this.i.bi = +v;
        }
        /**
         * Gets the actual shadow blur used by the series.
        */
        get actualShadowBlur() {
            return this.i.az;
        }
        set actualShadowBlur(v) {
            this.i.az = +v;
        }
        /**
         * Gets or sets the drop shadow color.
        */
        get shadowColor() {
            return colorToString(this.i.h4);
        }
        set shadowColor(v) {
            this.i.h4 = stringToColor(v);
        }
        /**
         * Gets actual the drop shadow color used by the series.
        */
        get actualShadowColor() {
            return colorToString(this.i.h3);
        }
        set actualShadowColor(v) {
            this.i.h3 = stringToColor(v);
        }
        /**
         * Gets or sets whether drop shadow is applied to the whole StackedFragmentSeries visual or to each of the individual shapes forming the StackedFragmentSeries.
         * When this property is set to true, no StackedFragmentSeries.ShadowBlur is applied.
        */
        get useSingleShadow() {
            return this.i.an;
        }
        set useSingleShadow(v) {
            this.i.an = ensureBool(v);
        }
        /**
         * Gets whether drop shadow is actually applied to the whole StackedFragmentSeries visual or to each of the individual shapes forming the StackedFragmentSeries.
        */
        get actualUseSingleShadow() {
            return this.i.ae;
        }
        set actualUseSingleShadow(v) {
            this.i.ae = ensureBool(v);
        }
        /**
         * Gets or sets the drop shadow x-offset.
        */
        get shadowOffsetX() {
            return this.i.bj;
        }
        set shadowOffsetX(v) {
            this.i.bj = +v;
        }
        /**
         * Gets the actual drop shadow x-offset applied to the series.
        */
        get actualShadowOffsetX() {
            return this.i.a0;
        }
        set actualShadowOffsetX(v) {
            this.i.a0 = +v;
        }
        /**
         * Gets or sets the drop shadow y-offset.
        */
        get shadowOffsetY() {
            return this.i.bk;
        }
        set shadowOffsetY(v) {
            this.i.bk = +v;
        }
        /**
         * Gets the actual drop shadow y-offset applied to the series.
        */
        get actualShadowOffsetY() {
            return this.i.a1;
        }
        set actualShadowOffsetY(v) {
            this.i.a1 = +v;
        }
        /**
         * Gets or sets the LegendItemBadgeTemplate property.
         * The legend item badge is created according to the LegendItemBadgeTemplate on-demand by
         * the series object itself.
        */
        get legendItemBadgeTemplate() {
            return this.i.fi;
        }
        set legendItemBadgeTemplate(v) {
            this.i.fi = v;
        }
        /**
         * Gets the actual legend item badge template used by the series.
        */
        get actualLegendItemBadgeTemplate() {
            return this.i.ff;
        }
        set actualLegendItemBadgeTemplate(v) {
            this.i.ff = v;
        }
        /**
         * Gets or sets the LegendItemTemplate property.
         * The legend item control content is created according to the LegendItemTemplate on-demand by
         * the series object itself.
        */
        get legendItemTemplate() {
            return this.i.fj;
        }
        set legendItemTemplate(v) {
            this.i.fj = v;
        }
        /**
         * Gets the actual legend item template used by the series.
        */
        get actualLegendItemTemplate() {
            return this.i.fg;
        }
        set actualLegendItemTemplate(v) {
            this.i.fg = v;
        }
        /**
         * Gets or sets the legend item visibility for the current series object.
        */
        get legendItemVisibility() {
            return this.i.iw;
        }
        set legendItemVisibility(v) {
            this.i.iw = ensureEnum(Visibility_$type, v);
        }
        /**
         * Gets the actual visibility of the legend items in the series.
        */
        get actualLegendItemVisibility() {
            return this.i.iu;
        }
        set actualLegendItemVisibility(v) {
            this.i.iu = ensureEnum(Visibility_$type, v);
        }
        /**
         * Gets or sets the type of legend badge representing the current series in a legend.
         * This property will be ignored when the LegendItemTemplate or LegendItemBadgeTemplate property is set on the series
        */
        get legendItemBadgeShape() {
            return this.i.p;
        }
        set legendItemBadgeShape(v) {
            this.i.p = ensureEnum(LegendItemBadgeShape_$type, v);
        }
        /**
         * Gets or sets the mode of legend badge representing the current series in a legend.
         * This property will be ignored when the LegendItemTemplate or LegendItemBadgeTemplate property is set on the series
        */
        get legendItemBadgeMode() {
            return this.i.n;
        }
        set legendItemBadgeMode(v) {
            this.i.n = ensureEnum(LegendItemBadgeMode_$type, v);
        }
        /**
         * Gets the actual LegendItemBadgeShape of the series.
        */
        get actualLegendItemBadgeShape() {
            return this.i.o;
        }
        set actualLegendItemBadgeShape(v) {
            this.i.o = ensureEnum(LegendItemBadgeShape_$type, v);
        }
        /**
         * Gets the actual LegendItemBadgeMode of the series.
        */
        get actualLegendItemBadgeMode() {
            return this.i.m;
        }
        set actualLegendItemBadgeMode(v) {
            this.i.m = ensureEnum(LegendItemBadgeMode_$type, v);
        }
        /**
         * Gets or sets the brush that specifies how the current series object's marker interiors are painted.
        */
        get markerBrush() {
            return brushToString(this.i.hy);
        }
        set markerBrush(v) {
            this.i.hy = stringToBrush(v);
        }
        /**
         * Gets the actual marker brush of the series.
        */
        get actualMarkerBrush() {
            return brushToString(this.i.ht);
        }
        set actualMarkerBrush(v) {
            this.i.ht = stringToBrush(v);
        }
        /**
         * Gets or sets the brush that specifies how the current series object's marker outlines are painted.
        */
        get markerOutline() {
            return brushToString(this.i.hz);
        }
        set markerOutline(v) {
            this.i.hz = stringToBrush(v);
        }
        /**
         * Gets the actual marker outline of the series.
        */
        get actualMarkerOutline() {
            return brushToString(this.i.hu);
        }
        set actualMarkerOutline(v) {
            this.i.hu = stringToBrush(v);
        }
        /**
         * Gets or sets the MarkerTemplate for the current series object.
        */
        get markerTemplate() {
            return this.i.fk;
        }
        set markerTemplate(v) {
            this.i.fk = v;
        }
        /**
         * Gets the actual marker template used by the series.
        */
        get actualMarkerTemplate() {
            return this.i.fh;
        }
        set actualMarkerTemplate(v) {
            this.i.fh = v;
        }
        /**
         * Gets or sets the marker type for the current series object.
         * If the MarkerTemplate property is set, the setting of the MarkerType property will be ignored.
        */
        get markerType() {
            return this.i.r;
        }
        set markerType(v) {
            this.i.r = ensureEnum(MarkerType_$type, v);
        }
        /**
         * Gets the actual marker type set used in the series.
        */
        get actualMarkerType() {
            return this.i.q;
        }
        set actualMarkerType(v) {
            this.i.q = ensureEnum(MarkerType_$type, v);
        }
        /**
         * Gets or sets the Name of the stacked fragment.
        */
        get name() {
            return this.i.dk;
        }
        set name(v) {
            this.i.dk = v;
        }
        /**
         * Gets or sets the Opacity of the stacked fragment.
        */
        get opacity() {
            return this.i.bf;
        }
        set opacity(v) {
            this.i.bf = +v;
        }
        /**
         * Gets the series opacity.
        */
        get actualOpacity() {
            return this.i.aw;
        }
        set actualOpacity(v) {
            this.i.aw = +v;
        }
        /**
         * Gets or sets the brush to use for the outline of the series.
         * Some series types, such as LineSeries, do not display outlines.  Therefore, this property does not affect some charts.
        */
        get outline() {
            return brushToString(this.i.h1);
        }
        set outline(v) {
            this.i.h1 = stringToBrush(v);
        }
        /**
         * Gets the series outline.
        */
        get actualOutline() {
            return brushToString(this.i.hw);
        }
        set actualOutline(v) {
            this.i.hw = stringToBrush(v);
        }
        /**
         * Gets or sets the AreaFillOpacity of the stacked fragment. This property only applies for area-like series.
        */
        get areaFillOpacity() {
            return this.i.a3;
        }
        set areaFillOpacity(v) {
            this.i.a3 = +v;
        }
        /**
         * Gets the series ActualAreaFillOpacity.  This property only applies for area-like series.
        */
        get actualAreaFillOpacity() {
            return this.i.as;
        }
        set actualAreaFillOpacity(v) {
            this.i.as = +v;
        }
        /**
         * Gets or sets the opacity to use for the marker fills.
        */
        get markerFillOpacity() {
            return this.i.bd;
        }
        set markerFillOpacity(v) {
            this.i.bd = +v;
        }
        /**
         * Gets the actual opacity to use for hte marker fills.
        */
        get actualMarkerFillOpacity() {
            return this.i.au;
        }
        set actualMarkerFillOpacity(v) {
            this.i.au = +v;
        }
        /**
         * Gets or sets the outline mode to use for the fragment.
        */
        get outlineMode() {
            return this.i.u;
        }
        set outlineMode(v) {
            this.i.u = ensureEnum(SeriesOutlineMode_$type, v);
        }
        /**
         * Gets the actual outline mode to use for the fragment.
        */
        get actualOutlineMode() {
            return this.i.t;
        }
        set actualOutlineMode(v) {
            this.i.t = ensureEnum(SeriesOutlineMode_$type, v);
        }
        /**
         * Gets or sets the target opacity to fade to for fade style highlighting.
        */
        get highlightingFadeOpacity() {
            return this.i.bc;
        }
        set highlightingFadeOpacity(v) {
            this.i.bc = +v;
        }
        /**
         * Gets the actual target opacity to fade to for fade style highlighting.
        */
        get actualHighlightingFadeOpacity() {
            return this.i.at;
        }
        set actualHighlightingFadeOpacity(v) {
            this.i.at = +v;
        }
        /**
         * Gets or sets the x-radius of the ellipse that is used to round the corners of the column. This only applies to Bar and Column series.
        */
        get radiusX() {
            return this.i.bg;
        }
        set radiusX(v) {
            this.i.bg = +v;
        }
        /**
         * Gets the actual corner radius of the series
        */
        get actualRadiusX() {
            return this.i.ax;
        }
        set actualRadiusX(v) {
            this.i.ax = +v;
        }
        /**
         * Gets whether the spline part is considered to be part of the range
        */
        get actualIsSplineShapePartOfRange() {
            return this.i.ac;
        }
        set actualIsSplineShapePartOfRange(v) {
            this.i.ac = ensureBool(v);
        }
        /**
         * Gets or sets whether to include the spline shape in the axis range requested of the axis.
        */
        get isSplineShapePartOfRange() {
            return this.i.ai;
        }
        set isSplineShapePartOfRange(v) {
            this.i.ai = ensureBool(v);
        }
        /**
         * Gets or sets the y-radius of the ellipse that is used to round the corners of the column. This only applies to Bar and Column series.
        */
        get radiusY() {
            return this.i.bh;
        }
        set radiusY(v) {
            this.i.bh = +v;
        }
        /**
         * Gets the actual corner radius of the series
        */
        get actualRadiusY() {
            return this.i.ay;
        }
        set actualRadiusY(v) {
            this.i.ay = +v;
        }
        /**
         * Gets or sets the width of the current series object's line thickness.
        */
        get thickness() {
            return this.i.bl;
        }
        set thickness(v) {
            this.i.bl = +v;
        }
        /**
         * Gets or sets the thickness of this stacked fragment.
        */
        get actualThickness() {
            return this.i.a2;
        }
        set actualThickness(v) {
            this.i.a2 = +v;
        }
        /**
         * Gets or sets the width of the current series object's marker thickness.
        */
        get markerThickness() {
            return this.i.be;
        }
        set markerThickness(v) {
            this.i.be = +v;
        }
        /**
         * Gets actual marker thickness of this stacked fragment.
        */
        get actualMarkerThickness() {
            return this.i.av;
        }
        set actualMarkerThickness(v) {
            this.i.av = +v;
        }
        /**
         * Gets or sets the Title property.
         * The legend item control is created according to the Title on-demand by
         * the series object itself.
        */
        get title() {
            return this.i.bv;
        }
        set title(v) {
            this.i.bv = v;
        }
        /**
         * Gets or sets the value mapping property for the current series object.
        */
        get valueMemberPath() {
            return this.i.d4;
        }
        set valueMemberPath(v) {
            this.i.d4 = v;
        }
        /**
         * Gets or sets the Visibility of the stacked fragment.
        */
        get visibility() {
            return this.i.ix;
        }
        set visibility(v) {
            this.i.ix = ensureEnum(Visibility_$type, v);
        }
        /**
         * Gets the actual visibility of the stacked fragment.
        */
        get actualVisibility() {
            return this.i.iv;
        }
        set actualVisibility(v) {
            this.i.iv = ensureEnum(Visibility_$type, v);
        }
        /**
         * Gets the resolved brush used between the local series and the parent series.
        */
        get parentOrLocalBrush() {
            return brushToString(this.i.h2);
        }
        set parentOrLocalBrush(v) {
            this.i.h2 = stringToBrush(v);
        }
        findByName(name) {
            return null;
        }
        get hasUserValues() {
            return this._hasUserValues;
        }
        __m(propertyName) {
            if (!this._inStyling) {
                this._hasUserValues.add(propertyName);
            }
        }
        _styling(container, component, parent) {
            if (this._inStyling) {
                return;
            }
            this._inStyling = true;
            this._stylingContainer = container;
            this._stylingParent = component;
            let genericPrefix = "";
            let typeName = this.i.$type.name;
            if (typeName.indexOf("Xam") === 0) {
                typeName = typeName.substring(3);
            }
            genericPrefix = toSpinal("StackedFragmentSeriesComponent");
            let additionalPrefixes = [];
            let prefix = toSpinal(typeName);
            additionalPrefixes.push(prefix + "-");
            let b = this.i.$type.baseType;
            while (b && b.name != "Object" &&
                b.name != "Base" &&
                b.name != "Control" &&
                b.Name != "DependencyObject" &&
                b.Name != "FrameworkElement") {
                typeName = b.name;
                if (typeName.indexOf("Xam") === 0) {
                    typeName = typeName.substring(3);
                }
                let basePrefix = toSpinal(typeName);
                additionalPrefixes.push(basePrefix + "-");
                b = b.baseType;
            }
            if (parent) {
                let parentTypeName = parent.i.$type.name;
                if (parentTypeName.indexOf("Xam") === 0) {
                    parentTypeName = parentTypeName.substring(3);
                }
                let parentPrefix = toSpinal(parentTypeName);
                additionalPrefixes.push(parentPrefix + "-" + genericPrefix + "-");
                additionalPrefixes.push(parentPrefix + "-" + prefix + "-");
            }
            initializePropertiesFromCss(container, this, genericPrefix + "-", this.hasUserValues, false, additionalPrefixes);
            if (this._otherStyling) {
                this._otherStyling(container, component, parent);
            }
            this._inStyling = false;
        }
        /**
         * Gets the item item index associated with the specified world position
        
        */
        getItemIndex(world) {
            let iv = this.i.bn(toPoint(world));
            return (iv);
        }
        /**
         * Gets the item that is the best match for the specified world coordinates.
        
        * @param world  * The world coordinates to use.
        */
        getItem(world) {
            let iv = this.i.bt(toPoint(world));
            return (iv);
        }
        getPreviousOrExactIndex(world, skipUnknowns) {
            let iv = this.i.bq(toPoint(world), skipUnknowns);
            return (iv);
        }
        getNextOrExactIndex(world, skipUnknowns) {
            let iv = this.i.bp(toPoint(world), skipUnknowns);
            return (iv);
        }
        getSeriesValue(world, useInterpolation, skipUnknowns) {
            let iv = this.i.ba(toPoint(world), useInterpolation, skipUnknowns);
            return (iv);
        }
        getSeriesValuePosition(world, useInterpolation, skipUnknowns) {
            let iv = this.i.ij(toPoint(world), useInterpolation, skipUnknowns);
            return fromPoint(iv);
        }
        /**
         * If possible, will return the best available value bounding box within the series that has the best value match for the world position provided.
        
        * @param world  * The world coordinate for which to get a value bounding box for
        */
        getSeriesValueBoundingBox(world) {
            let iv = this.i.io(toPoint(world));
            return fromRect(iv);
        }
        /**
         * If possible, will return the best available value marker bounding box within the series that has the best value match for the world position provided.
        
        * @param world  * The world coordinates for which to get a value marker bounding box for
        */
        getSeriesValueMarkerBoundingBox(world) {
            let iv = this.i.iq(toPoint(world));
            return fromRect(iv);
        }
        getSeriesHighValue(world, useInterpolation, skipUnknowns) {
            let iv = this.i.a6(toPoint(world), useInterpolation, skipUnknowns);
            return (iv);
        }
        getSeriesHighValuePosition(world, useInterpolation, skipUnknowns) {
            let iv = this.i.ie(toPoint(world), useInterpolation, skipUnknowns);
            return fromPoint(iv);
        }
        getSeriesLowValue(world, useInterpolation, skipUnknowns) {
            let iv = this.i.a8(toPoint(world), useInterpolation, skipUnknowns);
            return (iv);
        }
        getSeriesLowValuePosition(world, useInterpolation, skipUnknowns) {
            let iv = this.i.ih(toPoint(world), useInterpolation, skipUnknowns);
            return fromPoint(iv);
        }
        getSeriesValuePositionFromSeriesPixel(mouse, useInterpolation, skipUnknowns) {
            let iv = this.i.ik(toPoint(mouse), useInterpolation, skipUnknowns);
            return fromPoint(iv);
        }
        getSeriesValueFromSeriesPixel(mouse, useInterpolation, skipUnknowns) {
            let iv = this.i.bb(toPoint(mouse), useInterpolation, skipUnknowns);
            return (iv);
        }
        /**
         * For a category plotted series, returns the current width of the items within the categories. This only returns a value if the items have some form of width (e.g. columns, bars, etc.) otherwise 0 is returned.
        
        */
        getItemSpan() {
            let iv = this.i.a5();
            return (iv);
        }
        /**
         * Converts a point from coordinates within the series plot area to a world position within axis space.
        
        * @param seriesPoint  * The pixel location within the plot area of the series.
        */
        toWorldPosition(seriesPoint) {
            let iv = this.i.il(toPoint(seriesPoint));
            return fromPoint(iv);
        }
        /**
         * Converts a point from world coordinates to coordinates within the viewport of the series.
        
        * @param world  * The world position from which to convert.
        */
        fromWorldPosition(world) {
            let iv = this.i.id(toPoint(world));
            return fromPoint(iv);
        }
        /**
         * Requests that the provided item should be brought into view if possible.
        
        * @param item  * The item to attempt to bring into view.
        */
        scrollIntoView(item) {
            let iv = this.i.ak(item);
            return (iv);
        }
        /**
         * Gets the effective viewport, adjusted to account for margins and other factors.
        
        */
        getEffectiveViewport() {
            let iv = this.i.im();
            return fromRect(iv);
        }
        /**
         * Notifies the series that a visual property has changed, requiring a visual update.
        
        */
        notifyVisualPropertiesChanged() {
            this.i.d8();
        }
        /**
         * Simulates a pointer hover over the series surface.
        
        * @param point  * The pointer position relative to the series viewport over which to hover.
        */
        simulateHover(point) {
            this.i.ec(toPoint(point));
        }
        /**
         * Moves the cursor point to the provided world position. Some series may react to the current cursor position.
        
        * @param point  * The cursor point, in world coordinates.
        */
        moveCursorPoint(point) {
            this.i.d7(toPoint(point));
        }
        /**
         * Event raised when a property (including "effective" and non-dependency property) value changes.
        */
        get propertyUpdated() {
            if (this._propertyUpdated == null) {
                this._propertyUpdated = new EventEmitter();
                this.i.propertyUpdated = delegateCombine(this.i.propertyUpdated, (o, e) => {
                    this._runInZone(() => {
                        let outerArgs = new IgxPropertyUpdatedEventArgs();
                        outerArgs._provideImplementation(e);
                        if (this.beforePropertyUpdated) {
                            this.beforePropertyUpdated(this, outerArgs);
                        }
                        this._propertyUpdated.emit({
                            sender: this,
                            args: outerArgs
                        });
                    });
                });
            }
            return this._propertyUpdated;
        }
        _runInZone(act) {
            if (this._zoneRunner != null) {
                this._zoneRunner(act);
            }
            else {
                act();
            }
        }
    }
    IgxStackedFragmentSeriesComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.13", ngImport: i0, type: IgxStackedFragmentSeriesComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
    IgxStackedFragmentSeriesComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "12.2.13", type: IgxStackedFragmentSeriesComponent, selector: "igx-stacked-fragment-series", inputs: { dataSource: "dataSource", brush: "brush", actualBrush: "actualBrush", isDropShadowEnabled: "isDropShadowEnabled", actualIsDropShadowEnabled: "actualIsDropShadowEnabled", shadowBlur: "shadowBlur", actualShadowBlur: "actualShadowBlur", shadowColor: "shadowColor", actualShadowColor: "actualShadowColor", useSingleShadow: "useSingleShadow", actualUseSingleShadow: "actualUseSingleShadow", shadowOffsetX: "shadowOffsetX", actualShadowOffsetX: "actualShadowOffsetX", shadowOffsetY: "shadowOffsetY", actualShadowOffsetY: "actualShadowOffsetY", legendItemBadgeTemplate: "legendItemBadgeTemplate", actualLegendItemBadgeTemplate: "actualLegendItemBadgeTemplate", legendItemTemplate: "legendItemTemplate", actualLegendItemTemplate: "actualLegendItemTemplate", legendItemVisibility: "legendItemVisibility", actualLegendItemVisibility: "actualLegendItemVisibility", legendItemBadgeShape: "legendItemBadgeShape", legendItemBadgeMode: "legendItemBadgeMode", actualLegendItemBadgeShape: "actualLegendItemBadgeShape", actualLegendItemBadgeMode: "actualLegendItemBadgeMode", markerBrush: "markerBrush", actualMarkerBrush: "actualMarkerBrush", markerOutline: "markerOutline", actualMarkerOutline: "actualMarkerOutline", markerTemplate: "markerTemplate", actualMarkerTemplate: "actualMarkerTemplate", markerType: "markerType", actualMarkerType: "actualMarkerType", name: "name", opacity: "opacity", actualOpacity: "actualOpacity", outline: "outline", actualOutline: "actualOutline", areaFillOpacity: "areaFillOpacity", actualAreaFillOpacity: "actualAreaFillOpacity", markerFillOpacity: "markerFillOpacity", actualMarkerFillOpacity: "actualMarkerFillOpacity", outlineMode: "outlineMode", actualOutlineMode: "actualOutlineMode", highlightingFadeOpacity: "highlightingFadeOpacity", actualHighlightingFadeOpacity: "actualHighlightingFadeOpacity", radiusX: "radiusX", actualRadiusX: "actualRadiusX", actualIsSplineShapePartOfRange: "actualIsSplineShapePartOfRange", isSplineShapePartOfRange: "isSplineShapePartOfRange", radiusY: "radiusY", actualRadiusY: "actualRadiusY", thickness: "thickness", actualThickness: "actualThickness", markerThickness: "markerThickness", actualMarkerThickness: "actualMarkerThickness", title: "title", valueMemberPath: "valueMemberPath", visibility: "visibility", actualVisibility: "actualVisibility", parentOrLocalBrush: "parentOrLocalBrush" }, outputs: { propertyUpdated: "propertyUpdated" }, providers: [], ngImport: i0, template: ``, isInline: true, changeDetection: i0.ChangeDetectionStrategy.OnPush });
    return IgxStackedFragmentSeriesComponent;
})();
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.13", ngImport: i0, type: IgxStackedFragmentSeriesComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'igx-stacked-fragment-series',
                    template: ``,
                    providers: [],
                    changeDetection: ChangeDetectionStrategy.OnPush
                }]
        }], ctorParameters: function () { return []; }, propDecorators: { dataSource: [{
                type: Input
            }], brush: [{
                type: Input
            }], actualBrush: [{
                type: Input
            }], isDropShadowEnabled: [{
                type: Input
            }], actualIsDropShadowEnabled: [{
                type: Input
            }], shadowBlur: [{
                type: Input
            }], actualShadowBlur: [{
                type: Input
            }], shadowColor: [{
                type: Input
            }], actualShadowColor: [{
                type: Input
            }], useSingleShadow: [{
                type: Input
            }], actualUseSingleShadow: [{
                type: Input
            }], shadowOffsetX: [{
                type: Input
            }], actualShadowOffsetX: [{
                type: Input
            }], shadowOffsetY: [{
                type: Input
            }], actualShadowOffsetY: [{
                type: Input
            }], legendItemBadgeTemplate: [{
                type: Input
            }], actualLegendItemBadgeTemplate: [{
                type: Input
            }], legendItemTemplate: [{
                type: Input
            }], actualLegendItemTemplate: [{
                type: Input
            }], legendItemVisibility: [{
                type: Input
            }], actualLegendItemVisibility: [{
                type: Input
            }], legendItemBadgeShape: [{
                type: Input
            }], legendItemBadgeMode: [{
                type: Input
            }], actualLegendItemBadgeShape: [{
                type: Input
            }], actualLegendItemBadgeMode: [{
                type: Input
            }], markerBrush: [{
                type: Input
            }], actualMarkerBrush: [{
                type: Input
            }], markerOutline: [{
                type: Input
            }], actualMarkerOutline: [{
                type: Input
            }], markerTemplate: [{
                type: Input
            }], actualMarkerTemplate: [{
                type: Input
            }], markerType: [{
                type: Input
            }], actualMarkerType: [{
                type: Input
            }], name: [{
                type: Input
            }], opacity: [{
                type: Input
            }], actualOpacity: [{
                type: Input
            }], outline: [{
                type: Input
            }], actualOutline: [{
                type: Input
            }], areaFillOpacity: [{
                type: Input
            }], actualAreaFillOpacity: [{
                type: Input
            }], markerFillOpacity: [{
                type: Input
            }], actualMarkerFillOpacity: [{
                type: Input
            }], outlineMode: [{
                type: Input
            }], actualOutlineMode: [{
                type: Input
            }], highlightingFadeOpacity: [{
                type: Input
            }], actualHighlightingFadeOpacity: [{
                type: Input
            }], radiusX: [{
                type: Input
            }], actualRadiusX: [{
                type: Input
            }], actualIsSplineShapePartOfRange: [{
                type: Input
            }], isSplineShapePartOfRange: [{
                type: Input
            }], radiusY: [{
                type: Input
            }], actualRadiusY: [{
                type: Input
            }], thickness: [{
                type: Input
            }], actualThickness: [{
                type: Input
            }], markerThickness: [{
                type: Input
            }], actualMarkerThickness: [{
                type: Input
            }], title: [{
                type: Input
            }], valueMemberPath: [{
                type: Input
            }], visibility: [{
                type: Input
            }], actualVisibility: [{
                type: Input
            }], parentOrLocalBrush: [{
                type: Input
            }], propertyUpdated: [{
                type: Output
            }] } });
//# sourceMappingURL=igx-stacked-fragment-series-component.js.map
