import { IgxSeriesComponent } from "./igx-series-component";
/**
 * Represents event arguments for chart's SeriesAdded and SeriesRemoved events
*
* The `IgxDomainChartSeriesPointerEventArgs` class provide events for chart's SeriesAdded and SeriesRemoved.
*
* `SeriesPointerDown` get fired when the pointer is press down over a Series.
*
* ```html
*  <igx-financial-chart
*       #chart
*       [dataSource]="data"
*       (seriesPointerDown)=chart_seriesPointerDown()
*       >
*     </igx-financial-chart>
* ```
*
* ```ts
* this.chart.seriesPointerDown = this.chart_seriesPointerDown();
* ```
*/
var IgxDomainChartSeriesPointerEventArgs = /** @class */ /*@__PURE__*/ (function () {
    function IgxDomainChartSeriesPointerEventArgs() {
    }
    Object.defineProperty(IgxDomainChartSeriesPointerEventArgs.prototype, "i", {
        /**
         * @hidden
         */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgxDomainChartSeriesPointerEventArgs.prototype.onImplementationCreated = function () {
    };
    IgxDomainChartSeriesPointerEventArgs.prototype._provideImplementation = function (i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    };
    Object.defineProperty(IgxDomainChartSeriesPointerEventArgs.prototype, "series", {
        /**
         * Gets the series hit by the pointer.
        *
        * Use the `series` property to get the series.
        *
        * ```ts
        *  var series= args.series;
        * ```
        */
        get: function () {
            if (this.i.series == null) {
                return null;
            }
            if (!this.i.series.externalObject) {
                var e = IgxSeriesComponent._createFromInternal(this.i.series);
                if (e) {
                    e._implementation = this.i.series;
                }
                this.i.series.externalObject = e;
            }
            return this.i.series.externalObject;
        },
        set: function (v) {
            v == null ? this.i.series = null : this.i.series = v.i;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgxDomainChartSeriesPointerEventArgs.prototype, "item", {
        /**
         * Gets the item hit by the pointer.
        *
        * Use the `item` property to get the items.
        *
        * <https://www.infragistics.com/help/wpf/infragisticswpf.controls.charts.xamdatachart~infragistics.controls.charts.domainchartseriespointereventargs~item>
        *
        * ```ts
        * var Chartitem = args.item;
        * ```
        */
        get: function () {
            return this.i.item;
        },
        set: function (v) {
            this.i.item = v;
        },
        enumerable: false,
        configurable: true
    });
    return IgxDomainChartSeriesPointerEventArgs;
}());
export { IgxDomainChartSeriesPointerEventArgs };
//# sourceMappingURL=igx-domain-chart-series-pointer-event-args.js.map
