import { IgxStrategyBasedIndicatorComponent } from "./igx-strategy-based-indicator-component";
import { AverageTrueRangeIndicator } from "./AverageTrueRangeIndicator";
import * as i0 from "@angular/core";
/**
 * Represents a IgxDataChartComponent Average True Range indicator series.
 * Default required members: High, Low, Close
*
* You can use the `IgxAverageTrueRangeIndicatorComponent` to measures a security's degree of price movement or volatility within a given period of time.
*
* ```html
* <igx-data-chart
* 	#chart
*     [dataSource]="data" >
*     <igx-category-x-axis
* 		label="label"
* 		#xAxis>
*     </igx-category-x-axis>
*     <igx-numeric-y-axis
* 		#yAxis>
*     </igx-numeric-y-axis>
*     <igx-average-true-range-indicator
* 		[xAxis]="xAxis"
* 		[yAxis]="yAxis"
* 		openMemberPath="open"
* 		highMemberPath="high"
* 		lowMemberPath="low"
* 		closeMemberPath="close">
*     </igx-average-true-range-indicator>
* </igx-data-chart>
* ```
*
* ```ts
* let series = new IgxAverageTrueRangeIndicatorComponent();
* series.xAxis = this.xAxis;
* series.yAxis = this.yAxis;
* series.openMemberPath = "open";
* series.highMemberPath = "high";
* series.lowMemberPath = "low";
* series.closeMemberPath = "close";
* this.chart.series.add(series);
* ```
*/
export declare class IgxAverageTrueRangeIndicatorComponent extends IgxStrategyBasedIndicatorComponent {
    protected createImplementation(): AverageTrueRangeIndicator;
    /**
                                 * @hidden
                                 */
    get i(): AverageTrueRangeIndicator;
    constructor();
    /**
     * Gets or sets the moving average period for the current AverageTrueRangeSeries object.
     * The typical, and initial, value for AverageTrueRange periods is 14.
    *
    * You can use the `period` to set the moving average.
    *
    * ```html
    * <igx-data-chart
    *     [dataSource]="data" >
    *     <igx-category-x-axis
    * 		label="label"
    * 		#xAxis>
    *     </igx-category-x-axis>
    *     <igx-numeric-y-axis
    * 		#yAxis>
    *     </igx-numeric-y-axis>
    *     <igx-average-true-range-indicator
    * 		#series
    * 		[xAxis]="xAxis"
    * 		[yAxis]="yAxis"
    * 		openMemberPath="open"
    * 		highMemberPath="high"
    * 		lowMemberPath="low"
    * 		closeMemberPath="close"
    * 		period="14">
    *     </igx-average-true-range-indicator>
    * </igx-data-chart>
    * ```
    *
    * ```ts
    * this.series.period = 14;
    * ```
    */
    get period(): number;
    set period(v: number);
    static ngAcceptInputType_period: number | string;
    static ɵfac: i0.ɵɵFactoryDeclaration<IgxAverageTrueRangeIndicatorComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<IgxAverageTrueRangeIndicatorComponent, "igx-average-true-range-indicator", never, { "period": "period"; }, {}, never, never>;
}
