import { IgxCategoryAxisBaseComponent } from "./igx-category-axis-base-component";
import { IgxAnnotationLayerComponent } from "./igx-annotation-layer-component";
import { CategoryHighlightLayer } from "./CategoryHighlightLayer";
import * as i0 from "@angular/core";
/**
 * Represents an annotation layer that targets a category axis, or all category axes in the chart.
 * If the axis contains any series that are aligned between major gridlines of the axis (column, waterfall, etc) this will render a shape that fills the current category.
 * Otherwise it will render a band with an adjustable thickness at the closest gridline to the pointer position.
 * Setting UseIterpolation to true will cause the x position in the latter case to become affixed to the x position of the pointer.
*/
export declare class IgxCategoryHighlightLayerComponent extends IgxAnnotationLayerComponent {
    protected createImplementation(): CategoryHighlightLayer;
    /**
                                 * @hidden
                                 */
    get i(): CategoryHighlightLayer;
    constructor();
    /**
     * Gets whether the series is an annotation layer displayed only when hovering over the chart.
    */
    get isAnnotationHoverLayer(): boolean;
    static ngAcceptInputType_isAnnotationHoverLayer: boolean | string;
    /**
     * Gets or sets the axis to target this annotation to. If null, this annotation targets all category axes simultaneously.
    */
    get targetAxis(): IgxCategoryAxisBaseComponent;
    set targetAxis(v: IgxCategoryAxisBaseComponent);
    /**
     * Gets or sets whether to use value interpolation when drawing a line through the best value for the pointer position.
    */
    get useInterpolation(): boolean;
    set useInterpolation(v: boolean);
    static ngAcceptInputType_useInterpolation: boolean | string;
    /**
     * Gets or sets the width to use for the highlight region if drawing a band rather than filling a category.
    */
    get bandHighlightWidth(): number;
    set bandHighlightWidth(v: number);
    static ngAcceptInputType_bandHighlightWidth: number | string;
    findByName(name: string): any;
    protected _styling(container: any, component: any, parent?: any): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<IgxCategoryHighlightLayerComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<IgxCategoryHighlightLayerComponent, "igx-category-highlight-layer", never, { "targetAxis": "targetAxis"; "useInterpolation": "useInterpolation"; "bandHighlightWidth": "bandHighlightWidth"; }, {}, never, never>;
}
