import { EventEmitter } from '@angular/core';
import { IgxStrategyBasedIndicatorComponent } from './igx-strategy-based-indicator-component';
import { CustomIndicator } from "./CustomIndicator";
import { IgxFinancialEventArgs } from "./igx-financial-event-args";
import * as i0 from "@angular/core";
/**
 * Represents a IgxDataChartComponent Custom Indicator series.
 * The indicator value is calculated in the user specified Indicator event handler.
*
* `IgxCustomIndicatorComponent` class specify the series as Custom Indicator series.
*
* ```html
* <igx-data-chart [dataSource]="data">
*   <igx-category-x-axis #xAxis
*     label="time">
*   </igx-category-x-axis>
*   <igx-numeric-y-axis #yAxis>
*   </igx-numeric-y-axis>
*   <igx-commodity-channel-index-indicator
*     [xAxis]="xAxis"
*     [yAxis]="yAxis"
*     openMemberPath="open"
*     highMemberPath="high"
*     lowMemberPath="low"
*     closeMemberPath="close"
*     volumeMemberPath="volume" >
*   </igx-commodity-channel-index-indicator>
* </igx-data-chart>
* ```
*
* ```ts
* let series = new IgxCustomIndicatorComponent();
* series.xAxis = this.xAxis;
* series.yAxis = this.yAxis;
* series.openMemberPath = "open";
* series.highMemberPath = "high";
* series.lowMemberPath = "low";
* series.closeMemberPath = "close";
* this.chart.series.add(series);
* ```
*/
export declare class IgxCustomIndicatorComponent extends IgxStrategyBasedIndicatorComponent {
    protected createImplementation(): CustomIndicator;
    get i(): CustomIndicator;
    constructor();
    private _indicator;
    /**
     * This event is raised when the indicator values need to be computed.
    */
    get indicator(): EventEmitter<{
        sender: any;
        args: IgxFinancialEventArgs;
    }>;
    private _basedOnColumns;
    /**
     * This event is raised when the based on columns to be specified.
    */
    get basedOnColumns(): EventEmitter<{
        sender: any;
        args: IgxFinancialEventArgs;
    }>;
    static ɵfac: i0.ɵɵFactoryDeclaration<IgxCustomIndicatorComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<IgxCustomIndicatorComponent, "igx-custom-indicator", never, {}, { "indicator": "indicator"; "basedOnColumns": "basedOnColumns"; }, never, never>;
}
