import { TemplateRef, EventEmitter, OnInit } from '@angular/core';
import { IgRect } from "igniteui-angular-core";
import { HorizontalAlignment } from "igniteui-angular-core";
import { UnknownValuePlotting } from "igniteui-angular-core";
import { TrendLineType } from "igniteui-angular-core";
import { IgxChartSeriesEventArgs } from './igx-chart-series-event-args';
import { DomainChart } from "./DomainChart";
import { IgxDomainChartSeriesPointerEventArgs } from './igx-domain-chart-series-pointer-event-args';
import { IgxMarkerTypeCollection } from './igx-marker-type-collection';
import { ToolTipType } from "./ToolTipType";
import { CrosshairsDisplayMode } from "./CrosshairsDisplayMode";
import { IgxCalloutStyleUpdatingEventArgs } from "./igx-callout-style-updating-event-args";
import { ComputedPlotAreaMarginMode } from './ComputedPlotAreaMarginMode';
import { SeriesHighlightingMode } from './SeriesHighlightingMode';
import { SeriesHighlightingBehavior } from './SeriesHighlightingBehavior';
import { LegendHighlightingMode } from './LegendHighlightingMode';
import { SeriesOutlineMode } from './SeriesOutlineMode';
import { MarkerOutlineMode } from './MarkerOutlineMode';
import { MarkerFillMode } from './MarkerFillMode';
import { MarkerAutomaticBehavior } from './MarkerAutomaticBehavior';
import { LegendItemBadgeMode } from './LegendItemBadgeMode';
import { LegendItemBadgeShape } from './LegendItemBadgeShape';
import { DomainType } from "./DomainType";
import * as i0 from "@angular/core";
/**
 * Represents a base class for all domain charts that can plot scatter data and shapefiles
*
* ```html
* <igx-category-chart
*       yAxisMinimumValue="0"
*       [dataSource]="data"
*       bottomMargin= 20>
*     </igx-category-chart>
* ```
*/
export declare abstract class IgxDomainChartComponent implements OnInit {
    protected createImplementation(): DomainChart;
    ngOnInit(): void;
    protected _implementation: any;
    get i(): DomainChart;
    protected onImplementationCreated(): void;
    constructor();
    /**
    * Sets or gets the template reference to use for tooltips for all the series.
    *
    *
    */
    get tooltipTemplate(): TemplateRef<any>;
    set tooltipTemplate(v: TemplateRef<any>);
    /**
    * Sets or gets the template references to use for tooltips for all the series, in order.
    *
    *
    */
    get tooltipTemplates(): TemplateRef<any>[];
    set tooltipTemplates(v: TemplateRef<any>[]);
    get legend(): any;
    set legend(v: any);
    private _calloutsDataSource;
    set calloutsDataSource(value: Array<any>);
    get calloutsDataSource(): Array<any>;
    bindCalloutsData(): void;
    /**
 * Gets or sets the scaling value used to affect the pixel density of the control.
 * A higher scaling ratio will produce crisper visuals at the expense of memory.  Lower values will cause the control
 * to appear blurry.
*/
    get pixelScalingRatio(): number;
    set pixelScalingRatio(v: number);
    static ngAcceptInputType_pixelScalingRatio: number | string;
    /**
     * Gets or sets the left margin of chart title
    *
    *  Use `titleLeftMargin` property for the left margin of chart title.
    *
    * ```html
    * <igx-category-chart
    *     yAxisMinimumValue="0"
    *     [dataSource]="data"
    * 	titleLeftMargin= 10>
    * </igx-category-chart>
    * ```
    *
    * ```ts
    * this.chart.titleLeftMargin = 10;
    * ```
    */
    get titleLeftMargin(): number;
    set titleLeftMargin(v: number);
    static ngAcceptInputType_titleLeftMargin: number | string;
    /**
     * Gets or sets the right margin of chart title
    *
    *  Use `titleLeftMargin` property for the right margin of chart title.
    *
    * ```html
    * <igx-category-chart
    * 		yAxisMinimumValue="0"
    * 		[dataSource]="data"
    * 		titleRightMargin= 10>
    * </igx-category-chart>
    * ```
    *
    * ```ts
    * this.chart.titleRightMargin = 10;
    * ```
    */
    get titleRightMargin(): number;
    set titleRightMargin(v: number);
    static ngAcceptInputType_titleRightMargin: number | string;
    /**
     * Gets or sets the top margin of chart title
    *
    *  Use `titleTopMargin` property for the top margin of chart title.
    *
    * ```html
    * <igx-category-chart
    *      yAxisMinimumValue="0"
    *      [dataSource]="data"
    *      title="Countries"
    *      titleTopMargin=10 >
    * </igx-category-chart>
    * ```
    *
    * ```ts
    * this.chart.titleTopMargin = 10;
    * ```
    */
    get titleTopMargin(): number;
    set titleTopMargin(v: number);
    static ngAcceptInputType_titleTopMargin: number | string;
    /**
     * Gets or sets the bottom margin of chart title
    *
    *  Use `titleBottomMargin` property for the bottom margin of chart title.
    *
    * ```html
    * <igx-category-chart
    *    yAxisMinimumValue="0"
    *    [dataSource]="data"
    *    titleBottomMargin= 10 >
    * </igx-category-chart>
    * ```
    *
    * ```ts
    *  this.chart.titleBottomMargin = 5;
    * ```
    */
    get titleBottomMargin(): number;
    set titleBottomMargin(v: number);
    static ngAcceptInputType_titleBottomMargin: number | string;
    /**
     * Gets or sets the left margin of chart subtitle
    *
    * Use `subtitleLeftMargin` property for the left margin of chart subtitle.
    *
    * ```html
    * <igx-category-chart
    *     yAxisMinimumValue="0"
    *     [dataSource]="data"
    *     subtitleLeftMargin= 20>
    * </igx-category-chart>
    * ```
    *
    * ```ts
    * this.chart.subtitleLeftMargin = 20 ;
    * ```
    */
    get subtitleLeftMargin(): number;
    set subtitleLeftMargin(v: number);
    static ngAcceptInputType_subtitleLeftMargin: number | string;
    /**
     * Gets or sets the top margin of chart subtitle
    *
    * Use `subtitleTopMargin` property for the top margin of chart subtitle.
    *
    * ```html
    *    <igx-category-chart
    *       yAxisMinimumValue="0"
    *       [dataSource]="data"
    *       subtitle= "This is a subtitle"
    *       subtitleTopMargin=10>
    *     </igx-category-chart>
    * ```
    *
    * ```ts
    * this.chart.subtitleTopMargin = 10;
    * ```
    */
    get subtitleTopMargin(): number;
    set subtitleTopMargin(v: number);
    static ngAcceptInputType_subtitleTopMargin: number | string;
    /**
     * Gets or sets the right margin of chart subtitle
    *
    * Use `subtitleRightMargin` property for the right margin of chart subtitle.
    *
    * ```html
    * <igx-category-chart
    *     yAxisMinimumValue="0"
    *     [dataSource]="data"
    *     subtitleRightMargin= 10>
    * </igx-category-chart>
    * ```
    *
    * ```ts
    *  this.chart.subtitleRightMargin = 20 ;
    * ```
    */
    get subtitleRightMargin(): number;
    set subtitleRightMargin(v: number);
    static ngAcceptInputType_subtitleRightMargin: number | string;
    /**
     * Gets or sets the bottom margin of chart subtitle
    *
    * Use `subtitleBottomMargin` property for the bottom margin of chart subtitle.
    *
    * ```html
    * <igx-category-chart
    *     yAxisMinimumValue="0"
    *     [dataSource]="data"
    * 	subtitleBottomMargin=10>
    * </igx-category-chart>
    * ```
    *
    * ```ts
    * this.chart.subtitleBottomMargin = 10 ;
    * ```
    */
    get subtitleBottomMargin(): number;
    set subtitleBottomMargin(v: number);
    static ngAcceptInputType_subtitleBottomMargin: number | string;
    /**
     * Gets or sets color of chart subtitle
    *
    * Use `subtitleTextColor` property to color the subtitle.
    *
    * ```html
    *  <igx-category-chart
    *       yAxisMinimumValue="0"
    *       [dataSource]="data"
    *       subtitle= "This is a subtitle"
    *       subtitleTextColor= 'blue'>
    *     </igx-category-chart>
    * ```
    *
    * ```ts
    * this.chart.subtitleTextColor = "#ff0000" ;
    * ```
    */
    get subtitleTextColor(): string;
    set subtitleTextColor(v: string);
    /**
     * Gets or sets color of chart title
    *
    *  Use `titleTextColor` property to color the chart title
    *
    * ```html
    * <igx-category-chart
    *       yAxisMinimumValue="0"
    *       [dataSource]="data"
    *       titleTextColor= "red">
    * </igx-category-chart>
    * ```
    *
    * ```ts
    *  this.chart.titleTextColor="red" ;
    * ```
    */
    get titleTextColor(): string;
    set titleTextColor(v: string);
    /**
     * Gets or sets the left margin of the chart content.
    *
    * Use the 'leftMargin' property for the left margin of the chart content.
    *
    * ```html
    * <igx-category-chart
    *       yAxisMinimumValue="0"
    *       [dataSource]="data"
    *       leftMargin=20>
    * </igx-category-chart>
    * ```
    *
    * ```ts
    *  this.chart.leftMargin = 20;
    * ```
    */
    get leftMargin(): number;
    set leftMargin(v: number);
    static ngAcceptInputType_leftMargin: number | string;
    /**
     * Gets or sets the top margin of the chart content.
    *
    * Use `topMargin` property for the margin of the chart content.
    *
    * ```html
    * <igx-category-chart
    *     yAxisMinimumValue="0"
    *     [dataSource]="data"
    *     topMargin= 20>
    * </igx-category-chart>
    * ```
    *
    * ```ts
    * this.chart.topMargin=20;
    * ```
    */
    get topMargin(): number;
    set topMargin(v: number);
    static ngAcceptInputType_topMargin: number | string;
    /**
     * Gets or sets the right margin of the chart content.
    *
    * Use `rightMargin` property for the right margin of the chart content.
    *
    * ```html
    * <igx-category-chart
    *     yAxisMinimumValue="0"
    *     [dataSource]="data"
    *     rightMargin=20>
    * </igx-category-chart>
    * ```
    *
    * ```ts
    *   this.chart.rightMargin = 20 ;
    * ```
    */
    get rightMargin(): number;
    set rightMargin(v: number);
    static ngAcceptInputType_rightMargin: number | string;
    /**
     * Gets or sets the bottom margin around the chart content.
    *
    * Use the `bottomMargin` property for the bottom margin around the chart content.
    *
    * ```html
    * <igx-category-chart
    *       yAxisMinimumValue="0"
    *       [dataSource]="data"
    *       bottomMargin= 20>
    *     </igx-category-chart>
    * ```
    *
    * ```ts
    * this.chart.bottomMargin=20;
    * ```
    */
    get bottomMargin(): number;
    set bottomMargin(v: number);
    static ngAcceptInputType_bottomMargin: number | string;
    /**
     * Gets or sets the duration used for animating series plots when the data is changing
    *
    * Use the `transitionDuration` property to animating between data values.
    *
    * ```html
    * <igx-category-chart
    *     yAxisMinimumValue="0"
    *     [dataSource]="data"
    *     transitionDuration="500">
    * </igx-category-chart>
    * ```
    *
    * ```ts
    * this.chart.transitionDuratio= 500;
    * ```
    */
    get transitionDuration(): number;
    set transitionDuration(v: number);
    static ngAcceptInputType_transitionDuration: number | string;
    /**
     * Gets or sets the easing function used for animating series plots when the data is changing.
     * This can be set to one of the known values "linear" or "cubic," or it can be set to an easing function which takes a single numeric parameter and returns a number.
    *
    * The 'transitionInEasingFunction' property used for easing function for animating series plots when the chart is loading into view.
    *
    * ```html
    * <igx-category-chart
    *     yAxisMinimumValue="0"
    *     [dataSource]="data"
    *     transitionInEasingFunction= "cubic">
    * </igx-category-chart>
    * ```
    *
    * ```ts
    * this.chart.transitionInEasingFunction=  this.cubicFunc;
    *
    * cubicFunc(time: number) : number
    *   {
    *     return time;
    *   }
    * ```
    */
    get transitionEasingFunction(): (time: number) => number;
    set transitionEasingFunction(v: (time: number) => number);
    /**
     * Gets or sets CSS font property for the chart subtitle
    *
    * Use `subtitleTextStyle` property for the CSS font of the chart subtitle.
    *
    * ```html
    *  <igx-category-chart
    *       yAxisMinimumValue="0"
    *       [dataSource]="data"
    *       subtitle= "This is a subtitle"
    *       subtitleTextStyle ="16pt Verdona">
    *     </igx-category-chart>
    * ```
    *
    * ```ts
    * this.chart.subtitleTextStyle= "16pt Verdona";
    * ```
    */
    get subtitleTextStyle(): string;
    set subtitleTextStyle(v: string);
    /**
     * Gets or sets CSS font property for the chart title
    *
    * Use `titleTextStyle` property for the CSS font property of the chart title
    *
    * ```html
    *  <igx-category-chart
    *       yAxisMinimumValue="0"
    *       [dataSource]="data"
    *       titleTextStyle= "24pt Verdona">
    *     </igx-category-chart>
    * ```
    *
    * ```ts
    * this.chart.xAxisTitleTextStyle = "24pt Verdona";
    * ```
    */
    get titleTextStyle(): string;
    set titleTextStyle(v: string);
    /**
     * Gets the domain type of this chart
    */
    get domainType(): DomainType;
    static ngAcceptInputType_domainType: DomainType | string;
    /**
     * Gets or sets a set of property paths that should be included for consideration by the category chart, leaving the remainder excluded. If null, all properties will be considered.
    *
    * The `includedProperties` property used to include the properties for the consideration of the category chart.
    *
    * ```html
    * <igx-category-chart
    *     yAxisMinimumValue="0"
    *     [dataSource]="data"
    *     includedProperties="ProductName,Cost" >
    * </igx-category-chart>
    * ```
    *
    * ```ts
    * this.chart.includedProperties = ["ProductName", "Cost"];
    * ```
    */
    get includedProperties(): string[];
    set includedProperties(v: string[]);
    static ngAcceptInputType_includedProperties: string[] | string;
    /**
     * Gets or sets a set of property paths that should be excluded from consideration by the category chart.
    *
    * The `excludedProperties` property used for the property paths that should be excluded from consideration by the category chart.
    *
    * ```html
    * <igx-category-chart
    *     yAxisMinimumValue="0"
    *     [dataSource]="data"
    *     excludedProperties="ID">
    * </igx-category-chart>
    * ```
    *
    * ```ts
    * this.chart.excludedProperties = ["ID", "Discount"];
    * ```
    */
    get excludedProperties(): string[];
    set excludedProperties(v: string[]);
    static ngAcceptInputType_excludedProperties: string[] | string;
    /**
     * Gets or sets the palette of brushes to use for coloring the chart series.
     * The value provided should be an array of CSS color strings or JavaScript objects defining gradients. Optionally the first element can be a string reading "RGB" or "HSV" to specify the interpolation mode of the collection
    *
    * Use the `brushes` property to  set the brushes.
    *
    * ```html
    *  <igx-category-chart
    *       yAxisMinimumValue="0"
    *       [dataSource]="data"
    *       Brushes="#ff0000, #cc0000, #aa0000">
    *     </igx-category-chart>
    * ```
    *
    * ```ts
    * this.chart.brushes = ["#ff0000","#00ff00"];
    * ```
    */
    get brushes(): string[];
    set brushes(v: string[]);
    static ngAcceptInputType_brushes: string[] | string;
    /**
     * Gets or sets the palette of brushes to use for outlines on the chart series.
     * The value provided should be an array of CSS color strings or JavaScript objects defining gradients. Optionally the first element can be a string reading "RGB" or "HSV" to specify the interpolation mode of the collection
    *
    *  Use the `outlines` property to sets the palette of brushes to use for outlines on the chart series
    *
    * ```html
    * <igx-category-chart
    *     yAxisMinimumValue="0"
    *     [dataSource]="data"
    *     outlines="#ff0000, #cc0000, #aa0000">
    * </igx-category-chart>
    * ```
    */
    get outlines(): string[];
    set outlines(v: string[]);
    static ngAcceptInputType_outlines: string[] | string;
    /**
     * Gets the actual palette of brushes to use for coloring the chart series.
    */
    get actualBrushes(): string[];
    set actualBrushes(v: string[]);
    static ngAcceptInputType_actualBrushes: string[] | string;
    /**
     * Gets the actual palette of brushes to use for outlines on the chart series.
    */
    get actualOutlines(): string[];
    set actualOutlines(v: string[]);
    static ngAcceptInputType_actualOutlines: string[] | string;
    /**
     * Gets or sets whether the chart can be horizontally zoomed through user interactions.
    *
    * Use the `isHorizontalZoomEnabled` property to allow chart horizontally zoomed .
    *
    * ```html
    *  <igx-category-chart
    *       yAxisMinimumValue="0"
    *       [dataSource]="data"
    *       isHorizontalZoomEnabled=true>
    *   </igx-category-chart>
    * ```
    *
    * ```ts
    * this.chart.isHorizontalZoomEnabled = true;
    * ```
    */
    get isHorizontalZoomEnabled(): boolean;
    set isHorizontalZoomEnabled(v: boolean);
    static ngAcceptInputType_isHorizontalZoomEnabled: boolean | string;
    /**
     * Gets or sets whether the chart can be vertically zoomed through user interactions.
    *
    * Use the `isVerticalZoomEnabled` property to allow chart zoom vertically.
    *
    * ```html
    *  <igx-category-chart
    *       yAxisMinimumValue="0"
    *       [dataSource]="data"
    *       isVerticalZoomEnabled=true>
    *     </igx-category-chart>
    * ```
    *
    * ```ts
    *  this.chart.isVerticalZoomEnabled = true;
    * ```
    */
    get isVerticalZoomEnabled(): boolean;
    set isVerticalZoomEnabled(v: boolean);
    static ngAcceptInputType_isVerticalZoomEnabled: boolean | string;
    /**
     * Gets or sets whether the chart should display mock data when the data source has not been provided, if supported for this type of chart.
    */
    get shouldDisplayMockData(): boolean;
    set shouldDisplayMockData(v: boolean);
    static ngAcceptInputType_shouldDisplayMockData: boolean | string;
    /**
     * Gets or sets whether the chart should use a faded skeleton style for mock data.
    */
    get shouldUseSkeletonStyleForMockData(): boolean;
    set shouldUseSkeletonStyleForMockData(v: boolean);
    static ngAcceptInputType_shouldUseSkeletonStyleForMockData: boolean | string;
    /**
     * Gets or sets whether the chart can highlight series through user interactions.
     * This property applies to Category Chart and Financial Chart controls.
    */
    get isSeriesHighlightingEnabled(): boolean;
    set isSeriesHighlightingEnabled(v: boolean);
    static ngAcceptInputType_isSeriesHighlightingEnabled: boolean | string;
    /**
     * Gets or sets the rectangle representing the current scroll and zoom state of the chart.
     * WindowRect is expressed as a Rectangle with coordinates and sizes between 0 and 1.
    *
    * Use `windowRect` property representing the current scroll and zoom state of the chart.
    *
    * ```html
    * <igx-category-chart
    *       yAxisMinimumValue="0"
    *       [dataSource]="data"
    *       WindowRect=[0,0,1,1]>
    * </igx-category-chart>
    * ```
    *
    * ```ts
    * this.chart.windowRect =[0,0,1,1];
    * ```
    */
    get windowRect(): IgRect;
    set windowRect(v: IgRect);
    static ngAcceptInputType_windowRect: IgRect | string;
    /**
     * Gets a rectangle representing the bounds of the plot area.
    *
    * `viewport` property representing the bounds of the plot area.
    *
    * ```ts
    * let viewport:Rect =  this.chart.viewport;
    * ```
    */
    get viewport(): IgRect;
    static ngAcceptInputType_viewport: IgRect | string;
    /**
     * Gets or sets text to display above the plot area.
    *
    * Use the `chartTitle` property to display the text above the plot area.
    *
    * ```html
    * <igx-category-chart
    *     yAxisMinimumValue="0"
    *     [dataSource]="data"
    *     title="This is a Title">
    * </igx-category-chart>
    * ```
    *
    * ```ts
    *  this.chart.title= "This is a Title";
    * ```
    */
    get chartTitle(): string;
    set chartTitle(v: string);
    /**
     * Gets or sets text to display below the Title, above the plot area.
    *
    * Use the `subtitle` property to display the text below  and above the plot area.
    *
    * ```html
    * <igx-category-chart
    *     yAxisMinimumValue="0"
    *     [dataSource]="data"
    *     subtitle= "This is a subtitle">
    * </igx-category-chart>
    * ```
    *
    * ```ts
    *  this.chart.subtitle ="CategoryChart Subtitle" ;
    * ```
    */
    get subtitle(): string;
    set subtitle(v: string);
    /**
     * Gets or sets horizontal alignment which determines the title position, relative to the left and right edges of the control.
    *
    * Use the `titleAlignment` property for the horizontal alignment of the title.
    *
    * ```html
    * <igx-category-chart
    *     yAxisMinimumValue="0"
    *     [dataSource]="data"
    *     titleAlignment= "center">
    * </igx-category-chart>
    * ```
    *
    * ```ts
    * this.chart.titleAlignment = HorizontalAlignment.Center;
    * ```
    */
    get titleAlignment(): HorizontalAlignment;
    set titleAlignment(v: HorizontalAlignment);
    static ngAcceptInputType_titleAlignment: HorizontalAlignment | string;
    /**
     * Gets or sets horizontal alignment which determines the subtitle position, relative to the left and right edges of the control.
    *
    * Use the `subtitleAlignment` property to Gets or sets horizontal alignment.
    *
    * ```html
    * <igx-category-chart
    *     yAxisMinimumValue="0"
    *     [dataSource]="data"
    *     subtitleAlignment= "center">
    * </igx-category-chart>
    * ```
    *
    * ```ts
    * this.chart.subtitleAlignment = HorizontalAlignment.Right;
    * ```
    */
    get subtitleAlignment(): HorizontalAlignment;
    set subtitleAlignment(v: HorizontalAlignment);
    static ngAcceptInputType_subtitleAlignment: HorizontalAlignment | string;
    /**
     * Gets or sets the behavior that determines how unknown values will be plotted on the chart.
     * Null and Double.NaN are two examples of unknown values.
    *
    * Use the `unknownValuePlotting` property to determines the behavior that how unknown values will be plotted on the chart.
    *
    * ```html
    * <igx-category-chart
    *       yAxisMinimumValue="0"
    *       [dataSource]="data"
    *       unknownValuePlotting= "dontPlot">
    * </igx-category-chart>
    * ```
    *
    * ```ts
    * this.chart.unknownValuePlotting =UnknownValuePlotting.DontPlot;
    * ```
    */
    get unknownValuePlotting(): UnknownValuePlotting;
    set unknownValuePlotting(v: UnknownValuePlotting);
    static ngAcceptInputType_unknownValuePlotting: UnknownValuePlotting | string;
    /**
     * Gets or sets the rendering resolution for all series in this chart.
     * Where n = Resolution, for every n horizontal pixels, combine all items into a single data point.  When Resolution = 0, all data points will be rendered as graphical objects.  Charts with a higher resolution will have faster performance.
    *
    * Use the `resolution` property if the callouts should be display.
    *
    * ```html
    * <igx-category-chart
    *     yAxisMinimumValue="0"
    *     [dataSource]="data"
    *     resolution= 2>
    * </igx-category-chart>
    * ```
    *
    * ```ts
    *   this.chart.resolution = 2 ;
    * ```
    */
    get resolution(): number;
    set resolution(v: number);
    static ngAcceptInputType_resolution: number | string;
    /**
     * Gets or sets the thickness for all series in this chart. Depending on the ChartType, this can be the main brush used, or just the outline.
    *
    * Use the `thickness` property for the thickness of all the series in this chart.
    *
    * ```html
    * <igx-category-chart
    *     yAxisMinimumValue="0"
    *     [dataSource]="data"
    *     thickness=5>
    * </igx-category-chart>
    * ```
    */
    get thickness(): number;
    set thickness(v: number);
    static ngAcceptInputType_thickness: number | string;
    /**
     * Gets or sets the OutlineMode for all series in this chart.
    */
    get outlineMode(): SeriesOutlineMode;
    set outlineMode(v: SeriesOutlineMode);
    static ngAcceptInputType_outlineMode: SeriesOutlineMode | string;
    /**
     * Gets or sets the MarkerOutlineMode for all series that support markers in this chart.
    */
    get markerOutlineMode(): MarkerOutlineMode;
    set markerOutlineMode(v: MarkerOutlineMode);
    static ngAcceptInputType_markerOutlineMode: MarkerOutlineMode | string;
    /**
     * Gets or sets the MarkerFillMode for all series that support markers in this chart.
    */
    get markerFillMode(): MarkerFillMode;
    set markerFillMode(v: MarkerFillMode);
    static ngAcceptInputType_markerFillMode: MarkerFillMode | string;
    /**
     * Gets or sets the Marker Fill Opacity for all series that support markers in this chart.
    */
    get markerFillOpacity(): number;
    set markerFillOpacity(v: number);
    static ngAcceptInputType_markerFillOpacity: number | string;
    /**
     * Gets or sets the Marker Thickness for all series that support markers in this chart.
    */
    get markerThickness(): number;
    set markerThickness(v: number);
    static ngAcceptInputType_markerThickness: number | string;
    private _markerTypes;
    /**
     * Gets or sets the marker shapes used for indicating location of data points in this chart.
     * This property applies only to these chart types: point, line, spline, bubble, and polygon
    */
    get markerTypes(): IgxMarkerTypeCollection;
    set markerTypes(v: IgxMarkerTypeCollection);
    static ngAcceptInputType_markerTypes: IgxMarkerTypeCollection | string;
    /**
     * Gets or sets the default marker type for all series plotted in this chart.
     * This property is ignored when the MarkerTypes property is set
    */
    get markerAutomaticBehavior(): MarkerAutomaticBehavior;
    set markerAutomaticBehavior(v: MarkerAutomaticBehavior);
    static ngAcceptInputType_markerAutomaticBehavior: MarkerAutomaticBehavior | string;
    /**
     * Gets or sets the palette of brushes used for rendering fill area of data point markers.
     * This property applies only to these chart types: point, line, spline, bubble, and polygon
    *
    * `markerBrushes` property used for rendering fill area of data point markers.
    *
    * ```html
    * <igx-category-chart
    *     yAxisMinimumValue="0"
    *     [dataSource]="data"
    *     markerBrushes="#ff0000, #cc0000, #aa0000">
    * </igx-category-chart>
    * ```
    *
    * ```ts
    *  this.chart.markerBrushes=[ "#ff0000", "#ffff00", "#00ffff" ];
    * ```
    */
    get markerBrushes(): string[];
    set markerBrushes(v: string[]);
    static ngAcceptInputType_markerBrushes: string[] | string;
    /**
     * Gets or sets the palette of brushes used for rendering outlines of data point markers.
     * This property applies only to these chart types: point, line, spline, bubble, and polygon
    *
    * `markerOutlines` property used for rendering outlines of data point markers.
    *
    * ```html
    * <igx-category-chart
    *     yAxisMinimumValue="0"
    *     [dataSource]="data"
    *     markerOutlines="#ff0000, #cc0000, #aa0000">
    * </igx-category-chart>
    * ```
    *
    * ```ts
    * this.chart.markerOutlines= ["#ff0000", "#ffff00", "#00ffff"] ;
    * ```
    */
    get markerOutlines(): string[];
    set markerOutlines(v: string[]);
    static ngAcceptInputType_markerOutlines: string[] | string;
    /**
     * Gets or sets the maximum number of markers displayed in the plot area of the chart.
    *
    * `markerMaxCount` property used to display maximum number of markers in the plot area of the chart.
    *
    * ```html
    * <igx-category-chart
    *     yAxisMinimumValue="0"
    *     [dataSource]="data"
    *     markerMaxCount=100 >
    * </igx-category-chart>
    * ```
    *
    * ```ts
    *  this.chart.markerMaxCount = 100 ;
    * ```
    */
    get markerMaxCount(): number;
    set markerMaxCount(v: number);
    static ngAcceptInputType_markerMaxCount: number | string;
    /**
     * Gets or sets the fill opacity for all series that have area visuals in this chart.
     * For example, Area, SplineArea, Column chart types
    */
    get areaFillOpacity(): number;
    set areaFillOpacity(v: number);
    static ngAcceptInputType_areaFillOpacity: number | string;
    /**
     * Gets or sets whether the series animations should be allowed when a range change has been detected on an axis.
    */
    get animateSeriesWhenAxisRangeChanges(): boolean;
    set animateSeriesWhenAxisRangeChanges(v: boolean);
    static ngAcceptInputType_animateSeriesWhenAxisRangeChanges: boolean | string;
    /**
     * Gets or sets the palette of brushes to used for coloring trend lines in this chart.
     * The value provided should be an array of CSS color strings or JavaScript objects defining gradients. Optionally the first element can be a string reading "RGB" or "HSV" to specify the interpolation mode of the collection
    *
    * Use the `trendLineBrushes` property for coloring trend lines in the chart.
    *
    * ```html
    * <igx-category-chart
    *     yAxisMinimumValue="0"
    *     [dataSource]="data"
    *     trendLineBrushes="#ff0000,#aa0000">
    * </igx-category-chart>
    * ```
    *
    * ```ts
    * this.chart.trendLineBrushes=["#ff0000", "#ffff00", "#00ffff"]	;
    * ```
    */
    get trendLineBrushes(): string[];
    set trendLineBrushes(v: string[]);
    static ngAcceptInputType_trendLineBrushes: string[] | string;
    /**
     * Gets or sets the formula used for calculating trend lines in this chart.
     * This property applies only to these chart types: point, line, spline, and bubble
    *
    * Use the `trendLineType` property for calculating trend lines.
    *
    * ```html
    * <igx-category-chart
    *       yAxisMinimumValue="0"
    *       [dataSource]="data"
    *       trendLineType= "cubicFit">
    * </igx-category-chart>
    * ```
    *
    * ```ts
    * this.chart.trendLineType = TrendLineType.CubicFit;
    * ```
    */
    get trendLineType(): TrendLineType;
    set trendLineType(v: TrendLineType);
    static ngAcceptInputType_trendLineType: TrendLineType | string;
    /**
     * Gets or sets the thickness of the trend lines in this chart.
     * This property applies only to these chart types: point, line, spline, and bubble
    *
    * Use the `trendLineThickness` property for the thickness of the trend lines in the chart.
    *
    * ```html
    * <igx-category-chart
    *     yAxisMinimumValue="0"
    *     [dataSource]="data"
    *     trendLineThickness= 2>
    * </igx-category-chart>
    * ```
    *
    * ```ts
    * this.chart.trendLineThickness=2;
    * ```
    */
    get trendLineThickness(): number;
    set trendLineThickness(v: number);
    static ngAcceptInputType_trendLineThickness: number | string;
    /**
     * Gets or sets a value indicating whether grid and tick lines are aligned to device pixels.
    *
    * Use `alignsGridLinesToPixels` propert to indicat whether grid and tick lines are aligned to device pixels.
    *
    * ```html
    * <igx-category-chart
    *     [dataSource]="data"
    *     AlignsGridLinesToPixels="true">
    * </igx-category-chart>
    * ```
    *
    * ```ts
    *  this.chart.alignsGridLinesToPixels= true;
    * ```
    */
    get alignsGridLinesToPixels(): boolean;
    set alignsGridLinesToPixels(v: boolean);
    static ngAcceptInputType_alignsGridLinesToPixels: boolean | string;
    /**
     * Margin applied to the Left of the plot area.
    */
    get plotAreaMarginLeft(): number;
    set plotAreaMarginLeft(v: number);
    static ngAcceptInputType_plotAreaMarginLeft: number | string;
    /**
     * Margin applied to the Top of the plot area.
    */
    get plotAreaMarginTop(): number;
    set plotAreaMarginTop(v: number);
    static ngAcceptInputType_plotAreaMarginTop: number | string;
    /**
     * Margin applied to the right of the plot area.
    */
    get plotAreaMarginRight(): number;
    set plotAreaMarginRight(v: number);
    static ngAcceptInputType_plotAreaMarginRight: number | string;
    /**
     * Margin applied below the plot area.
    */
    get plotAreaMarginBottom(): number;
    set plotAreaMarginBottom(v: number);
    static ngAcceptInputType_plotAreaMarginBottom: number | string;
    /**
     * Gets or sets the highlighting mode to use for the series in the component, when supported. This takes precedence over the series level IsHightlightingEnabled.
    */
    get computedPlotAreaMarginMode(): ComputedPlotAreaMarginMode;
    set computedPlotAreaMarginMode(v: ComputedPlotAreaMarginMode);
    static ngAcceptInputType_computedPlotAreaMarginMode: ComputedPlotAreaMarginMode | string;
    /**
     * Gets or sets the highlighting mode to use for the series in the component, when supported. This takes precedence over the series level IsHightlightingEnabled.
    */
    get highlightingMode(): SeriesHighlightingMode;
    set highlightingMode(v: SeriesHighlightingMode);
    static ngAcceptInputType_highlightingMode: SeriesHighlightingMode | string;
    /**
     * Gets or sets the highlighting Behavior to use for the series in the component, when supported. This takes precedence over the series level IsHightlightingEnabled.
    */
    get highlightingBehavior(): SeriesHighlightingBehavior;
    set highlightingBehavior(v: SeriesHighlightingBehavior);
    static ngAcceptInputType_highlightingBehavior: SeriesHighlightingBehavior | string;
    /**
     * Gets or sets the highlighting mode to use for the legend linked to the component, when supported.
    */
    get legendHighlightingMode(): LegendHighlightingMode;
    set legendHighlightingMode(v: LegendHighlightingMode);
    static ngAcceptInputType_legendHighlightingMode: LegendHighlightingMode | string;
    /**
     * Gets or sets the type of legend badges representing all series displayed in a legend linked to this component
     * This property will be ignored when the LegendItemTemplate or LegendItemBadgeTemplate property is set on a series
    */
    get legendItemBadgeShape(): LegendItemBadgeShape;
    set legendItemBadgeShape(v: LegendItemBadgeShape);
    static ngAcceptInputType_legendItemBadgeShape: LegendItemBadgeShape | string;
    /**
     * Gets or sets the mode of legend badges representing all series displayed in a legend linked to this component.
     * This property will be ignored when the LegendItemTemplate or LegendItemBadgeTemplate property is set on a series
    */
    get legendItemBadgeMode(): LegendItemBadgeMode;
    set legendItemBadgeMode(v: LegendItemBadgeMode);
    static ngAcceptInputType_legendItemBadgeMode: LegendItemBadgeMode | string;
    /**
     * Gets or sets a whether the series viewer should auto expand margins to accommodate the initial horizontal axis labels.
    */
    get shouldAutoExpandMarginForInitialLabels(): boolean;
    set shouldAutoExpandMarginForInitialLabels(v: boolean);
    static ngAcceptInputType_shouldAutoExpandMarginForInitialLabels: boolean | string;
    /**
     * Gets or sets the extra amount the series viewer should auto expand margins to accommodate the initial horizontal axis labels.
    */
    get autoExpandMarginExtraPadding(): number;
    set autoExpandMarginExtraPadding(v: number);
    static ngAcceptInputType_autoExpandMarginExtraPadding: number | string;
    /**
     * Gets or sets the maximum amount the series viewer should auto expand margins to accommodate the initial horizontal axis labels.
    */
    get autoExpandMarginMaximumValue(): number;
    set autoExpandMarginMaximumValue(v: number);
    static ngAcceptInputType_autoExpandMarginMaximumValue: number | string;
    get trendLinePeriod(): number;
    set trendLinePeriod(v: number);
    static ngAcceptInputType_trendLinePeriod: number | string;
    /**
     * Gets or sets the style of tooltip to be displayed.
    */
    get toolTipType(): ToolTipType;
    set toolTipType(v: ToolTipType);
    static ngAcceptInputType_toolTipType: ToolTipType | string;
    /**
     * Gets or sets the crosshairs to be displayed.
    */
    get crosshairsDisplayMode(): CrosshairsDisplayMode;
    set crosshairsDisplayMode(v: CrosshairsDisplayMode);
    static ngAcceptInputType_crosshairsDisplayMode: CrosshairsDisplayMode | string;
    /**
     * Gets or sets whether crosshairs will snap to the nearest data point.
    */
    get crosshairsSnapToData(): boolean;
    set crosshairsSnapToData(v: boolean);
    static ngAcceptInputType_crosshairsSnapToData: boolean | string;
    /**
     * Gets or sets the color to apply to vertical crosshairs line.
    */
    get crosshairsLineVerticalStroke(): string;
    set crosshairsLineVerticalStroke(v: string);
    /**
     * Gets or sets thickness of crosshairs lines.
    */
    get crosshairsLineThickness(): number;
    set crosshairsLineThickness(v: number);
    static ngAcceptInputType_crosshairsLineThickness: number | string;
    /**
     * Gets or sets the color to apply to horizontal crosshairs line.
    */
    get crosshairsLineHorizontalStroke(): string;
    set crosshairsLineHorizontalStroke(v: string);
    /**
     * Gets or sets whether annotations are shown along the axis for crosshair values
    */
    get crosshairsAnnotationEnabled(): boolean;
    set crosshairsAnnotationEnabled(v: boolean);
    static ngAcceptInputType_crosshairsAnnotationEnabled: boolean | string;
    /**
     * Gets or sets the background of crosshair annotation on x-axis.
    */
    get crosshairsAnnotationXAxisBackground(): string;
    set crosshairsAnnotationXAxisBackground(v: string);
    /**
     * Gets or sets the background of crosshair annotation on y-axis.
    */
    get crosshairsAnnotationYAxisBackground(): string;
    set crosshairsAnnotationYAxisBackground(v: string);
    /**
     * Gets or sets the text color of crosshair annotation on x-axis.
    */
    get crosshairsAnnotationXAxisTextColor(): string;
    set crosshairsAnnotationXAxisTextColor(v: string);
    /**
     * Gets or sets the text color of crosshair annotation on y-axis.
    */
    get crosshairsAnnotationYAxisTextColor(): string;
    set crosshairsAnnotationYAxisTextColor(v: string);
    /**
     * Gets or sets precision on interpolated values of crosshairs on x-axis.
    */
    get crosshairsAnnotationXAxisPrecision(): number;
    set crosshairsAnnotationXAxisPrecision(v: number);
    static ngAcceptInputType_crosshairsAnnotationXAxisPrecision: number | string;
    /**
     * Gets or sets precision on interpolated values of crosshairs on y-axis.
    */
    get crosshairsAnnotationYAxisPrecision(): number;
    set crosshairsAnnotationYAxisPrecision(v: number);
    static ngAcceptInputType_crosshairsAnnotationYAxisPrecision: number | string;
    /**
     * Gets or sets whether annotations for the final value of each series is displayed on the axis.
    */
    get finalValueAnnotationsVisible(): boolean;
    set finalValueAnnotationsVisible(v: boolean);
    static ngAcceptInputType_finalValueAnnotationsVisible: boolean | string;
    /**
     * Gets or sets the background of final value annotation.
    */
    get finalValueAnnotationsBackground(): string;
    set finalValueAnnotationsBackground(v: string);
    /**
     * Gets or sets the text color of final value annotation.
    */
    get finalValueAnnotationsTextColor(): string;
    set finalValueAnnotationsTextColor(v: string);
    /**
     * Gets or sets precision on final value annotation.
    */
    get finalValueAnnotationsPrecision(): number;
    set finalValueAnnotationsPrecision(v: number);
    static ngAcceptInputType_finalValueAnnotationsPrecision: number | string;
    /**
     * Gets or sets if callouts should be displayed.
    */
    get calloutsVisible(): boolean;
    set calloutsVisible(v: boolean);
    static ngAcceptInputType_calloutsVisible: boolean | string;
    /**
     * Gets or sets if event annotations should be displayed.
    */
    get calloutStyleUpdatingEventEnabled(): boolean;
    set calloutStyleUpdatingEventEnabled(v: boolean);
    static ngAcceptInputType_calloutStyleUpdatingEventEnabled: boolean | string;
    /**
     * Gets or sets the member path of the X data for the callouts.
    */
    get calloutsXMemberPath(): string;
    set calloutsXMemberPath(v: string);
    /**
     * Gets or sets the member path of the Y data for the callouts.
    */
    get calloutsYMemberPath(): string;
    set calloutsYMemberPath(v: string);
    /**
     * Gets or sets the member path of the label data for the callouts.
    */
    get calloutsLabelMemberPath(): string;
    set calloutsLabelMemberPath(v: string);
    /**
     * Gets or sets the member path of the content data for the callouts.
    */
    get calloutsContentMemberPath(): string;
    set calloutsContentMemberPath(v: string);
    findByName(name: string): any;
    protected __p: string;
    protected _hasUserValues: Set<string>;
    protected get hasUserValues(): Set<string>;
    protected __m(propertyName: string): void;
    protected _stylingContainer: any;
    protected _stylingParent: any;
    protected _inStyling: boolean;
    protected _styling(container: any, component: any, parent?: any): void;
    /**
 * Provides a container for this control

*
* `provideContainer` method provide container for the control.
*
* ```ts
*     this.chart.provideContainer("Container");
* ```
*/
    provideContainer(container: any): void;
    /**
     * Destroy this control
    
    *
    * Use the `destroy` property to destroy the chart.
    *
    * ```ts
    * this.chart.destroy();
    * ```
    */
    destroy(): void;
    /**
     * Called when the control has been resized.
    
    *
    * `notifyResized` method Called when the control has been resized.
    *
    * ```ts
    * this.chart.notifyResized();
    * ```
    */
    notifyResized(): void;
    notifyVisualPropertiesChanged(): void;
    /**
     * Forces any pending refresh to the chart to be finished.
    
    *
    * Method `flush` used to Forces any pending deferred work to render on the chart before continuing.
    *
    * ```ts
    * this.chart.flush();
    * ```
    */
    flush(): void;
    /**
     * Hides the active main tooltip, if displayed.
    
    *
    * Use the `hideToolTip` method to hide the active tooltip.
    *
    * ```ts
    * this.chart.hideToolTip();
    * ```
    */
    hideToolTip(): void;
    /**
     * Replays transition-in animation on all series in the chart.
    
    */
    replayTransitionIn(): void;
    notifySetItem(source_: any, index: number, oldItem: any, newItem: any): void;
    /**
     * Used to manually notify the chart that the data source has reset or cleared its items.
    
    *
    * Use `notifyClearItems` method to notifies the chart that the items have been cleared from an associated data source.
    *
    * ```ts
    * this.chart.notifyClearItems(this.data);
    * ```
    */
    notifyClearItems(source_: any): void;
    notifyInsertItem(source_: any, index: number, newItem: any): void;
    notifyRemoveItem(source_: any, index: number, oldItem: any): void;
    private _seriesAdded;
    /**
     * Event raised when a series is initialized and added to this chart.
    *
    * `SeriesAdded` event raised when a series is initialized and added to this chart.
    *
    * ```html
    *  <igx-category-chart
    *       yAxisMinimumValue="0"
    *       [dataSource]="data"
    *       (seriesAdded)="CategoryChart_SeriesAdded()"
    *      >
    * </igx-category-chart>
    * ```
    */
    get seriesAdded(): EventEmitter<{
        sender: any;
        args: IgxChartSeriesEventArgs;
    }>;
    private _seriesRemoved;
    /**
     * Event raised when a series is removed from this chart.
    *
    * `SeriesRemoved` event raised when a series is removed from this chart.
    *
    * ```html
    * <igx-category-chart
    *       yAxisMinimumValue="0"
    *       [dataSource]="data"
    *       (seriesRemoved)="CategoryChart_seriesRemoved()">
    * </igx-category-chart>
    * ```
    *
    * ```ts
    *  CategoryChart_seriesRemoved(sender: any , aregs: ChartSeriesEventArgs)
    *   {
    *
    *   }
    * ```
    */
    get seriesRemoved(): EventEmitter<{
        sender: any;
        args: IgxChartSeriesEventArgs;
    }>;
    private _seriesPointerEnter;
    /**
     * Occurs when the pointer enters a Series.
    *
    * `SeriesPointerEnter` event raised when the pointer enters a Series.
    *
    * ```html
    * <igx-category-chart
    *       yAxisMinimumValue="0"
    *       [dataSource]="data"
    *       (seriesPointerEnter)="CategoryChart_seriesPointerEnter()" >
    * </igx-category-chart>
    * ```
    *
    * ```ts
    * CategoryChart_seriesPointerEnter(sender: any , aregs: ChartSeriesEventArgs)
    *   {
    *
    *   }
    * ```
    */
    get seriesPointerEnter(): EventEmitter<{
        sender: any;
        args: IgxDomainChartSeriesPointerEventArgs;
    }>;
    private _seriesPointerLeave;
    /**
     * Occurs when the pointer leaves a Series.
    *
    * `SeriesPointerLeave` event raised when the pointer leaves a Series.
    *
    * ```html
    * <igx-category-chart
    *       yAxisMinimumValue="0"
    *       [dataSource]="data"
    *       (seriesPointerLeave)= "CategoryChart_seriesPointerLeave()" >
    * </igx-category-chart>
    * ```
    *
    * ```ts
    * CategoryChart_seriesPointerLeave(sender: any , aregs: ChartSeriesEventArgs)
    *   {
    *
    *   }
    * ```
    */
    get seriesPointerLeave(): EventEmitter<{
        sender: any;
        args: IgxDomainChartSeriesPointerEventArgs;
    }>;
    private _seriesPointerMove;
    /**
     * Occurs when the pointer moves over a Series.
    *
    * `SeriesPointerMove` event raised when the pointer moves over a Series.
    *
    * ```html
    * <igx-category-chart
    *       yAxisMinimumValue="0"
    *       [dataSource]="data"
    *        (seriesPointerMove)="CategoryChart_seriesPointerMove()">
    * </igx-category-chart>
    * ```
    *
    * ```ts
    *  CategoryChart_seriesPointerMove(sender: any , aregs: ChartSeriesEventArgs)
    *   {
    *
    *   }
    * ```
    */
    get seriesPointerMove(): EventEmitter<{
        sender: any;
        args: IgxDomainChartSeriesPointerEventArgs;
    }>;
    private _seriesPointerDown;
    /**
     * Occurs when the pointer is pressed down over a Series.
    *
    * `SeriesPointerDown` event raised when the pointer is pressed down over a Series
    *
    * ```html
    * <igx-category-chart
    *       yAxisMinimumValue="0"
    *       [dataSource]="data"
    *       (seriesPointerDown)="CategoryChart_seriesPointerDown()" >
    * </igx-category-chart>
    * ```
    */
    get seriesPointerDown(): EventEmitter<{
        sender: any;
        args: IgxDomainChartSeriesPointerEventArgs;
    }>;
    private _seriesPointerUp;
    /**
     * Occurs when the pointer is released over a Series.
    *
    * `SeriesPointerUp` event raised when the pointer is released over a Series.
    *
    * ```ts
    *  CategoryChart_seriesPointerUp(sender: any , aregs: ChartSeriesEventArgs)
    *   {
    *
    *   }
    * ```
    *
    * ```html
    * <igx-category-chart
    *       yAxisMinimumValue="0"
    *       [dataSource]="data"
    *       (seriesPointerUp)="CategoryChart_seriesPointerUp()" >
    * </igx-category-chart>
    * ```
    */
    get seriesPointerUp(): EventEmitter<{
        sender: any;
        args: IgxDomainChartSeriesPointerEventArgs;
    }>;
    private _calloutStyleUpdating;
    /**
     * Occurs when the style of a callout is updated.
    */
    get calloutStyleUpdating(): EventEmitter<{
        sender: any;
        args: IgxCalloutStyleUpdatingEventArgs;
    }>;
    protected _zoneRunner: (act: () => void) => void;
    protected _runInZone(act: () => void): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<IgxDomainChartComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<IgxDomainChartComponent, "ng-component", never, { "tooltipTemplate": "tooltipTemplate"; "tooltipTemplates": "tooltipTemplates"; "legend": "legend"; "calloutsDataSource": "calloutsDataSource"; "pixelScalingRatio": "pixelScalingRatio"; "titleLeftMargin": "titleLeftMargin"; "titleRightMargin": "titleRightMargin"; "titleTopMargin": "titleTopMargin"; "titleBottomMargin": "titleBottomMargin"; "subtitleLeftMargin": "subtitleLeftMargin"; "subtitleTopMargin": "subtitleTopMargin"; "subtitleRightMargin": "subtitleRightMargin"; "subtitleBottomMargin": "subtitleBottomMargin"; "subtitleTextColor": "subtitleTextColor"; "titleTextColor": "titleTextColor"; "leftMargin": "leftMargin"; "topMargin": "topMargin"; "rightMargin": "rightMargin"; "bottomMargin": "bottomMargin"; "transitionDuration": "transitionDuration"; "transitionEasingFunction": "transitionEasingFunction"; "subtitleTextStyle": "subtitleTextStyle"; "titleTextStyle": "titleTextStyle"; "includedProperties": "includedProperties"; "excludedProperties": "excludedProperties"; "brushes": "brushes"; "outlines": "outlines"; "actualBrushes": "actualBrushes"; "actualOutlines": "actualOutlines"; "isHorizontalZoomEnabled": "isHorizontalZoomEnabled"; "isVerticalZoomEnabled": "isVerticalZoomEnabled"; "shouldDisplayMockData": "shouldDisplayMockData"; "shouldUseSkeletonStyleForMockData": "shouldUseSkeletonStyleForMockData"; "isSeriesHighlightingEnabled": "isSeriesHighlightingEnabled"; "windowRect": "windowRect"; "chartTitle": "chartTitle"; "subtitle": "subtitle"; "titleAlignment": "titleAlignment"; "subtitleAlignment": "subtitleAlignment"; "unknownValuePlotting": "unknownValuePlotting"; "resolution": "resolution"; "thickness": "thickness"; "outlineMode": "outlineMode"; "markerOutlineMode": "markerOutlineMode"; "markerFillMode": "markerFillMode"; "markerFillOpacity": "markerFillOpacity"; "markerThickness": "markerThickness"; "markerTypes": "markerTypes"; "markerAutomaticBehavior": "markerAutomaticBehavior"; "markerBrushes": "markerBrushes"; "markerOutlines": "markerOutlines"; "markerMaxCount": "markerMaxCount"; "areaFillOpacity": "areaFillOpacity"; "animateSeriesWhenAxisRangeChanges": "animateSeriesWhenAxisRangeChanges"; "trendLineBrushes": "trendLineBrushes"; "trendLineType": "trendLineType"; "trendLineThickness": "trendLineThickness"; "alignsGridLinesToPixels": "alignsGridLinesToPixels"; "plotAreaMarginLeft": "plotAreaMarginLeft"; "plotAreaMarginTop": "plotAreaMarginTop"; "plotAreaMarginRight": "plotAreaMarginRight"; "plotAreaMarginBottom": "plotAreaMarginBottom"; "computedPlotAreaMarginMode": "computedPlotAreaMarginMode"; "highlightingMode": "highlightingMode"; "highlightingBehavior": "highlightingBehavior"; "legendHighlightingMode": "legendHighlightingMode"; "legendItemBadgeShape": "legendItemBadgeShape"; "legendItemBadgeMode": "legendItemBadgeMode"; "shouldAutoExpandMarginForInitialLabels": "shouldAutoExpandMarginForInitialLabels"; "autoExpandMarginExtraPadding": "autoExpandMarginExtraPadding"; "autoExpandMarginMaximumValue": "autoExpandMarginMaximumValue"; "trendLinePeriod": "trendLinePeriod"; "toolTipType": "toolTipType"; "crosshairsDisplayMode": "crosshairsDisplayMode"; "crosshairsSnapToData": "crosshairsSnapToData"; "crosshairsLineVerticalStroke": "crosshairsLineVerticalStroke"; "crosshairsLineThickness": "crosshairsLineThickness"; "crosshairsLineHorizontalStroke": "crosshairsLineHorizontalStroke"; "crosshairsAnnotationEnabled": "crosshairsAnnotationEnabled"; "crosshairsAnnotationXAxisBackground": "crosshairsAnnotationXAxisBackground"; "crosshairsAnnotationYAxisBackground": "crosshairsAnnotationYAxisBackground"; "crosshairsAnnotationXAxisTextColor": "crosshairsAnnotationXAxisTextColor"; "crosshairsAnnotationYAxisTextColor": "crosshairsAnnotationYAxisTextColor"; "crosshairsAnnotationXAxisPrecision": "crosshairsAnnotationXAxisPrecision"; "crosshairsAnnotationYAxisPrecision": "crosshairsAnnotationYAxisPrecision"; "finalValueAnnotationsVisible": "finalValueAnnotationsVisible"; "finalValueAnnotationsBackground": "finalValueAnnotationsBackground"; "finalValueAnnotationsTextColor": "finalValueAnnotationsTextColor"; "finalValueAnnotationsPrecision": "finalValueAnnotationsPrecision"; "calloutsVisible": "calloutsVisible"; "calloutStyleUpdatingEventEnabled": "calloutStyleUpdatingEventEnabled"; "calloutsXMemberPath": "calloutsXMemberPath"; "calloutsYMemberPath": "calloutsYMemberPath"; "calloutsLabelMemberPath": "calloutsLabelMemberPath"; "calloutsContentMemberPath": "calloutsContentMemberPath"; }, { "seriesAdded": "seriesAdded"; "seriesRemoved": "seriesRemoved"; "seriesPointerEnter": "seriesPointerEnter"; "seriesPointerLeave": "seriesPointerLeave"; "seriesPointerMove": "seriesPointerMove"; "seriesPointerDown": "seriesPointerDown"; "seriesPointerUp": "seriesPointerUp"; "calloutStyleUpdating": "calloutStyleUpdating"; }, never, never>;
}
