import { EventEmitter } from '@angular/core';
import { IgPoint } from "igniteui-angular-core";
import { IgxCategoryAxisBaseComponent } from "./igx-category-axis-base-component";
import { IgxNumericYAxisComponent } from "./igx-numeric-y-axis-component";
import { CategoryTransitionInMode } from "./CategoryTransitionInMode";
import { IgxAssigningCategoryStyleEventArgs } from "./igx-assigning-category-style-event-args";
import { IgxFinancialEventArgs } from "./igx-financial-event-args";
import { IgxSeriesComponent } from "./igx-series-component";
import { FinancialSeries } from "./FinancialSeries";
import * as i0 from "@angular/core";
/**
 * Represents the base class for all financial indicator and overlay series.
*
* The `IgxFinancialSeriesComponent` represents the base class for all financial indicator and overlay series.
*
* ```html
*  <igx-data-chart
*     #chart
*         [dataSource]="data" >
*   <igx-category-x-axis
*         label="label"
*         #xAxis>
*         </igx-category-x-axis>
*  <igx-numeric-y-axis
*         minimumValue="0"
*         #yAxis>
* </igx-numeric-y-axis>
* <igx-financial-price-series
*     [xAxis]="xAxis"
*       [yAxis]="yAxis"
*       openMemberPath="open"
*       highMemberPath="high"
*       lowMemberPath="low"
*       closeMemberPath="close"
*       volumeMemberPath="volume">
* </igx-financial-price-series>
* </igx-data-chart>
* ```
*
* ```ts
* let series = new IgxFinancialPriceSeriesComponent();
* series.xAxis = this.xAxis;
* series.yAxis = this.yAxis;
* series.openMemberPath = "open";
* series.highMemberPath = "high";
* series.lowMemberPath = "low";
* series.closeMemberPath = "close";
* series.volumeMemberPath="volume";
* this.chart.series.add(series);
* ```
*/
export declare abstract class IgxFinancialSeriesComponent extends IgxSeriesComponent {
    /**
                                 * @hidden
                                 */
    get i(): FinancialSeries;
    constructor();
    /**
     * Gets whether the current series is a financial type series.
    */
    get isFinancial(): boolean;
    static ngAcceptInputType_isFinancial: boolean | string;
    /**
     * Gets or sets the brush to use for negative portions of the series.
    *
    * The `negativeBrush` property is used to brush the negative portions of the series.
    *
    * ```ts
    * series.negativeBrush="red";
    * ```
    *
    * ```html
    *  <igx-data-chart
    *     #chart
    *         [dataSource]="data" >
    *   <igx-category-x-axis
    *         label="label"
    *         #xAxis>
    *         </igx-category-x-axis>
    *  <igx-numeric-y-axis
    *         minimumValue="0"
    *         #yAxis>
    * </igx-numeric-y-axis>
    * <igx-financial-price-series
    *     [xAxis]="xAxis"
    *       [yAxis]="yAxis"
    *       openMemberPath="open"
    *       highMemberPath="high"
    *       lowMemberPath="low"
    *       closeMemberPath="close"
    *       volumeMemberPath="volume"
    * 	  negativeBrush="red">
    * </igx-financial-price-series>
    * </igx-data-chart>
    * ```
    */
    get negativeBrush(): string;
    set negativeBrush(v: string);
    /**
     * Gets or sets the effective x-axis for the current FinancialSeries object.
    *
    * Use `xAxis` property to set effective x-axis for the current FinancialSeries object.
    *
    * ```html
    *  <igx-data-chart
    *     #chart
    *         [dataSource]="data" >
    *   <igx-category-x-axis
    *         label="label"
    *         #xAxis>
    *         </igx-category-x-axis>
    *  <igx-numeric-y-axis
    *         minimumValue="0"
    *         #yAxis>
    * </igx-numeric-y-axis>
    * <igx-financial-price-series
    *     [xAxis]="xAxis"
    *       [yAxis]="yAxis"
    *       openMemberPath="open"
    *       highMemberPath="high"
    *       lowMemberPath="low"
    *       closeMemberPath="close"
    *       volumeMemberPath="volume">
    * </igx-financial-price-series>
    * </igx-data-chart>
    * ```
    *
    * ```ts
    * let series = new IgxFinancialPriceSeriesComponent();
    * series.xAxis = this.xAxis;
    * series.yAxis = this.yAxis;
    * series.openMemberPath = "open";
    * series.highMemberPath = "high";
    * series.lowMemberPath = "low";
    * series.closeMemberPath = "close";
    * series.volumeMemberPath="volume";
    * this.chart.series.add(series);
    * ```
    */
    get xAxis(): IgxCategoryAxisBaseComponent;
    set xAxis(v: IgxCategoryAxisBaseComponent);
    /**
     * Gets or sets the effective y-axis for the current FinancialSeries object.
    *
    * Use `yAxis` property to set the effective y-axis for the current FinancialSeries object.
    *
    * ```html
    *  <igx-data-chart
    *     #chart
    *         [dataSource]="data" >
    *   <igx-category-x-axis
    *         label="label"
    *         #xAxis>
    *         </igx-category-x-axis>
    *  <igx-numeric-y-axis
    *         minimumValue="0"
    *         #yAxis>
    * </igx-numeric-y-axis>
    * <igx-financial-price-series
    *     [xAxis]="xAxis"
    *       [yAxis]="yAxis"
    *       openMemberPath="open"
    *       highMemberPath="high"
    *       lowMemberPath="low"
    *       closeMemberPath="close"
    *       volumeMemberPath="volume">
    * </igx-financial-price-series>
    * </igx-data-chart>
    * ```
    *
    * ```ts
    * let series = new IgxFinancialPriceSeriesComponent();
    * series.xAxis = this.xAxis;
    * series.yAxis = this.yAxis;
    * series.openMemberPath = "open";
    * series.highMemberPath = "high";
    * series.lowMemberPath = "low";
    * series.closeMemberPath = "close";
    * series.volumeMemberPath="volume";
    * this.chart.series.add(series);
    * ```
    */
    get yAxis(): IgxNumericYAxisComponent;
    set yAxis(v: IgxNumericYAxisComponent);
    /**
     * Gets or sets the open mapping property for the current series object.
    *
    * The `openMemberPath` property is used for open mapping of the current series object.
    *
    * ```html
    *  <igx-data-chart
    *     #chart
    *         [dataSource]="data" >
    *   <igx-category-x-axis
    *         label="label"
    *         #xAxis>
    *         </igx-category-x-axis>
    *  <igx-numeric-y-axis
    *         minimumValue="0"
    *         #yAxis>
    * </igx-numeric-y-axis>
    * <igx-financial-price-series
    *     [xAxis]="xAxis"
    *       [yAxis]="yAxis"
    *       openMemberPath="open"
    *       highMemberPath="high"
    *       lowMemberPath="low"
    *       closeMemberPath="close"
    *       volumeMemberPath="volume">
    * </igx-financial-price-series>
    * </igx-data-chart>
    * ```
    *
    * ```ts
    * let series = new IgxFinancialPriceSeriesComponent();
    * series.xAxis = this.xAxis;
    * series.yAxis = this.yAxis;
    * series.openMemberPath = "open";
    * series.highMemberPath = "high";
    * series.lowMemberPath = "low";
    * series.closeMemberPath = "close";
    * series.volumeMemberPath="volume";
    * this.chart.series.add(series);
    * ```
    */
    get openMemberPath(): string;
    set openMemberPath(v: string);
    /**
     * Gets or sets the high mapping property for the current series object.
    *
    * Use `highMemberPath` propert for high mapping of the current series object.
    *
    * ```html
    *  <igx-data-chart
    *     #chart
    *         [dataSource]="data" >
    *   <igx-category-x-axis
    *         label="label"
    *         #xAxis>
    *         </igx-category-x-axis>
    *  <igx-numeric-y-axis
    *         minimumValue="0"
    *         #yAxis>
    * </igx-numeric-y-axis>
    * <igx-financial-price-series
    *     [xAxis]="xAxis"
    *       [yAxis]="yAxis"
    *       openMemberPath="open"
    *       highMemberPath="high"
    *       lowMemberPath="low"
    *       closeMemberPath="close"
    *       volumeMemberPath="volume">
    * </igx-financial-price-series>
    * </igx-data-chart>
    * ```
    *
    * ```ts
    * let series = new IgxFinancialPriceSeriesComponent();
    * series.xAxis = this.xAxis;
    * series.yAxis = this.yAxis;
    * series.openMemberPath = "open";
    * series.highMemberPath = "high";
    * series.lowMemberPath = "low";
    * series.closeMemberPath = "close";
    * series.volumeMemberPath="volume";
    * this.chart.series.add(series);
    * ```
    */
    get highMemberPath(): string;
    set highMemberPath(v: string);
    /**
     * Gets or sets the low mapping property for the current series object.
    *
    * The `lowMemberPath` is used for low mapping property of the current series object.
    *
    * ```html
    *  <igx-data-chart
    *     #chart
    *         [dataSource]="data" >
    *   <igx-category-x-axis
    *         label="label"
    *         #xAxis>
    *         </igx-category-x-axis>
    *  <igx-numeric-y-axis
    *         minimumValue="0"
    *         #yAxis>
    * </igx-numeric-y-axis>
    * <igx-financial-price-series
    *     [xAxis]="xAxis"
    *       [yAxis]="yAxis"
    *       openMemberPath="open"
    *       highMemberPath="high"
    *       lowMemberPath="low"
    *       closeMemberPath="close"
    *       volumeMemberPath="volume">
    * </igx-financial-price-series>
    * </igx-data-chart>
    * ```
    *
    * ```ts
    * let series = new IgxFinancialPriceSeriesComponent();
    * series.xAxis = this.xAxis;
    * series.yAxis = this.yAxis;
    * series.openMemberPath = "open";
    * series.highMemberPath = "high";
    * series.lowMemberPath = "low";
    * series.closeMemberPath = "close";
    * series.volumeMemberPath="volume";
    * this.chart.series.add(series);
    * ```
    */
    get lowMemberPath(): string;
    set lowMemberPath(v: string);
    /**
     * Gets or sets the close mapping property for the current series object.
    *
    * Use `closeMemberPath` property for the close mapping of the current series object.
    *
    * ```html
    *  <igx-data-chart
    *     #chart
    *         [dataSource]="data" >
    *   <igx-category-x-axis
    *         label="label"
    *         #xAxis>
    *         </igx-category-x-axis>
    *  <igx-numeric-y-axis
    *         minimumValue="0"
    *         #yAxis>
    * </igx-numeric-y-axis>
    * <igx-financial-price-series
    *     [xAxis]="xAxis"
    *       [yAxis]="yAxis"
    *       openMemberPath="open"
    *       highMemberPath="high"
    *       lowMemberPath="low"
    *       closeMemberPath="close"
    *       volumeMemberPath="volume">
    * </igx-financial-price-series>
    * </igx-data-chart>
    * ```
    *
    * ```ts
    * let series = new IgxFinancialPriceSeriesComponent();
    * series.xAxis = this.xAxis;
    * series.yAxis = this.yAxis;
    * series.openMemberPath = "open";
    * series.highMemberPath = "high";
    * series.lowMemberPath = "low";
    * series.closeMemberPath = "close";
    * series.volumeMemberPath="volume";
    * this.chart.series.add(series);
    * ```
    */
    get closeMemberPath(): string;
    set closeMemberPath(v: string);
    /**
     * Gets or sets the volume mapping property for the current series object.
    *
    * The `volumeMemberPath` property is used for the volume mapping property of the current series object.
    *
    * ```html
    *  <igx-data-chart
    *     #chart
    *         [dataSource]="data" >
    *   <igx-category-x-axis
    *         label="label"
    *         #xAxis>
    *         </igx-category-x-axis>
    *  <igx-numeric-y-axis
    *         minimumValue="0"
    *         #yAxis>
    * </igx-numeric-y-axis>
    * <igx-financial-price-series
    *     [xAxis]="xAxis"
    *       [yAxis]="yAxis"
    *       openMemberPath="open"
    *       highMemberPath="high"
    *       lowMemberPath="low"
    *       closeMemberPath="close"
    *       volumeMemberPath="volume">
    * </igx-financial-price-series>
    * </igx-data-chart>
    * ```
    *
    * ```ts
    * let series = new IgxFinancialPriceSeriesComponent();
    * series.xAxis = this.xAxis;
    * series.yAxis = this.yAxis;
    * series.openMemberPath = "open";
    * series.highMemberPath = "high";
    * series.lowMemberPath = "low";
    * series.closeMemberPath = "close";
    * series.volumeMemberPath="volume";
    * this.chart.series.add(series);
    * ```
    */
    get volumeMemberPath(): string;
    set volumeMemberPath(v: string);
    /**
     * Gets or sets whether this category series should allow custom style overrides of its individual visuals.
    *
    * The `isCustomCategoryStyleAllowed` property is used to check if the category series should allow custom style.
    *
    * ```html
    *  <igx-data-chart
    *     #chart
    *         [dataSource]="data" >
    *   <igx-category-x-axis
    *         label="label"
    *         #xAxis>
    *         </igx-category-x-axis>
    *  <igx-numeric-y-axis
    *         minimumValue="0"
    *         #yAxis>
    * </igx-numeric-y-axis>
    * <igx-financial-price-series
    *     [xAxis]="xAxis"
    *       [yAxis]="yAxis"
    *       openMemberPath="open"
    *       highMemberPath="high"
    *       lowMemberPath="low"
    *       closeMemberPath="close"
    *       volumeMemberPath="volume"
    * 	  isCustomCategoryStyleAllowed="True" />
    * </igx-financial-price-series>
    * </igx-data-chart>
    * ```
    *
    * ```ts
    * series.isCustomCategoryStyleAllowed= true;
    * ```
    */
    get isCustomCategoryStyleAllowed(): boolean;
    set isCustomCategoryStyleAllowed(v: boolean);
    static ngAcceptInputType_isCustomCategoryStyleAllowed: boolean | string;
    /**
     * Gets or sets the method by which to animate the data into the chart when the chart data source is swapped.
     * Note: Transitions are not currently supported for stacked series.
    *
    * The `transitionInMode` property is used to gets or sets the method by which to animate the data into the chart when the chart data source is swapped.
    *
    * ```ts
    * series.transitionInMode =CategoryTransitionInMode.Auto;
    * ```
    *
    * ```html
    *  <igx-data-chart
    *     #chart
    *         [dataSource]="data" >
    *   <igx-category-x-axis
    *         label="label"
    *         #xAxis>
    *         </igx-category-x-axis>
    *  <igx-numeric-y-axis
    *         minimumValue="0"
    *         #yAxis>
    * </igx-numeric-y-axis>
    * <igx-financial-price-series
    *     [xAxis]="xAxis"
    *       [yAxis]="yAxis"
    *       openMemberPath="open"
    *       highMemberPath="high"
    *       lowMemberPath="low"
    *       closeMemberPath="close"
    *       volumeMemberPath="volume"
    * 	  transitionInMode= "Auto">
    * </igx-financial-price-series>
    * </igx-data-chart>
    * ```
    */
    get transitionInMode(): CategoryTransitionInMode;
    set transitionInMode(v: CategoryTransitionInMode);
    static ngAcceptInputType_transitionInMode: CategoryTransitionInMode | string;
    /**
     * Gets or sets whether the series should transition into the plot area when a new data source is assigned.
     * Note: Transitions are not currently supported for stacked series.
    *
    * The `isTransitionInEnabled` property is used to check if the series should transition into the plot area when a new data source is assigned.
    *
    * ```ts
    * series.isTransitionInEnabled= true;
    * ```
    *
    * ```html
    *  <igx-data-chart
    *     #chart
    *         [dataSource]="data" >
    *   <igx-category-x-axis
    *         label="label"
    *         #xAxis>
    *         </igx-category-x-axis>
    *  <igx-numeric-y-axis
    *         minimumValue="0"
    *         #yAxis>
    * </igx-numeric-y-axis>
    * <igx-financial-price-series
    *     [xAxis]="xAxis"
    *       [yAxis]="yAxis"
    *       openMemberPath="open"
    *       highMemberPath="high"
    *       lowMemberPath="low"
    *       closeMemberPath="close"
    *       volumeMemberPath="volume"
    * 	  isTransitionInEnabled= "true">
    * </igx-financial-price-series>
    * </igx-data-chart>
    * ```
    */
    get isTransitionInEnabled(): boolean;
    set isTransitionInEnabled(v: boolean);
    static ngAcceptInputType_isTransitionInEnabled: boolean | string;
    /**
     * Overridden by derived series classes to indicate when negative colors are supported or not.
    */
    get isNegativeColorSupported(): boolean;
    static ngAcceptInputType_isNegativeColorSupported: boolean | string;
    findByName(name: string): any;
    protected _styling(container: any, component: any, parent?: any): void;
    getItemValue(item: any, memberPathName: string): any;
    getPreviousOrExactIndex(world: IgPoint, skipUnknowns: boolean): number;
    getNextOrExactIndex(world: IgPoint, skipUnknowns: boolean): number;
    /**
     * Returns the offset value for this series if grouped on a category axis.
    
    *
    * The `getOffsetValue` method returns the offset value for this series if grouped on a category axis.
    *
    * ```ts
    * number offset= series.getOffsetValue();
    * ```
    */
    getOffsetValue(): number;
    /**
     * Returns the width of the category grouping this series is in.
    
    *
    * The `getCategoryWidth` method returns the width of the category grouping this series is in.
    *
    * ```ts
    * number width = series.getCategoryWidth();
    * ```
    */
    getCategoryWidth(): number;
    getSeriesValuePosition(world: IgPoint, useInterpolation: boolean, skipUnknowns: boolean): IgPoint;
    getSeriesValue(world: IgPoint, useInterpolation: boolean, skipUnknowns: boolean): number;
    getSeriesHighValue(world: IgPoint, useInterpolation: boolean, skipUnknowns: boolean): number;
    getSeriesLowValue(world: IgPoint, useInterpolation: boolean, skipUnknowns: boolean): number;
    getSeriesCloseValue(world: IgPoint, useInterpolation: boolean, skipUnknowns: boolean): number;
    getSeriesOpenValue(world: IgPoint, useInterpolation: boolean, skipUnknowns: boolean): number;
    getSeriesVolumeValue(world: IgPoint, useInterpolation: boolean, skipUnknowns: boolean): number;
    getSeriesHighValuePosition(world: IgPoint, useInterpolation: boolean, skipUnknowns: boolean): IgPoint;
    getSeriesLowValuePosition(world: IgPoint, useInterpolation: boolean, skipUnknowns: boolean): IgPoint;
    getSeriesOpenValuePosition(world: IgPoint, useInterpolation: boolean, skipUnknowns: boolean): IgPoint;
    getSeriesCloseValuePosition(world: IgPoint, useInterpolation: boolean, skipUnknowns: boolean): IgPoint;
    getSeriesVolumeValuePosition(world: IgPoint, useInterpolation: boolean, skipUnknowns: boolean): IgPoint;
    /**
     * Determine if object can be used as YAxis
    
    * @param axis  * The object to check
    *
    * Use `canUseAsYAxis` method to determine if the object can be used as YAxis.
    *
    * ```ts
    *   boolean canY =series.canUseAsYAxis(yAxis);
    * ```
    */
    canUseAsYAxis(axis: any): boolean;
    /**
     * Determine if object can be used as XAxis
    
    * @param axis  * The object to check
    *
    * Use `canUseAsXAxis` method to determine if the object can be used as XAxis.
    *
    * ```ts
    *   boolean canX =series.canUseAsXAxis(xAxis);
    * ```
    */
    canUseAsXAxis(axis: any): boolean;
    /**
     * Gets the precise item index, if possible, based on the closeness to the previous or next whole integer. If the series cannot provide this information, GetExactItemIndex will return the same integer value as GetItemIndex.
    
    * @param world  * The world position for which to return the index.
    *
    * The `getExactItemIndex` method gets the precise item index, if possible, based on the closeness to the previous or next whole integer.
    *
    * If the series cannot provide this information, GetExactItemIndex will return the same integer value as GetItemIndex.
    *
    * ```ts
    * number index = series.getExactItemIndex(world);
    * ```
    */
    getExactItemIndex(world: IgPoint): number;
    /**
     * Gets the index of the item that resides at the provided world coordinates.
    
    * @param world  * The world coordinates of the requested item.
    *
    * The `getItemIndex` method gets the index of the item that resides at the provided world coordinates.
    *
    * ```ts
    * number itemindex= series.getItemIndex(world);
    * ```
    */
    getItemIndex(world: IgPoint): number;
    /**
     * Gets the item that is the best match for the specified world coordinates.
    
    * @param world  * The world coordinates to use.
    *
    * The `getItem` method gets the item that is the best match for the specified world coordinates.
    */
    getItem(world: IgPoint): any;
    setNegativeColors(negativeBrush: string, negativeOutline: string): void;
    private _assigningCategoryStyle;
    /**
     * Event raised when Assigning Category Style
    *
    * The `AssigningCategoryStyle` event raised when assigning Category Style.
    *
    * ```ts
    * series.assigningCategoryStyle= this.chart_AssigningCategoryStyle;
    * chart_AssigningCategoryStyle(sender :any,args: AssigningCategoryStyleEventArgs )
    *   {
    *
    *
    *   }
    * ```
    */
    get assigningCategoryStyle(): EventEmitter<{
        sender: any;
        args: IgxAssigningCategoryStyleEventArgs;
    }>;
    private _typical;
    /**
     * Handle this event in order to perform a custom typical price calculation.
    *
    * Use `Typical` event to perform a custom typical price calculation.
    *
    * ```ts
    * series.typical= this.chart_typical;
    *
    *   chart_typical(sender :any,args: FinancialEventArgs )
    *   {
    *
    *
    *   }
    * ```
    */
    get typical(): EventEmitter<{
        sender: any;
        args: IgxFinancialEventArgs;
    }>;
    private _typicalBasedOn;
    /**
     * Handle this event in order to specify which columns the Typical price calculation is based on.
    *
    * Use `TypicalBasedOn` event to specify which columns the Typical price calculation is based on.
    *
    * ```ts
    *    series.typicalBasedOn= this.chart_typicalBasedOn;
    *     chart_typicalBasedOn(sender :any,args: FinancialEventArgs )
    *   {
    *
    *   }
    * ```
    */
    get typicalBasedOn(): EventEmitter<{
        sender: any;
        args: IgxFinancialEventArgs;
    }>;
    static ɵfac: i0.ɵɵFactoryDeclaration<IgxFinancialSeriesComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<IgxFinancialSeriesComponent, "ng-component", never, { "negativeBrush": "negativeBrush"; "xAxis": "xAxis"; "yAxis": "yAxis"; "openMemberPath": "openMemberPath"; "highMemberPath": "highMemberPath"; "lowMemberPath": "lowMemberPath"; "closeMemberPath": "closeMemberPath"; "volumeMemberPath": "volumeMemberPath"; "isCustomCategoryStyleAllowed": "isCustomCategoryStyleAllowed"; "transitionInMode": "transitionInMode"; "isTransitionInEnabled": "isTransitionInEnabled"; }, { "assigningCategoryStyle": "assigningCategoryStyle"; "typical": "typical"; "typicalBasedOn": "typicalBasedOn"; }, never, never>;
}
