import { OnDestroy, Renderer2, ElementRef, NgZone } from '@angular/core';
import { IgxLegendBaseComponent } from './igx-legend-base-component';
import { Legend } from "./Legend";
import { LegendOrientation } from './LegendOrientation';
import * as i0 from "@angular/core";
/**
 * Represents a legend in a IgxDataChartComponent control.
*
* The `IgxLegendComponent` helps end-user identify visuals of chart series with contextual information related to the data plotted in the chart control.
*
* ```html
*  <igx-data-chart
*     [dataSource]="data"
* 	 [legend]="legend">
*     <igx-category-x-axis
*         label="label"
*         #xAxis>
*     </igx-category-x-axis>
*     <igx-numeric-y-axis
*         #yAxis>
*     </igx-numeric-y-axis>
*     <igx-line-series
*         [xAxis]="xAxis"
*         [yAxis]="yAxis"
*         valueMemberPath="value">
*     </igx-line-series>
* </igx-data-chart>
*  <igx-legend #legend></igx-legend>
* ```
*
* ```ts
* public legend : IgxLegendComponent;
* ```
*/
export declare class IgxLegendComponent extends IgxLegendBaseComponent implements OnDestroy {
    private renderer;
    private elRef;
    private ngZone;
    container: Element;
    constructor(renderer: Renderer2, elRef: ElementRef, ngZone: NgZone);
    private _wrapper;
    ngOnDestroy(): void;
    protected createImplementation(): Legend;
    get i(): Legend;
    /**
 * Gets or sets the current Legend object's orientation.
*/
    get orientation(): LegendOrientation;
    set orientation(v: LegendOrientation);
    static ngAcceptInputType_orientation: LegendOrientation | string;
    /**
     * Gets or sets color of text
    */
    get textColor(): string;
    set textColor(v: string);
    /**
     * Gets or sets style of text.
    */
    get textStyle(): string;
    set textStyle(v: string);
    static ɵfac: i0.ɵɵFactoryDeclaration<IgxLegendComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<IgxLegendComponent, "igx-legend", never, { "orientation": "orientation"; "textColor": "textColor"; "textStyle": "textStyle"; }, {}, never, never>;
}
