import { EventEmitter } from '@angular/core';
import { IgPoint } from "igniteui-angular-core";
import { IgxCategoryAngleAxisComponent } from "./igx-category-angle-axis-component";
import { IgxNumericRadiusAxisComponent } from "./igx-numeric-radius-axis-component";
import { IgxAssigningRadialStyleEventArgs } from "./igx-assigning-radial-style-event-args";
import { IgxAssigningRadialMarkerStyleEventArgs } from "./igx-assigning-radial-marker-style-event-args";
import { IgxMarkerSeriesComponent } from "./igx-marker-series-component";
import { RadialBase } from "./RadialBase";
import * as i0 from "@angular/core";
/**
 * Represents the base class for all IgxDataChartComponent radial series
*/
export declare abstract class IgxRadialBaseComponent extends IgxMarkerSeriesComponent {
    /**
                                 * @hidden
                                 */
    get i(): RadialBase;
    constructor();
    /**
     * Checks if this series is a radial series
    */
    get isRadial(): boolean;
    static ngAcceptInputType_isRadial: boolean | string;
    /**
     * Gets or sets whether this Radial series should allow custom style overrides of its individual visuals.
    */
    get isCustomRadialStyleAllowed(): boolean;
    set isCustomRadialStyleAllowed(v: boolean);
    static ngAcceptInputType_isCustomRadialStyleAllowed: boolean | string;
    /**
     * Gets or sets whether this Radial series should allow custom style overrides of its individual marker visuals.
    */
    get isCustomRadialMarkerStyleAllowed(): boolean;
    set isCustomRadialMarkerStyleAllowed(v: boolean);
    static ngAcceptInputType_isCustomRadialMarkerStyleAllowed: boolean | string;
    /**
     * Gets the effective angle axis for the current series object.
    */
    get angleAxis(): IgxCategoryAngleAxisComponent;
    set angleAxis(v: IgxCategoryAngleAxisComponent);
    /**
     * Gets the effective value axis for the current series object.
    */
    get valueAxis(): IgxNumericRadiusAxisComponent;
    set valueAxis(v: IgxNumericRadiusAxisComponent);
    /**
     * Gets or sets whether to clip the series to the bounds.
     * Setting this property to true will decrease chart performance.
    */
    get clipSeriesToBounds(): boolean;
    set clipSeriesToBounds(v: boolean);
    static ngAcceptInputType_clipSeriesToBounds: boolean | string;
    findByName(name: string): any;
    protected _styling(container: any, component: any, parent?: any): void;
    /**
     * Determine if object can be used as ValueAxis
    
    * @param axis  * The object to check
    */
    canUseAsValueAxis(axis: any): boolean;
    /**
     * Determine if object can be used as AngleAxis
    
    * @param axis  * The object to check
    */
    canUseAsAngleAxis(axis: any): boolean;
    /**
     * Gets the item that is the best match for the specified world coordinates.
    
    * @param world  * The world coordinates to use.
    */
    getItem(world: IgPoint): any;
    /**
     * Gets the angle to the provided world position from the center of the radial series.
    
    * @param world  * The world position to get the angle for
    */
    getAngleFromWorld(world: IgPoint): number;
    /**
     * Gets the precise item index, if possible, based on the closeness to the previous or next whole integer. If the series cannot provide this information, GetExactItemIndex will return the same integer value as GetItemIndex.
    
    * @param world  * The world position for which to return the index.
    */
    getExactItemIndex(world: IgPoint): number;
    /**
     * Get the index of the item near the provided world coordinates.
    
    * @param world  * The world coordinates for which to getch the item index.
    */
    getItemIndex(world: IgPoint): number;
    /**
     * Scrolls the specified item into the view.
    
    * @param item  * The item to scroll into view.
    */
    scrollIntoView(item: any): boolean;
    /**
     * Returns the offset value for this series if grouped on a category axis.
    
    */
    getOffsetValue(): number;
    /**
     * Returns the width of the category grouping this series is in.
    
    */
    getCategoryWidth(): number;
    private _assigningRadialStyle;
    /**
     * Event raised when Assigning Category Style
    */
    get assigningRadialStyle(): EventEmitter<{
        sender: any;
        args: IgxAssigningRadialStyleEventArgs;
    }>;
    private _assigningRadialMarkerStyle;
    /**
     * Event raised when Assigning Radial Marker Style
    */
    get assigningRadialMarkerStyle(): EventEmitter<{
        sender: any;
        args: IgxAssigningRadialMarkerStyleEventArgs;
    }>;
    static ɵfac: i0.ɵɵFactoryDeclaration<IgxRadialBaseComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<IgxRadialBaseComponent, "ng-component", never, { "isCustomRadialStyleAllowed": "isCustomRadialStyleAllowed"; "isCustomRadialMarkerStyleAllowed": "isCustomRadialMarkerStyleAllowed"; "angleAxis": "angleAxis"; "valueAxis": "valueAxis"; "clipSeriesToBounds": "clipSeriesToBounds"; }, { "assigningRadialStyle": "assigningRadialStyle"; "assigningRadialMarkerStyle": "assigningRadialMarkerStyle"; }, never, never>;
}
