import { IgxStrategyBasedIndicatorComponent } from "./igx-strategy-based-indicator-component";
import { RateOfChangeAndMomentumIndicator } from "./RateOfChangeAndMomentumIndicator";
import * as i0 from "@angular/core";
/**
 * Represents a IgxDataChartComponent Rate of Change and Momentum indicator series.
 * Default required members: Close
*
* `IgxRateOfChangeAndMomentumIndicatorComponent` class represents a Rate of Change and Momentum indicator series for the IgxDataChartComponent.
*
* ```html
* <igx-data-chart  #chart
*     [dataSource]="data">
*     <igx-category-x-axis
*     label="label"
*     #xAxis
*     >
*     </igx-category-x-axis>
*     <igx-numeric-y-axis
*     minimumValue="0"
*     #yAxis>
*     </igx-numeric-y-axis>
*     <igx-rate-of-change-and-momentum-indicator
*     [xAxis]="xAxis"
*     [yAxis]="yAxis"
*     openMemberPath="open"
*     highMemberPath="high"
*     lowMemberPath="low"
*     closeMemberPath="close"
*     >
* </igx-rate-of-change-and-momentum-indicator>
* </igx-data-chart>
* ```
*
* ```ts
* let series = new IgxRateOfChangeAndMomentumIndicatorComponent();
* series.xAxis = this.xAxis;
* series.yAxis = this.yAxis;
* series.openMemberPath = "open";
* series.highMemberPath = "high";
* series.lowMemberPath = "low";
* series.closeMemberPath = "close";
* this.chart.series.add(series);
* ```
*/
export declare class IgxRateOfChangeAndMomentumIndicatorComponent extends IgxStrategyBasedIndicatorComponent {
    protected createImplementation(): RateOfChangeAndMomentumIndicator;
    /**
                                 * @hidden
                                 */
    get i(): RateOfChangeAndMomentumIndicator;
    constructor();
    /**
     * Gets or sets the moving average period for the current AverageTrueRangeSeries object.
     * The typical, and initial, value for AverageTrueRange periods is 14.
    *
    * You can use the `period` property for the current AverageTrueRangeSeries object.
    *
    * The typical, and initial, value for AverageTrueRange periods is 14.
    *
    * ```html
    * <igx-data-chart  #chart
    *     [dataSource]="data">
    *     <igx-category-x-axis
    *     label="label"
    *     #xAxis
    *     >
    *     </igx-category-x-axis>
    *     <igx-numeric-y-axis
    *     minimumValue="0"
    *     #yAxis>
    *     </igx-numeric-y-axis>
    *     <igx-rate-of-change-and-momentum-indicator
    *     [xAxis]="xAxis"
    *     [yAxis]="yAxis"
    *     openMemberPath="open"
    *     highMemberPath="high"
    *     lowMemberPath="low"
    *     closeMemberPath="close"
    * 	period="30">
    * </igx-rate-of-change-and-momentum-indicator>
    * </igx-data-chart>
    * ```
    *
    * ```ts
    * this.series.period = 30;
    * ```
    */
    get period(): number;
    set period(v: number);
    static ngAcceptInputType_period: number | string;
    static ɵfac: i0.ɵɵFactoryDeclaration<IgxRateOfChangeAndMomentumIndicatorComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<IgxRateOfChangeAndMomentumIndicatorComponent, "igx-rate-of-change-and-momentum-indicator", never, { "period": "period"; }, {}, never, never>;
}
