import { IndicatorDisplayType } from "./IndicatorDisplayType";
import { IgxStrategyBasedIndicatorComponent } from "./igx-strategy-based-indicator-component";
import { RelativeStrengthIndexIndicator } from "./RelativeStrengthIndexIndicator";
import * as i0 from "@angular/core";
/**
 * Represents a IgxDataChartComponent Relative Strength Index indicator series.
 * Default required members: Close
*
* The `IgxRelativeStrengthIndexIndicatorComponent` class represents Relative Strength Index indicator series for the IgxDataChartComponent .
*
* ```html
*  <igx-data-chart
*     [dataSource]="data">
* 	<igx-category-x-axis
* 		label="label"
* 		#xAxis>
*     </igx-category-x-axis>
*     <igx-numeric-y-axis
* 		#yAxis>
*     </igx-numeric-y-axis>
* 	<igx-relative-strength-index-indicator
*         #series
*         [xAxis]="xAxis"
*         [yAxis]="yAxis"
*         highMemberPath="high"
* 		lowMemberPath="low"
* 		volumeMemberPath="volume">
*     </igx-relative-strength-index-indicator>
* </igx-data-chart>
* ```
*
* ```ts
* let series = new IgxRelativeStrengthIndexIndicatorComponent();
* series.xAxis = this.xAxis;
* series.yAxis = this.yAxis;
* series.openMemberPath = "open";
* series.highMemberPath = "high";
* series.lowMemberPath = "low";
* series.closeMemberPath = "close";
* this.chart.series.add(series);
* ```
*/
export declare class IgxRelativeStrengthIndexIndicatorComponent extends IgxStrategyBasedIndicatorComponent {
    protected createImplementation(): RelativeStrengthIndexIndicator;
    /**
                                 * @hidden
                                 */
    get i(): RelativeStrengthIndexIndicator;
    constructor();
    /**
     * Gets default display type for the current Financial Indicator
    */
    get defaultDisplayType(): IndicatorDisplayType;
    static ngAcceptInputType_defaultDisplayType: IndicatorDisplayType | string;
    /**
     * Gets or sets the moving average period for the current RelativeStrengthIndexIndicator object.
     * The typical, and initial, value for RSI periods is 14.
    *
    * You can use the `period` property for the current RelativeStrengthIndexIndicator object.
    *
    * ```html
    *  <igx-data-chart
    *     [dataSource]="data">
    * 	<igx-category-x-axis
    * 		label="label"
    * 		#xAxis>
    *     </igx-category-x-axis>
    *     <igx-numeric-y-axis
    * 		#yAxis>
    *     </igx-numeric-y-axis>
    * 	<igx-relative-strength-index-indicator
    *         #series
    *         [xAxis]="xAxis"
    *         [yAxis]="yAxis"
    *         highMemberPath="high"
    * 		lowMemberPath="low"
    * 		volumeMemberPath="volume"
    * 		period=30>
    *     </igx-relative-strength-index-indicator>
    * </igx-data-chart>
    * ```
    *
    * ```ts
    * this.series.period = 30;
    * ```
    */
    get period(): number;
    set period(v: number);
    static ngAcceptInputType_period: number | string;
    static ɵfac: i0.ɵɵFactoryDeclaration<IgxRelativeStrengthIndexIndicatorComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<IgxRelativeStrengthIndexIndicatorComponent, "igx-relative-strength-index-indicator", never, { "period": "period"; }, {}, never, never>;
}
