import { EventEmitter, OnInit } from '@angular/core';
import { IgPoint } from "igniteui-angular-core";
import { StackedSeriesBase } from "./StackedSeriesBase";
import { IgxStackedSeriesCreatedEventArgs } from './igx-stacked-series-created-event-args';
import { IgxCategorySeriesComponent } from "./igx-category-series-component";
import { AfterContentInit, QueryList } from '@angular/core';
import { IgxStackedFragmentSeriesComponent } from './igx-stacked-fragment-series-component';
import { IgxStackedSeriesCollection } from './igx-stacked-series-collection';
import * as i0 from "@angular/core";
/**
 * Represents a base class for stacked series.
*/
export declare abstract class IgxStackedSeriesBaseComponent extends IgxCategorySeriesComponent implements AfterContentInit, OnInit {
    protected createImplementation(): StackedSeriesBase;
    ngOnInit(): void;
    protected _implementation: any;
    get i(): StackedSeriesBase;
    constructor();
    ngAfterContentInit(): void;
    fragments: QueryList<IgxStackedFragmentSeriesComponent>;
    private _seriesAdapter;
    /**
     * The series actually present in the chart. Do not directly modify this array.
     * This array's contents can be modified by causing Angular to reproject the child content.
     * Or adding and removing series from the manual series collection on the series property.
     */
    actualSeries: IgxStackedFragmentSeriesComponent[];
    private _series;
    /**
     * A collection or manually added series for the chart.
    */
    get series(): IgxStackedSeriesCollection;
    static _createFromInternal(internal: any): IgxStackedSeriesBaseComponent;
    /**
 * Gets or sets whether series should be automatically generated. Reqiures the use of GroupBy as the ItemsSource.
*/
    get autoGenerateSeries(): boolean;
    set autoGenerateSeries(v: boolean);
    static ngAcceptInputType_autoGenerateSeries: boolean | string;
    /**
     * Gets or sets whether the order of the fragment series should be reversed in the legend.
    */
    get reverseLegendOrder(): boolean;
    set reverseLegendOrder(v: boolean);
    static ngAcceptInputType_reverseLegendOrder: boolean | string;
    /**
     * Checks if this series is a stacked series
    */
    get isStacked(): boolean;
    static ngAcceptInputType_isStacked: boolean | string;
    get isPercentBased(): boolean;
    static ngAcceptInputType_isPercentBased: boolean | string;
    findByName(name: string): any;
    /**
 * Called to notify about changes to indexed-based properties, e.g. Brushes, Outlines, MarkerBrushes, MarkerOutlines and refresh series

*/
    notifyIndexedPropertiesChanged(): void;
    /**
     * Simulates a pointer hover over the series surface.
    
    * @param point  * The pointer position relative to the series viewport over which to hover.
    */
    simulateHover(point: IgPoint): void;
    /**
     * Scrolls the series to display the item for the specified data item.
     * The series is scrolled by the minimum amount required to place the specified data item within
     * the central 80% of the visible axis.
    
    * @param item  * The data item (item) to scroll to.
    */
    scrollIntoView(item: any): boolean;
    private _seriesCreated;
    /**
     * Event raised when a new fragment series is automatically generated.
    */
    get seriesCreated(): EventEmitter<{
        sender: any;
        args: IgxStackedSeriesCreatedEventArgs;
    }>;
    static ɵfac: i0.ɵɵFactoryDeclaration<IgxStackedSeriesBaseComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<IgxStackedSeriesBaseComponent, "ng-component", never, { "autoGenerateSeries": "autoGenerateSeries"; "reverseLegendOrder": "reverseLegendOrder"; }, { "seriesCreated": "seriesCreated"; }, ["fragments"], never>;
}
